@@ -16,9 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bstapp.h"
-
 #include "topconfig.h"
-
+#include "bstskinconfig.h"
 #include "bstsupershell.h"
 #include "bstfiledialog.h"
 #include "bstgconfig.h"
@@ -32,18 +31,17 @@
 
 
 /* --- prototypes --- */
-static void     bst_app_class_init              (BstAppClass    *class);
-static void     bst_app_init                    (BstApp         *app);
-static void     bst_app_destroy                 (GtkObject      *object);
-static gboolean bst_app_handle_delete_event     (GtkWidget      *widget,
-                                                 GdkEventAny    *event);
-static void     bst_app_run_script_proc         (gpointer        data,
-                                                 gulong          category_id);
-static GxkActionList* demo_entries_create       (BstApp         *app);
-static void     app_action_exec                 (gpointer        data,
-                                                 gulong          action);
-static gboolean app_action_check                (gpointer        data,
-                                                 gulong          action);
+static void           bst_app_destroy             (GtkObject   *object);
+static gboolean       bst_app_handle_delete_event (GtkWidget   *widget,
+                                                   GdkEventAny *event);
+static void           bst_app_run_script_proc     (gpointer     data,
+                                                   gulong       category_id);
+static GxkActionList* demo_entries_create         (BstApp      *app);
+static GxkActionList* skin_entries_create         (BstApp      *app);
+static void           app_action_exec             (gpointer     data,
+                                                   gulong       action);
+static gboolean       app_action_check            (gpointer     data,
+                                                   gulong       action);
 
 
 /* --- menus --- */
@@ -136,31 +134,10 @@ static const GxkStockAction devel_help_actions[] = {
 
 /* --- variables --- */
 static BstAppClass    *bst_app_class = NULL;
-static gpointer        parent_class = NULL;
 
 
 /* --- functions --- */
-GType
-bst_app_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-        sizeof (BstAppClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) bst_app_class_init,
-        NULL,   /* class_finalize */
-        NULL,   /* class_data */
-        sizeof (BstApp),
-        0,      /* n_preallocs */
-        (GInstanceInitFunc) bst_app_init,
-      };
-      type = g_type_register_static (GXK_TYPE_DIALOG, "BstApp", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstApp, bst_app, GXK_TYPE_DIALOG);
 
 static void
 bst_app_class_init (BstAppClass *class)
@@ -169,7 +146,6 @@ bst_app_class_init (BstAppClass *class)
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
   bst_app_class = class;
-  parent_class = g_type_class_peek_parent (class);
 
   object_class->destroy = bst_app_destroy;
 
@@ -265,13 +241,17 @@ bst_app_init (BstApp *app)
   al1 = demo_entries_create (app);
   gxk_action_list_sort (al1);
   gxk_widget_publish_action_list (widget, "demo-songs", al1);
+  /* add skins */
+  al1 = skin_entries_create (app);
+  gxk_action_list_sort (al1);
+  gxk_widget_publish_action_list (widget, "skin-options", al1);
 
   /* setup playback controls */
   app->pcontrols = g_object_new (BST_TYPE_PROJECT_CTRL, NULL);
   gxk_gadget_add (app->box, "control-area", app->pcontrols);
   /* setup the main notebook */
   app->notebook = gxk_gadget_find (app->box, "main-notebook");
-  gxk_nullify_in_object (app->notebook, &app->notebook, app);
+  gxk_nullify_in_object (app, &app->notebook);
   g_object_connect (app->notebook,
                     "swapped_signal_after::switch-page", gxk_widget_update_actions, app,
                     "signal_after::switch-page", gxk_widget_viewable_changed, NULL,
@@ -301,7 +281,7 @@ bst_app_destroy (GtkObject *object)
 
   bst_app_unregister (self);
 
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (bst_app_parent_class)->destroy (object);
 
   if (!bst_app_class->apps && bst_app_class->seen_apps)
     {
@@ -509,6 +489,7 @@ typedef struct {
   gchar *file;
   gchar *name;
 } DemoEntry;
+
 static DemoEntry *demo_entries = NULL;
 static guint     n_demo_entries = 0;
 
@@ -521,7 +502,7 @@ demo_entries_setup (void)
       while (files)
         {
           gchar *file = sfi_ring_pop_head (&files);
-          gchar *name = bst_file_scan_song_name (file);
+          gchar *name = bst_file_scan_find_key (file, "container-child", "BseSong::");
           if (name && n_demo_entries < 0xffff)
             {
               guint i = n_demo_entries++;
@@ -573,6 +554,62 @@ demo_entries_create (BstApp *app)
   return alist;
 }
 
+static DemoEntry *skin_entries = NULL;
+static guint     n_skin_entries = 0;
+
+static void
+skin_entries_setup (void)
+{
+  if (!skin_entries)
+    {
+      gchar *skindirs = BST_STRDUP_SKIN_PATH ();
+      SfiRing *files = sfi_file_crawler_list_files (skindirs, "*.skin", 0);
+      g_free (skindirs);
+      while (files)
+        {
+          gchar *file = sfi_ring_pop_head (&files);
+          gchar *name = bst_file_scan_find_key (file, "skin-name", "");
+          static guint statici = 1;
+          if (!name)
+            name = g_strdup_printf ("skin-%u", statici++);
+          if (name && n_skin_entries < 0xffff)
+            {
+              guint i = n_skin_entries++;
+              skin_entries = g_renew (DemoEntry, skin_entries, n_skin_entries);
+              skin_entries[i].file = file;
+              skin_entries[i].name = name;
+            }
+          else
+            {
+              g_free (name);
+              g_free (file);
+            }
+        }
+    }
+}
+
+static void
+load_skin (gpointer data,
+           gulong   callback_action)
+{
+  const gchar *file_name = skin_entries[callback_action - BST_ACTION_LOAD_SKIN_0000].file;
+  BseErrorType error = bst_skin_parse (file_name);
+  bst_status_eprintf (error, _("Loading skin `%s'"), file_name);
+}
+
+static GxkActionList*
+skin_entries_create (BstApp *app)
+{
+  GxkActionList *alist = gxk_action_list_create ();
+  guint i;
+  skin_entries_setup ();
+  for (i = 0; i < n_skin_entries; i++)
+    gxk_action_list_add_translated (alist, skin_entries[i].name, skin_entries[i].name,
+                                    NULL, NULL, BST_ACTION_LOAD_SKIN_0000 + i, BST_STOCK_BROWSE_IMAGE,
+                                    NULL, load_skin, app);
+  return alist;
+}
+
 static void
 bst_app_run_script_proc (gpointer data,
                          gulong   category_id)
