@@ -172,8 +172,8 @@ clink_view_update (BstCanvasLink *clink,
 
       /* figure appropriate window title
        */
-      iname = clink->icsource ? bse_item_get_name_or_type (clink->icsource->source) : "<???>";
-      oname = clink->ocsource ? bse_item_get_name_or_type (clink->ocsource->source) : "<???>";
+      iname = clink->icsource ? bse_item_get_name_or_type (clink->icsource->source) : "<""???"">";
+      oname = clink->ocsource ? bse_item_get_name_or_type (clink->ocsource->source) : "<""???"">";
       string = g_strconcat (_("Module Link: "), iname, " <=> ", oname, NULL);
       gxk_dialog_set_title (GXK_DIALOG (clink->link_view), string);
       g_free (string);
