@@ -20,7 +20,7 @@
 
 
 #define CONTROL_TYPE(erctrl)    ((erctrl)->eroll->control_type)
-#define QUANTIZATION(self)      ((self)->quant_rtools->tool_id)
+#define QUANTIZATION(self)      ((self)->quant_rtools->action_id)
 #define HAVE_OBJECT             (1 << 31)
 
 
@@ -54,10 +54,16 @@ bst_event_roll_controller_get_clipboard (void)
   return clipboard_cseq;
 }
 
+static void
+controller_reset_canvas_cursor (BstEventRollController *self)
+{
+  controller_update_canvas_cursor (self, self->canvas_rtools->action_id);
+}
+
 BstEventRollController*
-bst_event_roll_controller_new (BstEventRoll  *eroll,
-                               BstRadioTools *quant_rtools,
-                               BstRadioTools *canvas_rtools)
+bst_event_roll_controller_new (BstEventRoll   *eroll,
+                               GxkActionGroup *quant_rtools,
+                               GxkActionGroup *canvas_rtools)
 {
   BstEventRollController *self;
   
@@ -79,11 +85,11 @@ bst_event_roll_controller_new (BstEventRoll  *eroll,
 			 G_CONNECT_SWAPPED);
   self->quant_rtools = g_object_ref (quant_rtools);
   self->canvas_rtools = g_object_ref (canvas_rtools);
-  /* update from rtools */
+  /* update from atools */
   g_object_connect (self->canvas_rtools,
-                    "swapped_signal::set_tool", controller_update_canvas_cursor, self,
+                    "swapped_signal::changed", controller_reset_canvas_cursor, self,
                     NULL);
-  controller_update_canvas_cursor (self, self->canvas_rtools->tool_id);
+  controller_reset_canvas_cursor (self);
   
   return self;
 }
@@ -108,9 +114,9 @@ bst_event_roll_controller_unref (BstEventRollController *self)
   self->ref_count--;
   if (!self->ref_count)
     {
-      bst_radio_tools_dispose (self->canvas_rtools);
+      gxk_action_group_dispose (self->canvas_rtools);
       g_object_unref (self->canvas_rtools);
-      bst_radio_tools_dispose (self->quant_rtools);
+      gxk_action_group_dispose (self->quant_rtools);
       g_object_unref (self->quant_rtools);
       g_free (self);
     }
@@ -121,7 +127,7 @@ event_canvas_button_tool (BstEventRollController *self,
                           guint                   button,
                           guint                   have_object)
 {
-  switch (self->canvas_rtools->tool_id | /* user selected tool */
+  switch (self->canvas_rtools->action_id | /* user selected tool */
           (have_object ? HAVE_OBJECT : 0))
     {
     case BST_GENERIC_ROLL_TOOL_INSERT: /* background */
@@ -310,25 +316,26 @@ static void
 controller_update_canvas_cursor (BstEventRollController *self,
                                  BstGenericRollTool      tool)
 {
+  GxkScrollCanvas *scc = GXK_SCROLL_CANVAS (self->eroll);
   switch (tool)
     {
     case BST_GENERIC_ROLL_TOOL_INSERT:
-      bst_event_roll_set_canvas_cursor (self->eroll, GDK_PENCIL);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_PENCIL);
       break;
     case BST_GENERIC_ROLL_TOOL_RESIZE:
-      bst_event_roll_set_canvas_cursor (self->eroll, GDK_SB_V_DOUBLE_ARROW);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_SB_V_DOUBLE_ARROW);
       break;
     case BST_GENERIC_ROLL_TOOL_MOVE:
-      bst_event_roll_set_canvas_cursor (self->eroll, GDK_FLEUR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_FLEUR);
       break;
     case BST_GENERIC_ROLL_TOOL_DELETE:
-      bst_event_roll_set_canvas_cursor (self->eroll, GDK_TARGET);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_TARGET);
       break;
     case BST_GENERIC_ROLL_TOOL_SELECT:
-      bst_event_roll_set_canvas_cursor (self->eroll, GDK_CROSSHAIR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GDK_CROSSHAIR);
       break;
     default:
-      bst_event_roll_set_canvas_cursor (self->eroll, GXK_DEFAULT_CURSOR);
+      gxk_scroll_canvas_set_canvas_cursor (scc, GXK_DEFAULT_CURSOR);
       break;
     }
 }
@@ -342,14 +349,14 @@ move_start (BstEventRollController *self,
     {
       controller_update_canvas_cursor (self, BST_GENERIC_ROLL_TOOL_MOVE);
       gxk_status_set (GXK_STATUS_WAIT, _("Move Control Event"), NULL);
-      drag->state = BST_DRAG_CONTINUE;
-      if (bse_part_is_selected_event (part, self->obj_id))
+      drag->state = GXK_DRAG_CONTINUE;
+      if (bse_part_is_event_selected (part, self->obj_id))
 	self->sel_cseq = bse_part_control_seq_copy_shallow (bse_part_list_selected_controls (part, CONTROL_TYPE (self)));
     }
   else
     {
       gxk_status_set (GXK_STATUS_ERROR, _("Move Control Event"), _("No target"));
-      drag->state = BST_DRAG_HANDLED;
+      drag->state = GXK_DRAG_HANDLED;
     }
 }
 
@@ -373,7 +380,7 @@ move_group_motion (BstEventRollController *self,
                                CONTROL_TYPE (self),
                                pctrl->value);
     }
-  if (drag->type == BST_DRAG_DONE)
+  if (drag->type == GXK_DRAG_DONE)
     {
       bse_part_control_seq_free (self->sel_cseq);
       self->sel_cseq = NULL;
@@ -397,9 +404,14 @@ move_motion (BstEventRollController *self,
   new_tick = bst_event_roll_controller_quantize (self, drag->current_tick);
   if (new_tick != self->obj_tick)
     {
-      if (bse_part_change_control (part, self->obj_id, new_tick, CONTROL_TYPE (self), self->obj_value) != BSE_ERROR_NONE)
-        drag->state = BST_DRAG_ERROR;
-      self->obj_tick = new_tick;
+      BsePartControlSeq *cseq = bse_part_get_controls (part, new_tick, CONTROL_TYPE (self));
+      if (!cseq->n_pcontrols)    /* avoid overlap */
+        {
+          if (bse_part_change_control (part, self->obj_id, new_tick, CONTROL_TYPE (self), self->obj_value) != BSE_ERROR_NONE)
+            drag->state = GXK_DRAG_ERROR;
+          else
+            self->obj_tick = new_tick;
+        }
     }
 }
 
@@ -421,7 +433,7 @@ align_start (BstEventRollController *self,
 {
   bst_event_roll_init_segment (self->eroll, BST_SEGMENT_LINE);
   bst_event_roll_segment_start (self->eroll, drag->start_tick, drag->start_value);
-  drag->state = BST_DRAG_CONTINUE;
+  drag->state = GXK_DRAG_CONTINUE;
   gxk_status_set (GXK_STATUS_WAIT, _("Align Control Events"), NULL);
 }
 
@@ -430,7 +442,7 @@ align_motion (BstEventRollController *self,
               BstEventRollDrag       *drag)
 {
   bst_event_roll_segment_move_to (self->eroll, drag->current_tick, drag->current_value_raw);
-  if (drag->type == BST_DRAG_DONE)
+  if (drag->type == GXK_DRAG_DONE)
     {
       SfiProxy part = self->eroll->proxy;
       guint tick, duration, i;
@@ -482,7 +494,7 @@ insert_start (BstEventRollController *self,
   else /* no insertion */
     self->obj_id = 0;
   bst_status_eprintf (error, _("Insert Control Event"));
-  drag->state = BST_DRAG_HANDLED;
+  drag->state = GXK_DRAG_HANDLED;
 }
 
 static void
@@ -493,12 +505,12 @@ resize_start (BstEventRollController *self,
     {
       controller_update_canvas_cursor (self, BST_GENERIC_ROLL_TOOL_RESIZE);
       gxk_status_set (GXK_STATUS_WAIT, _("Resize Control Event"), NULL);
-      drag->state = BST_DRAG_CONTINUE;
+      drag->state = GXK_DRAG_CONTINUE;
     }
   else
     {
       gxk_status_set (GXK_STATUS_ERROR, _("Resize Control Event"), _("No target"));
-      drag->state = BST_DRAG_HANDLED;
+      drag->state = GXK_DRAG_HANDLED;
     }
 }
 
@@ -524,7 +536,7 @@ resize_motion (BstEventRollController *self,
       self->obj_value = drag->current_value;
       if (bse_part_change_control (part, self->obj_id, self->obj_tick, CONTROL_TYPE (self),
                                    self->obj_value) != BSE_ERROR_NONE)
-        drag->state = BST_DRAG_ERROR;
+        drag->state = GXK_DRAG_ERROR;
       bse_item_ungroup_undo (part);
     }
 }
@@ -548,7 +560,7 @@ delete_start (BstEventRollController *self,
     }
   else
     gxk_status_set (GXK_STATUS_ERROR, _("Delete Control Event"), _("No target"));
-  drag->state = BST_DRAG_HANDLED;
+  drag->state = GXK_DRAG_HANDLED;
 }
 
 static void
@@ -558,7 +570,7 @@ select_start (BstEventRollController *self,
   drag->start_tick = bst_event_roll_controller_quantize (self, drag->start_tick);
   bst_event_roll_set_view_selection (drag->eroll, drag->start_tick, 0);
   gxk_status_set (GXK_STATUS_WAIT, _("Select Region"), NULL);
-  drag->state = BST_DRAG_CONTINUE;
+  drag->state = GXK_DRAG_CONTINUE;
 }
 
 static void
@@ -570,7 +582,7 @@ select_motion (BstEventRollController *self,
   guint end_tick = MAX (drag->start_tick, drag->current_tick);
   
   bst_event_roll_set_view_selection (drag->eroll, start_tick, end_tick - start_tick);
-  if (drag->type == BST_DRAG_DONE)
+  if (drag->type == GXK_DRAG_DONE)
     {
       bse_part_select_controls_exclusive (part, start_tick, end_tick - start_tick, CONTROL_TYPE (self));
       bst_event_roll_set_view_selection (drag->eroll, 0, 0);
@@ -605,18 +617,18 @@ controller_canvas_drag (BstEventRollController *self,
     BstGenericRollTool tool;
     DragFunc start, motion, abort;
   } tool_table[] = {
-    { BST_GENERIC_ROLL_TOOL_INSERT, insert_resize_start,	resize_motion,  resize_abort,	},
-    { BST_GENERIC_ROLL_TOOL_ALIGN,	align_start,	align_motion,	align_abort,	},
-    { BST_GENERIC_ROLL_TOOL_RESIZE,	resize_start,	resize_motion,	resize_abort,	},
-    { BST_GENERIC_ROLL_TOOL_MOVE,		move_start,	move_motion,	move_abort,	},
-    { BST_GENERIC_ROLL_TOOL_DELETE,	delete_start,	NULL,		NULL,		},
-    { BST_GENERIC_ROLL_TOOL_SELECT,	select_start,	select_motion,	select_abort,	},
+    { BST_GENERIC_ROLL_TOOL_INSERT,     insert_resize_start,	resize_motion,  resize_abort,	},
+    { BST_GENERIC_ROLL_TOOL_ALIGN,	align_start,	        align_motion,	align_abort,	},
+    { BST_GENERIC_ROLL_TOOL_RESIZE,	resize_start,	        resize_motion,	resize_abort,	},
+    { BST_GENERIC_ROLL_TOOL_MOVE,	move_start,	        move_motion,	move_abort,	},
+    { BST_GENERIC_ROLL_TOOL_DELETE,	delete_start,	        NULL,		NULL,		},
+    { BST_GENERIC_ROLL_TOOL_SELECT,	select_start,	        select_motion,	select_abort,	},
   };
   guint i;
   
   // sfi_debug ("canvas drag event, tick=%d (valid=%d) value=%f", drag->current_tick, drag->current_valid, drag->current_value);
 
-  if (drag->type == BST_DRAG_START)
+  if (drag->type == GXK_DRAG_START)
     {
       BstGenericRollTool tool = BST_GENERIC_ROLL_TOOL_NONE;
       BsePartControlSeq *cseq;
@@ -676,23 +688,23 @@ controller_canvas_drag (BstEventRollController *self,
   g_return_if_fail (i < G_N_ELEMENTS (tool_table));
   switch (drag->type)
     {
-    case BST_DRAG_START:
+    case GXK_DRAG_START:
       if (tool_table[i].start)
 	tool_table[i].start (self, drag);
       break;
-    case BST_DRAG_MOTION:
-    case BST_DRAG_DONE:
+    case GXK_DRAG_MOTION:
+    case GXK_DRAG_DONE:
       if (tool_table[i].motion)
 	tool_table[i].motion (self, drag);
       break;
-    case BST_DRAG_ABORT:
+    case GXK_DRAG_ABORT:
       if (tool_table[i].abort)
 	tool_table[i].abort (self, drag);
       break;
     }
-  if (drag->type == BST_DRAG_DONE ||
-      drag->type == BST_DRAG_ABORT)
-    controller_update_canvas_cursor (self, self->canvas_rtools->tool_id);
+  if (drag->type == GXK_DRAG_DONE ||
+      drag->type == GXK_DRAG_ABORT)
+    controller_reset_canvas_cursor (self);
 }
 
 void
@@ -701,7 +713,7 @@ controller_vpanel_drag (BstEventRollController *self,
 {
   // sfi_debug ("vpanel drag event, tick=%d (valid=%d) value=%f", drag->current_tick, drag->current_valid, drag->current_value);
   
-  if (drag->type == BST_DRAG_START ||
-      drag->type == BST_DRAG_MOTION)
-    drag->state = BST_DRAG_CONTINUE;
+  if (drag->type == GXK_DRAG_START ||
+      drag->type == GXK_DRAG_MOTION)
+    drag->state = GXK_DRAG_CONTINUE;
 }
