@@ -23,46 +23,18 @@
 
 
 /* --- prototypes --- */
-static void	bst_file_dialog_class_init	(BstFileDialogClass	*class);
-static void	bst_file_dialog_init		(BstFileDialog		*fd);
 static void	bst_file_dialog_finalize	(GObject		*object);
 static void	bst_file_dialog_activate	(BstFileDialog		*self);
 
 
-/* --- variables --- */
-static GtkFileSelection *parent_class = NULL;
-
-
 /* --- functions --- */
-GType
-bst_file_dialog_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-	sizeof (BstFileDialogClass),
-	(GBaseInitFunc) NULL,
-	(GBaseFinalizeFunc) NULL,
-	(GClassInitFunc) bst_file_dialog_class_init,
-	NULL,   /* class_finalize */
-	NULL,   /* class_data */
-	sizeof (BstFileDialog),
-	0,      /* n_preallocs */
-	(GInstanceInitFunc) bst_file_dialog_init,
-      };
-      type = g_type_register_static (GXK_TYPE_DIALOG, "BstFileDialog", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstFileDialog, bst_file_dialog, GXK_TYPE_DIALOG);
 
 static void
 bst_file_dialog_class_init (BstFileDialogClass	*class)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   
-  parent_class = g_type_class_peek_parent (class);
-  
   gobject_class->finalize = bst_file_dialog_finalize;
 }
 
@@ -241,7 +213,7 @@ bst_file_dialog_finalize (GObject *object)
   bst_file_store_destroy (self->file_store);
   
   /* chain parent class' handler */
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_file_dialog_parent_class)->finalize (object);
 }
 
 static BstFileDialog*
@@ -413,6 +385,20 @@ bst_file_dialog_popup_open_project (gpointer parent_widget)
   return widget;
 }
 
+GtkWidget*
+bst_file_dialog_popup_select_file (gpointer parent_widget)
+{
+  BstFileDialog *self = bst_file_dialog_global_project ();
+  GtkWidget *widget = GTK_WIDGET (self);
+
+  bst_file_dialog_set_mode (self, parent_widget,
+			    BST_FILE_DIALOG_SELECT_FILE,
+			    _("Select File"), 0);
+  gxk_widget_showraise (widget);
+
+  return widget;
+}
+
 GtkWidget*
 bst_file_dialog_popup_select_dir (gpointer parent_widget)
 {
@@ -870,6 +856,7 @@ bst_file_dialog_activate (BstFileDialog *self)
     case BST_FILE_DIALOG_SAVE_INSTRUMENT:
       popdown = bst_file_dialog_save_instrument (self, file_name);
       break;
+    case BST_FILE_DIALOG_SELECT_FILE:
     case BST_FILE_DIALOG_SELECT_DIR:
       popdown = TRUE;   /* handled via BstFileDialogHandler and ->selected */
       break;
