@@ -21,6 +21,7 @@
 #include "bstsplash.h"
 #include "bstxkb.h"
 #include "bstgconfig.h"
+#include "bstskinconfig.h"
 #include "bstusermessage.h"
 #include "bstparam.h"
 #include "bstpreferences.h"
@@ -49,13 +50,6 @@ static gboolean     arg_force_xkb = FALSE;
 static gboolean     register_core_plugins = TRUE;
 static gboolean     register_ladspa_plugins = TRUE;
 static gboolean     register_scripts = TRUE;
-static const gchar *bst_rc_string =
-( "style'BstTooltips-style'"
-  "{"
-  "bg[NORMAL]={.94,.88,0.}"
-  "}"
-  "widget'gtk-tooltips'style'BstTooltips-style'"
-  "\n");
 
 
 /* --- functions --- */
@@ -88,6 +82,8 @@ main (int   argc,
   SfiRec *bseconfig;
   gchar *string;
   GSource *source;
+  gboolean parse_rc_file = TRUE;
+  gboolean save_rc_file = TRUE;
   guint i;
 
   /* initialize i18n */
@@ -147,20 +143,19 @@ main (int   argc,
   _bst_init_utils ();
   _bst_init_params ();
   _bst_gconfig_init ();
+  _bst_skin_config_init ();
   bst_splash_update_item (beast_splash, _("Language"));
 
-  /* GUI patchups
-   */
-  gtk_rc_parse_string (bst_rc_string);
-
   /* parse rc file
    */
-  if (TRUE)
+  if (parse_rc_file)
     {
       gchar *file_name = BST_STRDUP_RC_FILE ();
       bst_splash_update_item (beast_splash, _("RC File"));
       bst_rc_parse (file_name);
       g_free (file_name);
+      bst_splash_update_item (beast_splash, _("Skin RC"));
+      bst_skin_parse (bst_skin_config_rcfile ());
     }
 
   /* show splash images
@@ -338,6 +333,7 @@ main (int   argc,
    */
   if (!BST_RC_VERSION || strcmp (BST_RC_VERSION, BST_VERSION))
     {
+      save_rc_file = TRUE;
       bst_app_trigger_action (app, BST_ACTION_HELP_RELEASE_NOTES);
       bst_gconfig_set_rc_version (BST_VERSION);
     }
@@ -373,13 +369,13 @@ main (int   argc,
     }
   GDK_THREADS_ENTER ();
   
-  /* save rc file
-   */
-  if (TRUE)
+  /* save BSE configuration */
+  bse_server_save_preferences (BSE_SERVER);
+  if (save_rc_file)
     {
+      /* save BEAST configuration and accelerator map */
       gchar *file_name = BST_STRDUP_RC_FILE ();
       BseErrorType error = bst_rc_dump (file_name);
-      bse_server_save_preferences (BSE_SERVER);
       if (error)
 	g_warning ("failed to save rc-file \"%s\": %s", file_name, bse_error_blurb (error));
       g_free (file_name);
@@ -461,7 +457,7 @@ bst_early_parse_args (int    *argc_p,
 	    {
               bst_developer_hints = TRUE;
 	      bst_debug_extensions = TRUE;
-	      g_message ("enabling possibly harmfull debugging extensions due to '-:d'");
+	      g_message ("enabling possibly harmful debugging extensions due to '-:d'");
 	    }
 	  sfi_rec_set_bool (bseconfig, "debug-extensions", bst_debug_extensions);
 	  argv[i] = NULL;
@@ -519,16 +515,25 @@ bst_early_parse_args (int    *argc_p,
 	  argv[i] = NULL;
 	  exit (0);
 	}
+      else if (strcmp ("--skinrc", argv[i]) == 0 ||
+	       strncmp ("--skinrc=", argv[i], 9) == 0)
+        {
+          gchar *arg = argv[i][9 - 1] == '=' ? argv[i] + 9 : (argv[i + 1] ? argv[i + 1] : "");
+          bst_skin_config_set_rcfile (arg);
+        }
       else if (strcmp ("--print-dir", argv[i]) == 0 ||
-	       strncmp ("--print-dir=", argv[i], 13) == 0)
+	       strncmp ("--print-dir=", argv[i], 12) == 0)
 	{
-	  gchar *arg = argv[i][13 - 1] == '=' ? argv[i] + 13 : (argv[i + 1] ? argv[i + 1] : "");
+	  gchar *arg = argv[i][12 - 1] == '=' ? argv[i] + 12 : (argv[i + 1] ? argv[i + 1] : "");
+          gchar *freeme = NULL;
 	  if (strcmp (arg, "docs") == 0)
 	    g_print ("%s\n", BST_PATH_DOCS);
 	  else if (strcmp (arg, "images") == 0)
 	    g_print ("%s\n", BST_PATH_IMAGES);
 	  else if (strcmp (arg, "locale") == 0)
 	    g_print ("%s\n", BST_PATH_LOCALE);
+	  else if (strcmp (arg, "skins") == 0)
+	    g_print ("%s\n", freeme = BST_STRDUP_SKIN_PATH ());
 	  else if (strcmp (arg, "ladspa") == 0)
 	    g_print ("%s\n", BSE_PATH_LADSPA);
 	  else if (strcmp (arg, "plugins") == 0)
@@ -541,12 +546,15 @@ bst_early_parse_args (int    *argc_p,
 	    g_print ("%s\n", bse_server_get_script_path (BSE_SERVER));
 	  else if (strcmp (arg, "instruments") == 0)
 	    g_print ("%s\n", bse_server_get_instrument_path (BSE_SERVER));
+	  else if (strcmp (arg, "demo") == 0)
+	    g_print ("%s\n", bse_server_get_demo_path (BSE_SERVER));
 	  else
 	    {
 	      if (arg[0])
                 g_message ("no such resource path: %s", arg);
-	      g_message ("supported resource paths: docs, images, locale, ladspa, plugins, scripts, effects, instruments, samples");
+	      g_message ("supported resource paths: docs, images, locale, skins, ladspa, plugins, scripts, effects, instruments, demo, samples");
 	    }
+          g_free (freeme);
 	  exit (0);
 	}
     }
@@ -574,6 +582,7 @@ static void G_GNUC_NORETURN
 bst_exit_print_version (void)
 {
   const gchar *c;
+  gchar *freeme = NULL;
   /* hack: start BSE, so we can query it for paths, works since we immediately exit() afterwards */
   bse_init_async (NULL, NULL, NULL);
   sfi_glue_context_push (bse_init_glue_context ("BEAST"));
@@ -595,13 +604,15 @@ bst_exit_print_version (void)
   g_print ("\n");
   g_print ("Compiled for: %s\n", BST_ARCH_NAME);
   g_print ("\n");
-  g_print ("Locale Path:     %s\n", BST_PATH_LOCALE);
   g_print ("Doc Path:        %s\n", BST_PATH_DOCS);
   g_print ("Image Path:      %s\n", BST_PATH_IMAGES);
+  g_print ("Locale Path:     %s\n", BST_PATH_LOCALE);
+  g_print ("Skin Path:       %s\n", freeme = BST_STRDUP_SKIN_PATH());
   g_print ("Sample Path:     %s\n", bse_server_get_sample_path (BSE_SERVER));
   g_print ("Script Path:     %s\n", bse_server_get_script_path (BSE_SERVER));
   g_print ("Effect Path:     %s\n", bse_server_get_effect_path (BSE_SERVER));
   g_print ("Instrument Path: %s\n", bse_server_get_instrument_path (BSE_SERVER));
+  g_print ("Demo Path:       %s\n", bse_server_get_demo_path (BSE_SERVER));
   g_print ("Plugin Path:     %s\n", bse_server_get_plugin_path (BSE_SERVER));
   g_print ("LADSPA Path:     %s:$LADSPA_PATH\n", bse_server_get_ladspa_path (BSE_SERVER));
   g_print ("\n");
@@ -610,6 +621,7 @@ bst_exit_print_version (void)
   g_print ("the GNU General Public License which can be found in the\n");
   g_print ("BEAST source package. Sources, examples and contact\n");
   g_print ("information are available at http://beast.gtk.org\n");
+  g_free (freeme);
   exit (0);
 }
 
@@ -620,8 +632,9 @@ bst_print_blurb (void)
 #ifdef BST_WITH_XKB
   g_print ("  --force-xkb             force XKB keytable queries\n");
 #endif
+  g_print ("  --skinrc[=FILENAME]     skin resource file name\n");
   g_print ("  --print-dir[=RESOURCE]  print the directory for a specific resource\n");
-  g_print ("  --devel                 enrich the GUI with hints usefull for developers,\n");
+  g_print ("  --devel                 enrich the GUI with hints useful for developers,\n");
   g_print ("                          enable unstable plugins and experimental code\n");
   g_print ("  -h, --help              show this help message\n");
   g_print ("  -v, --version           print version and file paths\n");
@@ -667,6 +680,7 @@ beast_show_about_box (void)
     "Ville P\xc3\xa4tsi",
     /* general code and fixes */
     "Sam Hocevar",
+    "Nedko Arnaudov",
     "Alper Ersoy",
     "Ben Collver",
     "Tim Janik",
@@ -675,19 +689,26 @@ beast_show_about_box (void)
     "David A. Bartold",
     //"Tim Janik",
     //"Stefan Westerfeld",
-    /* languages */
-    "Metin Amiroff",
+    /* translations */
     "Alexandre Prokoudine",
-    "Danilo Segan",
-    "Christian Rose",
     "Christian Neumair",
-    "Miloslav Trmac",
-    "Duarte Loreto",
-    "Vincent van Adrighem",
+    "Christian Rose",
+    "Christophe Merlet",
     "Danilo Segan",
-    "Xavier Conde Rueda",
-    "Kostas Papadimas",
+    "Duarte Loreto",
+    "Dulmandakh Sukhbaatar",
+    "Francisco Javier F. Serrador",
     "Ismael Andres Rubio Rojas",
+    "Kees van den Broek",
+    "Kostas Papadimas",
+    "Laurent Dhima",
+    "Metin Amiroff",
+    "Miloslav Trmac",
+    "Robert Sedak",
+    "Tino Meinen",
+    "Vincent van Adrighem",
+    "Xavier Conde Rueda",
+    "Yelitza Louze",
     NULL
   };
   if (!GTK_WIDGET_VISIBLE (beast_splash))
