@@ -19,14 +19,9 @@
 #ifndef __BST_PREFERENCES_H__
 #define __BST_PREFERENCES_H__
 
-#include	"bstparamview.h"
-#include	"bstdialog.h"
-
-
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+#include "bstparamview.h"
 
+G_BEGIN_DECLS
 
 /* --- Gtk+ type macros --- */
 #define	BST_TYPE_PREFERENCES		(bst_preferences_get_type ())
@@ -44,11 +39,18 @@ struct _BstPreferences
 {
   GtkVBox	 parent_object;
 
-  BseGConfig	*gconf;
+  GtkNotebook	*notebook;
+
+  SfiRec	*bstrec;
+  SfiRing	*bstparams;
+
+  SfiRec        *skinrec;
+  SfiRing       *skinparams;
+
+  GParamSpec    *bsepspec;
+  SfiRec	*bserec;
+  SfiRing	*bseparams;
 
-  GtkWidget	*bse_param_view;
-  GtkWidget	*bst_param_view;
-  GtkWidget	*notebook;
   GtkWidget	*apply;
 };
 struct _BstPreferencesClass
@@ -59,29 +61,13 @@ struct _BstPreferencesClass
 
 /* --- prototypes --- */
 GtkType		 bst_preferences_get_type	(void);
-GtkWidget*	 bst_preferences_new		(BseGConfig	*gconf);
-void		 bst_preferences_rebuild	(BstPreferences *prefs);
-void		 bst_preferences_set_gconfig	(BstPreferences *prefs,
-						 BseGConfig     *gconf);
 void		 bst_preferences_apply		(BstPreferences *prefs);
 void		 bst_preferences_save		(BstPreferences *prefs);
 void		 bst_preferences_revert		(BstPreferences *prefs);
 void		 bst_preferences_default_revert	(BstPreferences *prefs);
 void		 bst_preferences_create_buttons (BstPreferences *prefs,
-						 BstDialog      *dialog);
-#define	bst_preferences_update	bst_preferences_revert
+						 GxkDialog      *dialog);
 
-
-/* --- rc file --- */
-BseErrorType	 bst_rc_dump			(const gchar	*file_name,
-						 BseGConfig     *gconf);
-BseErrorType	 bst_rc_parse			(const gchar	*file_name,
-						 BseGConfig     *gconf);
-
-
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BST_PREFERENCES_H__ */
