@@ -39,9 +39,6 @@ enum {
 
 
 /* --- prototypes --- */
-static void	  bst_snet_router_class_init	(BstSNetRouterClass	*klass);
-static void	  bst_snet_router_init		(BstSNetRouter		*self,
-						 BstSNetRouterClass     *class);
 static void	  bst_snet_router_destroy	(GtkObject		*object);
 static void	  bst_snet_router_finalize	(GObject		*object);
 static void	  bst_snet_router_item_added    (BstSNetRouter          *self,
@@ -84,32 +81,11 @@ static const GxkStockAction router_toolbar_actions[] = {
 
 
 /* --- static variables --- */
-static gpointer            parent_class = NULL;
 static BstSNetRouterClass *bst_snet_router_class = NULL;
 
 
 /* --- functions --- */
-GType
-bst_snet_router_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-        sizeof (BstSNetRouterClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) bst_snet_router_class_init,
-        NULL,   /* class_finalize */
-        NULL,   /* class_data */
-        sizeof (BstSNetRouter),
-        0,      /* n_preallocs */
-        (GInstanceInitFunc) bst_snet_router_init,
-      };
-      type = g_type_register_static (GNOME_TYPE_CANVAS, "BstSNetRouter", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstSNetRouter, bst_snet_router, GNOME_TYPE_CANVAS);
 
 static void
 bst_snet_router_class_init (BstSNetRouterClass *class)
@@ -118,7 +94,6 @@ bst_snet_router_class_init (BstSNetRouterClass *class)
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
-  parent_class = g_type_class_peek_parent (class);
   bst_snet_router_class = class;
   
   gobject_class->finalize = bst_snet_router_finalize;
@@ -142,8 +117,7 @@ filter_popup_modules (gpointer         predicate_data,
 }
 
 static void
-bst_snet_router_init (BstSNetRouter      *self,
-		      BstSNetRouterClass *class)
+bst_snet_router_init (BstSNetRouter      *self)
 {
   GnomeCanvas *canvas = GNOME_CANVAS (self);
   GxkActionList *al1, *al2, *canvas_modules, *toolbar_modules, *palette_modules;
@@ -301,7 +275,7 @@ bst_snet_router_destroy (GtkObject *object)
   if (self->palette)
     gtk_widget_destroy (self->palette);
   
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (bst_snet_router_parent_class)->destroy (object);
 }
 
 static void
@@ -312,7 +286,7 @@ bst_snet_router_finalize (GObject *object)
   g_object_unref (self->canvas_tool);
   g_object_unref (self->channel_toggle);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_snet_router_parent_class)->finalize (object);
 }
 
 static void
@@ -1018,8 +992,8 @@ bst_snet_router_event (GtkWidget *widget,
       break;
     }
   
-  if (!handled && GTK_WIDGET_CLASS (parent_class)->event)
-    handled = GTK_WIDGET_CLASS (parent_class)->event (widget, event);
+  if (!handled && GTK_WIDGET_CLASS (bst_snet_router_parent_class)->event)
+    handled = GTK_WIDGET_CLASS (bst_snet_router_parent_class)->event (widget, event);
   
   return handled;
 }
@@ -1032,7 +1006,7 @@ bst_snet_router_button_press (GtkWidget      *widget,
   gboolean handled;
   
   /* chain parent class' handler */
-  handled = GTK_WIDGET_CLASS (parent_class)->button_press_event (widget, event);
+  handled = GTK_WIDGET_CLASS (bst_snet_router_parent_class)->button_press_event (widget, event);
   
   if (!handled && event->button == 3 && self->canvas_popup)
     gxk_menu_popup (self->canvas_popup,
@@ -1047,7 +1021,13 @@ snet_router_tool2text (BstSNetRouter *self)
   GtkLabel *label = gxk_gadget_find (self->palette, "type-label");
   BseCategory *cat = ROUTER_TOOL (self) ? bse_category_from_id (ROUTER_TOOL (self)) : 0;
   const gchar *blurb = cat ? bse_type_blurb (cat->type) : NULL;
+  const gchar *authors = cat ? bse_type_authors (cat->type) : NULL;
+  const gchar *license = cat ? bse_type_license (cat->type) : NULL;
   const gchar *name = cat ? gxk_factory_path_get_leaf (cat->category) : NULL;
+  if (authors && !authors[0])
+    authors = NULL;
+  if (license && !license[0])
+    license = NULL;
   if (!blurb)
     {
       guint i;
@@ -1059,6 +1039,21 @@ snet_router_tool2text (BstSNetRouter *self)
           name = router_canvas_tools[i].name;
     }
   gxk_scroll_text_set (self->palette_text, blurb);
+  if (blurb && (authors || license))
+    gxk_scroll_text_append (self->palette_text, "\n");
+  if (authors)
+    {
+      gxk_scroll_text_append (self->palette_text, "\n");
+      gxk_scroll_text_append (self->palette_text, "Authors: ");
+      gxk_scroll_text_append (self->palette_text, authors);
+      gxk_scroll_text_append (self->palette_text, "\n");
+    }
+  if (license)
+    {
+      gxk_scroll_text_append (self->palette_text, "\n");
+      gxk_scroll_text_append (self->palette_text, "License: ");
+      gxk_scroll_text_append (self->palette_text, license);
+    }
   g_object_set (label, "label", name, NULL);
 }
 
