@@ -20,8 +20,6 @@
 
 
 /* --- prototypes --- */
-static void     bst_track_synth_dialog_class_init   (BstTrackSynthDialogClass   *class);
-static void     bst_track_synth_dialog_init         (BstTrackSynthDialog        *self);
 static void     bst_track_synth_dialog_finalize     (GObject                    *object);
 static void     bst_track_synth_dialog_activate     (BstTrackSynthDialog        *self);
 static gboolean bst_track_synth_dialog_delete_event (GtkWidget                  *widget,
@@ -32,32 +30,8 @@ static void     bst_track_synth_dialog_setup        (BstTrackSynthDialog *self,
                                                      SfiProxy             proxy);
 
 
-/* --- static variables --- */
-static gpointer parent_class = NULL;
-
-
 /* --- functions --- */
-GType
-bst_track_synth_dialog_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-        sizeof (BstTrackSynthDialogClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) bst_track_synth_dialog_class_init,
-        NULL,   /* class_finalize */
-        NULL,   /* class_data */
-        sizeof (BstTrackSynthDialog),
-        0,      /* n_preallocs */
-        (GInstanceInitFunc) bst_track_synth_dialog_init,
-      };
-      type = g_type_register_static (GXK_TYPE_DIALOG, "BstTrackSynthDialog", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstTrackSynthDialog, bst_track_synth_dialog, GXK_TYPE_DIALOG);
 
 static void
 bst_track_synth_dialog_class_init (BstTrackSynthDialogClass *class)
@@ -65,8 +39,6 @@ bst_track_synth_dialog_class_init (BstTrackSynthDialogClass *class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
   
-  parent_class = g_type_class_peek_parent (class);
-  
   gobject_class->finalize = bst_track_synth_dialog_finalize;
 
   widget_class->delete_event = bst_track_synth_dialog_delete_event;
@@ -170,7 +142,7 @@ bst_track_synth_dialog_finalize (GObject *object)
   bst_track_synth_dialog_setup (self, NULL, NULL, 0);
 
   /* chain parent class' handler */
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_track_synth_dialog_parent_class)->finalize (object);
 }
 
 static gboolean
@@ -181,7 +153,7 @@ bst_track_synth_dialog_delete_event (GtkWidget   *widget,
   if (self->pstore)
     bst_proxy_seq_store_set (self->pstore, NULL);
   /* chain parent class' handler */
-  return GTK_WIDGET_CLASS (parent_class)->delete_event (widget, event);
+  return GTK_WIDGET_CLASS (bst_track_synth_dialog_parent_class)->delete_event (widget, event);
 }
 
 static void
