@@ -24,8 +24,6 @@
 #define	SCROLLBAR_SPACING (3) /* from gtkscrolledwindow.c:DEFAULT_SCROLLBAR_SPACING */
 
 /* --- prototypes --- */
-static void	bst_track_view_class_init	(BstTrackViewClass	*klass);
-static void	bst_track_view_init		(BstTrackView		*self);
 static void	bst_track_view_finalize		(GObject		*object);
 static gboolean track_view_action_check         (gpointer                data,
                                                  gulong                  action);
@@ -68,32 +66,8 @@ static const GxkStockAction track_view_actions[] = {
 };
 
 
-/* --- variables --- */
-static gpointer parent_class = NULL;
-
-
 /* --- functions --- */
-GType
-bst_track_view_get_type (void)
-{
-  static GType type = 0;
-  if (!type)
-    {
-      static const GTypeInfo type_info = {
-        sizeof (BstTrackViewClass),
-        (GBaseInitFunc) NULL,
-        (GBaseFinalizeFunc) NULL,
-        (GClassInitFunc) bst_track_view_class_init,
-        NULL,   /* class_finalize */
-        NULL,   /* class_data */
-        sizeof (BstTrackView),
-        0,      /* n_preallocs */
-        (GInstanceInitFunc) bst_track_view_init,
-      };
-      type = g_type_register_static (BST_TYPE_ITEM_VIEW, "BstTrackView", &type_info, 0);
-    }
-  return type;
-}
+G_DEFINE_TYPE (BstTrackView, bst_track_view, BST_TYPE_ITEM_VIEW);
 
 static void
 bst_track_view_class_init (BstTrackViewClass *class)
@@ -101,8 +75,6 @@ bst_track_view_class_init (BstTrackViewClass *class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (class);
   BstItemViewClass *item_view_class = BST_ITEM_VIEW_CLASS (class);
 
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class->finalize = bst_track_view_finalize;
 
   item_view_class->set_container = track_view_set_container;
@@ -120,7 +92,7 @@ bst_track_view_finalize (GObject *object)
   if (self->tctrl)
     bst_track_roll_controller_unref (self->tctrl);
 
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (bst_track_view_parent_class)->finalize (object);
 }
 
 GtkWidget*
@@ -383,19 +355,6 @@ get_track (gpointer data,
   return bst_item_view_get_proxy (BST_ITEM_VIEW (data), row);
 }
 
-static void
-update_selection (BstTrackView     *self)
-{
-  BstItemView *iview = BST_ITEM_VIEW (self);
-  if (self->troll && iview->tree)
-    {
-      bst_track_roll_set_prelight_row (self->troll,
-				       gxk_tree_view_get_selected_row (iview->tree));
-      if (GTK_WIDGET_DRAWABLE (self->troll))
-	gxk_window_process_next (GTK_WIDGET (self->troll)->window, TRUE);
-    }
-}
-
 static void
 track_view_marks_changed (BstTrackView *self)
 {
@@ -404,9 +363,9 @@ track_view_marks_changed (BstTrackView *self)
     {
       SfiInt lleft, lright, pointer;
       bse_proxy_get (song, "loop_left", &lleft, "loop_right", &lright, "tick_pointer", &pointer, NULL);
-      bst_track_roll_set_mark (self->troll, 1, lleft, lleft >= 0 ? BST_MARKER_GREEN : 0);
-      bst_track_roll_set_mark (self->troll, 2, lright, lright >= 0 ? BST_MARKER_BLUE : 0);
-      bst_track_roll_set_mark (self->troll, 3, pointer, pointer >= 0 ? BST_MARKER_RED : 0);
+      bst_track_roll_set_marker (self->troll, 1, lleft, lleft >= 0 ? BST_TRACK_ROLL_MARKER_LOOP : 0);
+      bst_track_roll_set_marker (self->troll, 2, lright, lright >= 0 ? BST_TRACK_ROLL_MARKER_LOOP : 0);
+      bst_track_roll_set_marker (self->troll, 3, pointer, pointer >= 0 ? BST_TRACK_ROLL_MARKER_POS : 0);
     }
 }
 
@@ -488,27 +447,16 @@ bst_track_view_init (BstTrackView *self)
                               "visible", TRUE,
 			      "parent", gxk_gadget_find (gadget, "track-area"),
 			      NULL);
-  gxk_nullify_on_destroy (self->troll, &self->troll);
-  bst_track_roll_set_hadjustment (self->troll, gtk_range_get_adjustment (GTK_RANGE (trackhs)));
-  bst_track_roll_set_vadjustment (self->troll, gtk_range_get_adjustment (GTK_RANGE (vscroll)));
+  gxk_nullify_in_object (self, &self->troll);
+  gxk_scroll_canvas_set_hadjustment (GXK_SCROLL_CANVAS (self->troll), gtk_range_get_adjustment (GTK_RANGE (trackhs)));
+  gxk_scroll_canvas_set_vadjustment (GXK_SCROLL_CANVAS (self->troll), gtk_range_get_adjustment (GTK_RANGE (vscroll)));
   bst_track_roll_set_track_callback (self->troll, self, get_track);
   track_view_marks_changed (self);
 
   /* link track roll to tree view and list model */
   g_signal_connect_object (tsel, "changed",
-			   G_CALLBACK (update_selection),
-			   self, G_CONNECT_SWAPPED | G_CONNECT_AFTER);
-  bst_track_roll_set_size_callbacks (self->troll,
-				     iview->tree,
-				     gxk_tree_view_get_bin_window_pos,
-				     gxk_tree_view_get_row_area,
-				     gxk_tree_view_get_row_from_coord);
-  g_signal_connect_object (iview->tree, "size_allocate",
-			   G_CALLBACK (bst_track_roll_reallocate),
+			   G_CALLBACK (bst_track_roll_reselect),
 			   self->troll, G_CONNECT_SWAPPED | G_CONNECT_AFTER);
-  g_signal_connect_object (iview->tree, "size_allocate",
-			   G_CALLBACK (update_selection),
-			   self, G_CONNECT_SWAPPED | G_CONNECT_AFTER);
   g_signal_connect_object (self->troll, "select-row",
 			   G_CALLBACK (gxk_tree_view_focus_row),
 			   iview->tree, G_CONNECT_SWAPPED);
@@ -528,7 +476,7 @@ bst_track_view_init (BstTrackView *self)
   
   /* add repeat toggle */
   self->repeat_toggle = gxk_gadget_find (gadget, "repeat-toggle");
-  gxk_nullify_on_destroy (self->repeat_toggle, &self->repeat_toggle);
+  gxk_nullify_in_object (self, &self->repeat_toggle);
   g_object_connect (self->repeat_toggle, "swapped_signal::toggled", track_view_repeat_toggled, self, NULL);
   track_view_repeat_changed (self);
 
@@ -589,7 +537,7 @@ track_view_pointer_changed (BstTrackView *self,
 			    SfiInt        position)
 {
   if (self->troll)
-    bst_track_roll_set_mark (self->troll, 3, position, position >= 0 ? BST_MARKER_RED : 0);
+    bst_track_roll_set_marker (self->troll, 3, position, position >= 0 ? BST_TRACK_ROLL_MARKER_POS : 0);
 }
 
 static void
@@ -603,7 +551,9 @@ track_view_set_container (BstItemView *iview,
 			  "any_signal", track_view_marks_changed, self,
 			  "any_signal", track_view_repeat_changed, self,
 			  NULL);
-  BST_ITEM_VIEW_CLASS (parent_class)->set_container (iview, new_container);
+  BST_ITEM_VIEW_CLASS (bst_track_view_parent_class)->set_container (iview, new_container);
+  if (self->troll)
+    bst_track_roll_setup (self->troll, iview->container ? iview->tree : NULL, iview->container);
   if (BSE_IS_SONG (iview->container))
     {
       bst_track_roll_controller_set_song (self->tctrl, iview->container);
@@ -630,7 +580,7 @@ static void
 track_view_listen_on (BstItemView *iview,
 		      SfiProxy     item)
 {
-  BST_ITEM_VIEW_CLASS (parent_class)->listen_on (iview, item);
+  BST_ITEM_VIEW_CLASS (bst_track_view_parent_class)->listen_on (iview, item);
   bse_proxy_connect (item,
 		     "signal::changed", track_changed, iview,
 		     NULL);
@@ -654,7 +604,7 @@ track_view_unlisten_on (BstItemView *iview,
 			"any_signal", track_changed, iview,
 			"any_signal", track_property_changed, iview,
 			NULL);
-  BST_ITEM_VIEW_CLASS (parent_class)->unlisten_on (iview, item);
+  BST_ITEM_VIEW_CLASS (bst_track_view_parent_class)->unlisten_on (iview, item);
 }
 
 static void
