@@ -161,7 +161,7 @@ bst_stock_register_icon (const gchar    *stock_id,
   
   if (!gtk_icon_factory_lookup (stock_icon_factory, stock_id))
     {
-      GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data (g_memdup (pixels, rowstride * height * bytes_per_pixel),
+      GdkPixbuf *pixbuf = gdk_pixbuf_new_from_data (g_memdup (pixels, rowstride * height),
                                                     GDK_COLORSPACE_RGB, bytes_per_pixel == 4,
                                                     8, width, height,
                                                     width * bytes_per_pixel,
@@ -393,7 +393,6 @@ bst_hpack0 (const gchar *first_location,
   return box;
 }
 
-
 void
 bst_action_list_add_cat (GxkActionList          *alist,
                          BseCategory            *cat,
@@ -1195,25 +1194,10 @@ bst_xpm_view_create (const gchar **xpm,
 /* --- file utils --- */
 #include <sfi/sfistore.h>
 
-static gboolean
-song_name_scanner (SfiRStore      *rstore,
-                   gpointer        data)
-{
-  if (g_scanner_peek_next_token (rstore->scanner) == G_TOKEN_STRING)
-    {
-      g_scanner_get_next_token (rstore->scanner);
-      if (strncmp (rstore->scanner->value.v_string, "BseSong::", 9) == 0)
-        {
-          gchar **rval = data;
-          *rval = g_strdup (rstore->scanner->value.v_string + 9);
-          return FALSE;
-        }
-    }
-  return TRUE;
-}
-
 gchar*
-bst_file_scan_song_name (const gchar *file)
+bst_file_scan_find_key (const gchar *file,
+                        const gchar *key,
+                        const gchar *value_prefix)
 {
   SfiRStore *rstore;
   
@@ -1222,8 +1206,26 @@ bst_file_scan_song_name (const gchar *file)
   rstore = sfi_rstore_new_open (file);
   if (rstore)
     {
+      guint l = value_prefix ? strlen (value_prefix) : 0;
       gchar *name = NULL;
-      sfi_rstore_quick_scan (rstore, "container-child", song_name_scanner, &name);
+      while (!g_scanner_eof (rstore->scanner))
+        {
+          if (g_scanner_get_next_token (rstore->scanner) == '(' &&
+              g_scanner_peek_next_token (rstore->scanner) == G_TOKEN_IDENTIFIER)
+            {
+              g_scanner_get_next_token (rstore->scanner);
+              if (strcmp (rstore->scanner->value.v_identifier, key) == 0 &&
+                  g_scanner_peek_next_token (rstore->scanner) == G_TOKEN_STRING)
+                {
+                  g_scanner_get_next_token (rstore->scanner);
+                  if (!l || strncmp (rstore->scanner->value.v_string, value_prefix, l) == 0)
+                    {
+                      name = g_strdup (rstore->scanner->value.v_string + l);
+                      break;
+                    }
+                }
+            }
+        }
       sfi_rstore_destroy (rstore);
       return name;
     }
@@ -1250,35 +1252,51 @@ _bst_log_scan_keys (void)
 
 
 /* --- IDL pspecs --- */
-#define sfidl_pspec_Int(group, name, nick, blurb, dflt, min, max, step, hints)  \
+#define sfidl_pspec_Bool(group, name, nick, blurb, dflt, hints) \
+  sfi_pspec_set_group (sfi_pspec_bool (name, nick, blurb, dflt, hints), group)
+#define sfidl_pspec_Bool_default(group, name) \
+  sfi_pspec_set_group (sfi_pspec_bool (name, NULL, NULL, FALSE, SFI_PARAM_STANDARD), group)
+#define sfidl_pspec_Int(group, name, nick, blurb, dflt, min, max, step, hints) \
   sfi_pspec_set_group (sfi_pspec_int (name, nick, blurb, dflt, min, max, step, hints), group)
-#define sfidl_pspec_Int_default(group, name)                                            \
+#define sfidl_pspec_Int_default(group, name) \
   sfi_pspec_set_group (sfi_pspec_int (name, NULL, NULL, 0, G_MININT, G_MAXINT, 256, SFI_PARAM_STANDARD), group)
 #define sfidl_pspec_UInt(group, name, nick, blurb, dflt, hints) \
   sfi_pspec_set_group (sfi_pspec_int (name, nick, blurb, dflt, 0, G_MAXINT, 1, hints), group)
 #define sfidl_pspec_Real(group, name, nick, blurb, dflt, min, max, step, hints) \
   sfi_pspec_set_group (sfi_pspec_real (name, nick, blurb, dflt, min, max, step, hints), group)
-#define sfidl_pspec_Real_default(group, name)                                           \
+#define sfidl_pspec_Real_default(group, name) \
   sfi_pspec_set_group (sfi_pspec_real (name, NULL, NULL, 0, -SFI_MAXREAL, SFI_MAXREAL, 10, SFI_PARAM_STANDARD), group)
-#define sfidl_pspec_Bool(group, name, nick, blurb, dflt, hints)                 \
-  sfi_pspec_set_group (sfi_pspec_bool (name, nick, blurb, dflt, hints), group)
-#define sfidl_pspec_Bool_default(group, name)                                           \
-  sfi_pspec_set_group (sfi_pspec_bool (name, NULL, NULL, FALSE, SFI_PARAM_STANDARD), group)
-#define sfidl_pspec_Note(group, name, nick, blurb, dflt, hints)                 \
+#define sfidl_pspec_Note(group, name, nick, blurb, dflt, hints) \
   sfi_pspec_set_group (sfi_pspec_note (name, nick, blurb, dflt, hints), group)
-#define sfidl_pspec_String(group, name, nick, blurb, dflt, hints)                       \
-  sfi_pspec_set_group (sfi_pspec_string (name, nick, blurb, dflt, hints), group)
-#define sfidl_pspec_String_default(group, name)                                 \
-  sfi_pspec_set_group (sfi_pspec_string (name, NULL, NULL, NULL, SFI_PARAM_STANDARD), group)
-#define sfidl_pspec_Proxy_default(group, name)                                          \
+#define sfidl_pspec_Choice(group, name, nick, blurb, dval, options, cvalues) \
+  sfi_pspec_set_group (sfi_pspec_choice (name, nick, blurb, dval, cvalues, SFI_PARAM_STANDARD), group)
+#define sfidl_pspec_Choice_default(group, name, cvalues) \
+  sfidl_pspec_Choice (group, name, NULL, NULL, NULL, SFI_PARAM_STANDARD, cvalues)
+#define sfidl_pspec_String(group, name, nick, blurb, dflt, options) \
+  sfi_pspec_set_group (sfi_pspec_string (name, nick, blurb, dflt, options), group)
+#define sfidl_pspec_String_default(group, name) \
+  sfidl_pspec_String (group, name, NULL, NULL, NULL, SFI_PARAM_STANDARD)
+#define sfidl_pspec_BBlock(group, name, nick, blurb, options) \
+  sfi_pspec_set_group (sfi_pspec_bblock (name, nick, blurb, options), group)
+#define sfidl_pspec_BBlock_default(group, name) \
+  sfidl_pspec_BBlock (group, name, NULL, NULL, SFI_PARAM_STANDARD)
+#define sfidl_pspec_FBlock(group, name, nick, blurb, options) \
+  sfi_pspec_set_group (sfi_pspec_fblock (name, nick, blurb, options), group)
+#define sfidl_pspec_FBlock_default(group, name) \
+  sfidl_pspec_FBlock (group, name, NULL, NULL, SFI_PARAM_STANDARD)
+#define sfidl_pspec_Rec(group, name, nick, blurb, options) \
+  sfi_pspec_set_group (sfi_pspec_rec_generic (name, nick, blurb, options), group)
+#define sfidl_pspec_Rec_default(group, name, fields) \
+  sfidl_pspec_Rec (group, name, NULL, NULL, SFI_PARAM_STANDARD)
+#define sfidl_pspec_Record(group, name, nick, blurb, options, fields) \
+  sfi_pspec_set_group (sfi_pspec_rec (name, nick, blurb, fields, options), group)
+#define sfidl_pspec_Record_default(group, name, fields) \
+  sfidl_pspec_Record (group, name, NULL, NULL, SFI_PARAM_STANDARD, fields)
+#define sfidl_pspec_Sequence(group, name, nick, blurb, options, element) \
+  sfi_pspec_set_group (sfi_pspec_seq (name, nick, blurb, element, options), group)
+#define sfidl_pspec_Sequence_default(group, name, element) \
+  sfidl_pspec_Sequence (group, name, NULL, NULL, SFI_PARAM_STANDARD, element)
+#define sfidl_pspec_Proxy_default(group, name) \
   sfi_pspec_set_group (sfi_pspec_proxy (name, NULL, NULL, SFI_PARAM_STANDARD), group)
-#define sfidl_pspec_Seq(group, name, nick, blurb, hints, element_pspec)         \
-  sfi_pspec_set_group (sfi_pspec_seq (name, nick, blurb, element_pspec, hints), group)
-#define sfidl_pspec_Rec(group, name, nick, blurb, hints, fields)                        \
-  sfi_pspec_set_group (sfi_pspec_rec (name, nick, blurb, fields, hints), group)
-#define sfidl_pspec_Rec_default(group, name, fields)                                    \
-  sfi_pspec_set_group (sfi_pspec_rec (name, NULL, NULL, fields, SFI_PARAM_STANDARD), group)
-#define sfidl_pspec_BBlock(group, name, nick, blurb, hints)                             \
-  sfi_pspec_set_group (sfi_pspec_bblock (name, nick, blurb, hints), group)
 /* --- generated type IDs and SFIDL types --- */
 #include "bstgentypes.c"        /* type id defs */
