@@ -15,10 +15,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
+#include "bstutils.h"	/* for GScanner */
 #include "bstxframe.h"
 
-#include "bstutils.h"
-
 
 enum {
   PARAM_0,
@@ -28,8 +27,6 @@ enum {
 
 
 /* --- prototypes --- */
-static void     bst_xframe_class_init                 (BstXFrameClass	*class);
-static void     bst_xframe_init                       (BstXFrame	*xframe);
 static void     bst_xframe_destroy                    (GtkObject	*object);
 static void     bst_xframe_set_property		      (GObject		*object,
 						       guint		 prop_id,
@@ -59,37 +56,11 @@ static void     bst_xframe_size_allocate_cover        (GtkWidget	*widget,
 
 
 /* --- variables --- */
-static gpointer parent_class = NULL;
 static guint    signal_button_check = 0;
 
 
 /* --- functions --- */
-GType
-bst_xframe_get_type (void)
-{
-  static GType object_type = 0;
-
-  if (!object_type)
-    {
-      static const GTypeInfo object_info = {
-	sizeof (BstXFrameClass),
-	(GBaseInitFunc) NULL,
-	(GBaseFinalizeFunc) NULL,
-	(GClassInitFunc) bst_xframe_class_init,
-	NULL,   /* class_finalize */
-	NULL,   /* class_data */
-	sizeof (BstXFrame),
-	0,      /* n_preallocs */
-	(GInstanceInitFunc) bst_xframe_init,
-      };
-
-      object_type = g_type_register_static (GTK_TYPE_FRAME,
-					    "BstXFrame",
-					    &object_info, 0);
-    }
-
-  return object_type;
-}
+G_DEFINE_TYPE (BstXFrame, bst_xframe, GTK_TYPE_FRAME);
 
 static void
 bst_xframe_class_init (BstXFrameClass *class)
@@ -98,8 +69,6 @@ bst_xframe_class_init (BstXFrameClass *class)
   GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
 
-  parent_class = g_type_class_peek_parent (class);
-
   gobject_class->set_property = bst_xframe_set_property;
   gobject_class->get_property = bst_xframe_get_property;
   object_class->destroy = bst_xframe_destroy;
@@ -139,7 +108,7 @@ bst_xframe_init (BstXFrame *xframe)
   xframe->button_down = 0;
   xframe->allocation_valid = FALSE;
   xframe->entered = FALSE;
-  g_object_set (xframe, "shadow_type", GTK_SHADOW_NONE, NULL);
+  g_object_set (xframe, "visible", TRUE, "shadow_type", GTK_SHADOW_NONE, NULL);
 }
 
 static void
@@ -150,7 +119,7 @@ bst_xframe_destroy (GtkObject *object)
   if (xframe->cover)
     bst_xframe_set_cover_widget (xframe, NULL, FALSE);
 
-  GTK_OBJECT_CLASS (parent_class)->destroy (object);
+  GTK_OBJECT_CLASS (bst_xframe_parent_class)->destroy (object);
 }
 
 static void
@@ -224,7 +193,7 @@ bst_xframe_size_allocate (GtkWidget     *widget,
 {
   BstXFrame *xframe = BST_XFRAME (widget);
 
-  GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
+  GTK_WIDGET_CLASS (bst_xframe_parent_class)->size_allocate (widget, allocation);
 
   bst_xframe_resize (xframe);
 }
@@ -236,7 +205,7 @@ bst_xframe_realize (GtkWidget *widget)
   GdkWindowAttr attributes;
   gint attributes_mask;
   
-  GTK_WIDGET_CLASS (parent_class)->realize (widget);
+  GTK_WIDGET_CLASS (bst_xframe_parent_class)->realize (widget);
 
   attributes.window_type = GDK_WINDOW_CHILD;
   attributes.x = widget->allocation.x;
@@ -266,7 +235,7 @@ bst_xframe_unrealize (GtkWidget *widget)
   gdk_window_destroy (xframe->iwindow);
   xframe->iwindow = NULL;
 
-  GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
+  GTK_WIDGET_CLASS (bst_xframe_parent_class)->unrealize (widget);
 }
 
 static void
@@ -274,7 +243,7 @@ bst_xframe_map (GtkWidget *widget)
 {
   BstXFrame *xframe = BST_XFRAME (widget);
 
-  GTK_WIDGET_CLASS (parent_class)->map (widget);
+  GTK_WIDGET_CLASS (bst_xframe_parent_class)->map (widget);
 
   gdk_window_show (xframe->iwindow);
   gdk_window_lower (xframe->iwindow);
@@ -287,7 +256,7 @@ bst_xframe_unmap (GtkWidget *widget)
 
   gdk_window_hide (xframe->iwindow);
 
-  GTK_WIDGET_CLASS (parent_class)->unmap (widget);
+  GTK_WIDGET_CLASS (bst_xframe_parent_class)->unmap (widget);
 }
 
 static gint
