@@ -22,17 +22,27 @@
 #include <sfi/glib-extra.h>
 #include <gtk/gtk.h>
 
+#include <gxk/glewidgets.h>
+#include <gxk/gxkaction.h>
+#include <gxk/gxkauxwidgets.h>
 #include <gxk/gxkcanvas.h>
 #include <gxk/gxkcellrendererpopup.h>
 #include <gxk/gxkdialog.h>
+#include <gxk/gxkgadget.h>
+#include <gxk/gxkgadgetfactory.h>
 #include <gxk/gxkglobals.h>
 #include <gxk/gxkled.h>
 #include <gxk/gxklistwrapper.h>
+#include <gxk/gxkparam.h>
+#include <gxk/gxklogadjustment.h>
 #include <gxk/gxkpolygon.h>
+#include <gxk/gxkracktable.h>
+#include <gxk/gxkrackitem.h>
+#include <gxk/gxkscrollcanvas.h>
+#include <gxk/gxksimplelabel.h>
 #include <gxk/gxkstatusbar.h>
 #include <gxk/gxkstock.h>
 #include <gxk/gxktexttools.h>
-#include <gxk/gxktoolbar.h>
 #include <gxk/gxkutils.h>
 
 #endif /* __GXK_H__ */
