@@ -149,7 +149,7 @@ gxk_dialog_init (GxkDialog *self)
                              "spacing", 0,
                              "parent", window,
                              NULL);
-  gxk_nullify_in_object (self->mbox, &self->mbox, self);
+  gxk_nullify_in_object (self, &self->mbox);
   
   /* user vbox */
   self->vbox = g_object_new (GTK_TYPE_VBOX,
@@ -158,11 +158,11 @@ gxk_dialog_init (GxkDialog *self)
                              "spacing", 0,
                              "parent", self->mbox,
                              NULL);
-  gxk_nullify_in_object (self->vbox, &self->vbox, self);
+  gxk_nullify_in_object (self, &self->vbox);
   
   /* status bar */
   self->status_bar = gxk_status_bar_create ();
-  gxk_nullify_in_object (self->status_bar, &self->status_bar, self);
+  gxk_nullify_in_object (self, &self->status_bar);
   gtk_box_pack_end (GTK_BOX (self->mbox), self->status_bar, FALSE, FALSE, 0);
   
   /* button box */
@@ -172,14 +172,14 @@ gxk_dialog_init (GxkDialog *self)
                              "spacing", GXK_INNER_PADDING,
                              "border_width", GXK_INNER_PADDING,
                              NULL);
-  gxk_nullify_in_object (self->hbox, &self->hbox, self);
+  gxk_nullify_in_object (self, &self->hbox);
   gtk_box_pack_end (GTK_BOX (self->mbox), self->hbox, FALSE, TRUE, GXK_INNER_PADDING);
   
   /* separator */
   self->sep = g_object_new (GTK_TYPE_HSEPARATOR,
                             "visible", FALSE,
                             NULL);
-  gxk_nullify_in_object (self->sep, &self->sep, self);
+  gxk_nullify_in_object (self, &self->sep);
   gtk_box_pack_end (GTK_BOX (self->mbox), self->sep, FALSE, FALSE, GXK_INNER_PADDING);
 }
 
@@ -560,12 +560,15 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
     }
 
 #if defined (__linux__)         // FIXME: use gtk_window_activate_key() once exposed
-  /* we're iverriding the GtkWindow implementation here to give
+  /* we're overriding the GtkWindow implementation here to give
    * the focus widget precedence over unmodified accelerators
    * before the accelerator activation scheme.
    */
-  if (!handled && event->state & ~GDK_SHIFT_MASK)
+
+  /* invoke control/alt accelerators */
+  if (!handled && event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK))
     handled = _gtk_window_activate_key (window, event);
+  /* invoke focus widget handlers */
   if (!handled)
     {
       GtkWidget *focus = window->focus_widget;
@@ -587,9 +590,10 @@ gxk_dialog_key_press_event (GtkWidget   *widget,
       if (focus)
         g_object_unref (focus);
     }
-  if (!handled && !(event->state & ~GDK_SHIFT_MASK))
+  /* invoke non-(control/alt) accelerators */
+  if (!handled && !(event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)))
     handled = _gtk_window_activate_key (window, event);
-  /* chain up bypassing gtk_window_key_press(), invokes binding set */
+  /* chain up, bypassing gtk_window_key_press(), to invoke binding set */
   if (!handled)
     handled = GTK_WIDGET_CLASS (g_type_class_peek (g_type_parent (GTK_TYPE_WINDOW)))->key_press_event (widget, event);
 #else
