@@ -388,6 +388,45 @@ gxk_color_alloc (GdkColormap *colormap,
     g_message ("failed to allocate color: { %d, %d, %d }", color->red, color->green, color->blue);
 }
 
+GdkColor
+gdk_color_from_rgb (guint rgb_value)
+{
+  GdkColor c = { 0, };
+  c.red = (rgb_value >> 16) & 0xff;
+  c.green = (rgb_value >> 8) & 0xff;
+  c.blue = rgb_value & 0xff;
+  c.red *= 0x0101;
+  c.green *= 0x0101;
+  c.blue *= 0x0101;
+  return c;
+}
+
+GdkColor
+gdk_color_from_argb (guint rgb_value)
+{
+  GdkColor c = { 0, };
+  c.red = (rgb_value >> 16) & 0xff;
+  c.green = (rgb_value >> 8) & 0xff;
+  c.blue = rgb_value & 0xff;
+  c.red *= 0x0101;
+  c.green *= 0x0101;
+  c.blue *= 0x0101;
+  return c;
+}
+
+GdkColor
+gdk_color_from_rgba (guint rgb_value)
+{
+  GdkColor c = { 0, };
+  c.red = (rgb_value >> 24) & 0xff;
+  c.green = (rgb_value >> 16) & 0xff;
+  c.blue = (rgb_value >> 8) & 0xff;
+  c.red *= 0x0101;
+  c.green *= 0x0101;
+  c.blue *= 0x0101;
+  return c;
+}
+
 /**
  * gxk_widget_make_insensitive
  * @widget: a valid GtkWidget
@@ -445,7 +484,7 @@ idle_showraiser (gpointer data)
  * @widget: a valid #GtkWidget
  *
  * Defers showing and raising this widget like gxk_widget_showraise()
- * until the next idle handler is run. This is usefull if other things
+ * until the next idle handler is run. This is useful if other things
  * are pending which need to be processed first, for instance hiding
  * other toplevels or constructing remaining parts of the widget hierarchy.
  */
@@ -487,7 +526,7 @@ idle_shower (GtkWidget **widget_p)
  * @widget: a valid #GtkWidget
  *
  * Defer showing this widget until the next idle handler
- * is run. This is usefull if other things are pending
+ * is run. This is useful if other things are pending
  * which need to be processed first, for instance
  * hiding other toplevels.
  */
@@ -534,7 +573,7 @@ idle_unrealizer (GtkWidget **widget_p)
  * @widget: a valid #GtkWindow
  *
  * Defer unrealizing this widget until the next idle handler
- * is run. This is usefull if other things are pending
+ * is run. This is useful if other things are pending
  * which need to be processed first, e.g. completing a running
  * signal emission.
  */
@@ -619,7 +658,7 @@ gxk_widget_showraise (GtkWidget *widget)
  * gxk_toplevel_delete
  * @widget: a widget having a toplevel
  *
- * This function is usefull to produce the exact same effect
+ * This function is useful to produce the exact same effect
  * as if the user caused window manager triggered window
  * deletion on the toplevel of @widget.
  */
@@ -689,7 +728,7 @@ style_modify_fg_as_sensitive (GtkWidget *widget)
  * @widget: a valid GtkWidget
  *
  * Modify the widget and it's style, so that it is insensitive,
- * but doesn't quite look that way. Usefull for inactive title
+ * but doesn't quite look that way. Useful for inactive title
  * menu items in menus (@widget should be the menu item's label).
  */
 void
@@ -723,7 +762,7 @@ style_modify_bg_as_base (GtkWidget *widget)
  * @widget: a valid GtkWidget
  *
  * Modify the widget's background to look like the background
- * of a text or list widget (usually white). This is usefull
+ * of a text or list widget (usually white). This is useful
  * if a hbox or similar widget is used to "simulate" a list,
  * text, or similar widget.
  */
@@ -756,7 +795,7 @@ style_modify_base_as_bg (GtkWidget *widget)
  *
  * Modify the widget's base background (used by list and
  * text widgets) to look like an ordinary widget background.
- * This is usefull if a list, text or similar widget shouldn't
+ * This is useful if a list, text or similar widget shouldn't
  * stand out as such, e.g. when the GtkTextView widget displaying
  * a long non-editable text should look similar to a GtkLabel.
  */
@@ -887,7 +926,7 @@ gxk_size_group (GtkSizeGroupMode sgmode,
  * gxk_tree_spath_index0
  * @strpath: stringified #GtkTreePath
  *
- * Return index[0] of @strpath. Usefull for paths in lists,
+ * Return index[0] of @strpath. Useful for paths in lists,
  * where index[0] usually corresponds to the nth row.
  */
 gint
@@ -904,6 +943,32 @@ gxk_tree_spath_index0 (const gchar *strpath)
   return row;
 }
 
+/**
+ * gxk_tree_model_get_iter
+ *
+ * This function is a replacement for gtk_tree_model_get_iter()
+ * for Gtk+-2.4. For sort models, gtk_tree_model_get_iter() can
+ * erroneously return %TRUE which is corrected by calling this
+ * function instead.
+ */
+gboolean
+gxk_tree_model_get_iter (GtkTreeModel          *tree_model,
+                         GtkTreeIter           *iter,
+                         GtkTreePath           *path)
+{
+  if (!gtk_tree_model_get_iter (tree_model, iter, path))
+    return FALSE;
+  while (GTK_IS_TREE_MODEL_SORT (tree_model))
+    {
+      GtkTreeIter dummy;
+      tree_model = gtk_tree_model_sort_get_model (GTK_TREE_MODEL_SORT (tree_model));
+      if (!gtk_tree_model_get_iter (tree_model, &dummy, path))
+        return FALSE;
+    }
+  return TRUE;
+}
+
+
 /**
  * gxk_tree_path_prev
  * @path: valid #GtkTreePath
@@ -1609,10 +1674,11 @@ gxk_tree_view_get_bin_window_pos (GtkTreeView *tree,
 
 /**
  * gxk_tree_view_get_row_area
- * @tree:     valid #GtkTreeView
- * @row:      row to retrieve area coordinates for
- * @y_p:      y position of @row
- * @height_p: height of @row
+ * @tree:         valid #GtkTreeView
+ * @row:          row to retrieve area coordinates for
+ * @y_p:          y position of @row
+ * @height_p:     height of @row
+ * @content_area: whether the cell background area or content area is returned
  *
  * Retrieve the position and height of a row of a
  * #GtkTreeView widget within its bin window.
@@ -1621,7 +1687,8 @@ gboolean
 gxk_tree_view_get_row_area (GtkTreeView *tree,
                             gint         row,
                             gint        *y_p,
-                            gint        *height_p)
+                            gint        *height_p,
+                            gboolean     content_area)
 {
   GdkRectangle rect = { 0, 0, 0, 0 };
 
@@ -1631,7 +1698,10 @@ gxk_tree_view_get_row_area (GtkTreeView *tree,
     {
       GtkTreePath *path = gtk_tree_path_new ();
       gtk_tree_path_append_index (path, row);
-      gtk_tree_view_get_background_area (tree, path, NULL, &rect);
+      if (content_area)
+        gtk_tree_view_get_cell_area (tree, path, NULL, &rect);
+      else
+        gtk_tree_view_get_background_area (tree, path, NULL, &rect);
       gtk_tree_path_free (path);
     }
   if (y_p)
@@ -2121,7 +2191,7 @@ requisition_to_aux_info (GtkWidget      *widget,
  *
  * Proxy the size requisition of @widget through the
  * ::width_request and ::height_request properties.
- * This is usefull only for immediate children of a
+ * This is useful only for immediate children of a
  * #GtkScrolledWindow, to have the #GtkScrolledWindow
  * honour the widgets size requisition.
  */
@@ -2835,7 +2905,7 @@ gxk_widget_get_options (gpointer widget)
  *
  * Add/set a custom @option of @widget to a particular @value.
  * Custom options on widgets are used to attach extra information
- * to widgets which may be usefull to otherwise disjoint code
+ * to widgets which may be useful to otherwise disjoint code
  * portions. The actual options are implemented by means of
  * g_option_concat(), g_option_check() and g_option_get().
  */
