@@ -18,6 +18,7 @@
 #include "bsemain.h"
 #include "bsecategories.h"
 #include "bseprocedure.h"
+#include "bsesource.h"
 #include "topconfig.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,6 +28,24 @@
 #include <fcntl.h>
 
 
+static const gchar*
+beauty_float (gdouble f)
+{
+  gchar *s = g_strdup_printf ("%.7f", f);
+  const gchar *c;
+  if (strchr (s, '.'))
+    {
+      guint l = strlen (s) - 1;
+      while (s[l] == '0')
+        s[l--] = 0;
+      if (s[l] == '.')
+        s[l--] = 0;
+    }
+  c = g_intern_string (s);
+  g_free (s);
+  return c;
+}
+
 static GQuark  boxed_type_tag = 0;
 
 static void
@@ -149,7 +168,9 @@ show_procdoc (void)
   cseq = bse_categories_match_typed ("*", BSE_TYPE_PROCEDURE);
   for (i = 0; i < cseq->n_cats; i++)
     {
-      BseProcedureClass *class = g_type_class_ref (g_type_from_name (cseq->cats[i]->type));
+      GType type = g_type_from_name (cseq->cats[i]->type);
+      BseProcedureClass *class = g_type_class_ref (type);
+      const gchar *blurb = bse_type_get_blurb (type);
       gchar *cname = g_type_name_to_cname (cseq->cats[i]->type);
       gchar *sname = g_type_name_to_sname (cseq->cats[i]->type);
       guint j;
@@ -176,8 +197,10 @@ show_procdoc (void)
 	}
       g_print (");");
       
+#if 0
       if (class->blurb)
 	g_print (" - @refBlurb{%s}", class->blurb);
+#endif
       
       g_print ("\n");
       
@@ -225,8 +248,8 @@ show_procdoc (void)
 	  g_print ("@end multitable\n\n");
 	}
       
-      if (class->help)
-	g_print ("%s\n", class->help);
+      if (blurb)
+	g_print ("%s\n", blurb);
       else
 	g_print ("@*\n");
       
@@ -340,15 +363,157 @@ show_structdoc (void)
   g_free (children);
 }
 
+static gboolean
+strequals (const gchar *s1,
+           const gchar *s2)
+{
+  if (!s1 || !s2)
+    return s1 == s2;
+  return strcmp (s1, s2) == 0;
+}
+
+static void
+show_objdoc (void)
+{
+  BseCategorySeq *cseq;
+  guint i, j, in_itemize = 0;
+  g_print ("\\input texinfo\n"
+	   "@c %%**start of header\n"
+	   "@settitle %s\n"
+	   "@footnotestyle end\n"
+	   "@c %%**end of header\n"
+	   "\n"
+	   "@include texiutils.texi\n"
+	   "\n"
+	   "@docpackage{BEAST-%s}\n"
+	   "@docfont{tech}\n"
+	   "\n"
+	   "@majorheading %s - %s\n"
+	   "\n"
+	   "@revision{Document Revised:}\n"
+	   "\n"
+           "@contents\n"
+	   "\n",
+           _("BSE-Objects"),
+	   BST_VERSION,
+           _("BSE-Objects"), _(" Object Reference"));
+  cseq = bse_categories_match_typed ("*", BSE_TYPE_SOURCE);
+  for (i = 0; i < cseq->n_cats; i++)
+    {
+      BseCategory *cat = cseq->cats[i];
+      GType btype, type = g_type_from_name (cat->type);
+      BseSource *source = g_object_new (type, NULL);
+      const gchar *string, *pgroup = NULL;
+      g_print ("\n\n@anchor{%s} ", g_type_name (type));
+      g_print ("@unnumbered %s\n", g_type_name (type));
+      string = bse_type_get_authors (type);
+      if (string)
+        g_print ("@* @emph{%s} %s\n", _("Authors:"), string);
+      string = bse_type_get_license (type);
+      if (string)
+        g_print ("@* @emph{%s} %s\n", _("License:"), string);
+      string = bse_type_get_blurb (type);
+      if (string)
+        g_print ("@* %s\n", string);
+      g_print ("@heading %s\n", _("Properties:"));
+      btype = G_TYPE_OBJECT;
+      do
+        {
+          GParamSpec **pspecs;
+          btype = g_type_next_base (type, btype);
+          pspecs = g_object_class_list_properties (g_type_class_peek (btype), NULL);
+          for (j = 0; pspecs[j]; j++)
+            {
+              GParamSpec *pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (source), pspecs[j]->name);
+              const gchar *group = sfi_pspec_get_group (pspec);
+              if (pspec->owner_type != btype || !sfi_pspec_check_option (pspec, "G"))
+                continue;
+              if (!strequals (group, pgroup))
+                {
+                  if (in_itemize)
+                    g_print ("@end itemize\n");
+                  in_itemize = 0;
+                  pgroup = group;
+                  if (group)
+                    g_print ("@strong{%s:}\n", group);
+                }
+              if (!in_itemize++)
+                g_print ("@itemize\n");
+              g_print ("@anchor{%s::%s} ", g_type_name (type), sfi_pspec_get_name (pspec));
+              g_print ("@item @strong{@emph{%s}}\n", sfi_pspec_get_nick (pspec));
+              g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), sfi_pspec_get_name (pspec));
+              if (SFI_IS_PSPEC_INT (pspec))
+                {
+                  SfiInt imin, imax;
+                  sfi_pspec_get_int_range (pspec, &imin, &imax, NULL);
+                  g_print ("@* @emph{%s} %d .. %d\n", _("Range:"), imin, imax);
+                }
+              else if (SFI_IS_PSPEC_REAL (pspec))
+                {
+                  SfiReal fmin, fmax;
+                  sfi_pspec_get_real_range (pspec, &fmin, &fmax, NULL);
+                  g_print ("@* @emph{%s} %s .. %s\n", _("Range:"), beauty_float (fmin), beauty_float (fmax));
+                }
+              string = sfi_pspec_get_blurb (pspec);
+              if (string)
+                g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+            }
+          if (in_itemize)
+            {
+              g_print ("@end itemize\n");
+              in_itemize = 0;
+            }
+          g_free (pspecs);
+        }
+      while (btype != type);
+      g_print ("@heading %s\n", _("Input Channels:"));
+      for (j = 0; j < BSE_SOURCE_N_ICHANNELS (source); j++)
+        {
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_ICHANNEL_IDENT (source, j));
+          g_print ("@item @strong{@emph{%s %s}}\n", BSE_SOURCE_ICHANNEL_NAME (source, j),
+                   BSE_SOURCE_IS_JOINT_ICHANNEL (source, j) ? _("(Joint Input)") : "");
+          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_ICHANNEL_IDENT (source, j));
+          string = BSE_SOURCE_ICHANNEL_BLURB (source, j);
+          if (string)
+            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+      g_print ("@heading %s\n", _("Output Channels:"));
+      for (j = 0; j < BSE_SOURCE_N_OCHANNELS (source); j++)
+        {
+          if (!in_itemize++)
+            g_print ("@itemize\n");
+          g_print ("@anchor{%s::%s} ", g_type_name (type), BSE_SOURCE_OCHANNEL_IDENT (source, j));
+          g_print ("@item @strong{@emph{%s}} \n", BSE_SOURCE_OCHANNEL_NAME (source, j));
+          g_print ("@* @emph{%s} @var{%s}\n", _("Identifier:"), BSE_SOURCE_OCHANNEL_IDENT (source, j));
+          string = BSE_SOURCE_OCHANNEL_BLURB (source, j);
+          if (string)
+            g_print ("@* @emph{%s} %s\n", _("Description:"), string);
+        }
+      if (in_itemize)
+        {
+          g_print ("@end itemize\n");
+          in_itemize = 0;
+        }
+      g_print ("\n");
+      g_object_unref (source);
+    }
+}
+
 static gint
 help (const gchar *name,
       const gchar *arg)
 {
   if (arg)
     fprintf (stderr, "%s: unknown argument: %s\n", name, arg);
-  fprintf (stderr, "usage: %s [-h] [-p] [-s] {procs|structs}\n", name);
+  fprintf (stderr, "usage: %s [-h] [-p] {procs|structs|objects}\n", name);
   fprintf (stderr, "  -p                  include plugins\n");
-  fprintf (stderr, "  -s                  include scripts\n");
   fprintf (stderr, "  -h                  show help\n");
   fprintf (stderr, "  --seealso <link>    add a SEE ALSO section link\n");
   
@@ -360,25 +525,22 @@ main (gint   argc,
       gchar *argv[])
 {
   GSList *seealso = NULL;
+  SfiRec *config;
   gboolean gen_procs = FALSE;
   gboolean gen_structs = FALSE;
+  gboolean gen_objects = FALSE;
   guint i;
   
   g_thread_init (NULL);
-  
-  bse_init_intern (&argc, &argv, NULL);
-
+  sfi_init ();
+  config = sfi_rec_new();
   boxed_type_tag = g_quark_from_static_string ("bse-auto-doc-boxed-type-tag");
   
   for (i = 1; i < argc; i++)
     {
       if (strcmp ("-p", argv[i]) == 0)
 	{
-	  // FIXME: bsw_register_plugins (NULL, TRUE, NULL, NULL, NULL);
-	}
-      else if (strcmp ("-s", argv[i]) == 0)
-	{
-	  // FIXME: bsw_register_scripts (NULL, TRUE, NULL, NULL, NULL);
+          sfi_rec_set_bool (config, "load-core-plugins", TRUE);
 	}
       else if (strcmp ("procs", argv[i]) == 0)
 	{
@@ -388,6 +550,10 @@ main (gint   argc,
 	{
 	  gen_structs = TRUE;
 	}
+      else if (strcmp ("objects", argv[i]) == 0)
+	{
+	  gen_objects = TRUE;
+	}
       else if (strcmp ("--seealso", argv[i]) == 0)
 	{
 	  if (i + 1 < argc)
@@ -407,12 +573,16 @@ main (gint   argc,
 	return help (argv[0], argv[i]);
     }
 
+  bse_init_intern (&argc, &argv, config);
+
   tag_all_boxed_pspecs ();
 
   if (gen_procs)
     show_procdoc ();
   else if (gen_structs)
     show_structdoc ();
+  else if (gen_objects)
+    show_objdoc ();
   else
     return help (argv[0], NULL);
 
