@@ -132,7 +132,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 			      bse_param_spec_genum ("filter_type", _("Filter Type"), _("The filter design type"),
 						    BSE_TYPE_BIQUAD_FILTER_TYPE,
 						    BSE_BIQUAD_FILTER_RESONANT_LOWPASS,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_FREQ,
 			      sfi_pspec_log_scale ("freq", _("Cutoff [Hz]"), NULL,
@@ -140,7 +140,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						   BSE_MIN_OSC_FREQUENCY_f, BSE_MAX_OSC_FREQUENCY_f - FREQ_DELTA,
 						   5.0,
 						   BSE_KAMMER_FREQUENCY_f * 2, 2, 4,
-						   SFI_PARAM_DEFAULT ":dial"));
+						   SFI_PARAM_STANDARD ":dial"));
   bse_object_class_add_param (object_class, _("Center Frequency"),
 			      PROP_NOTE,
 			      sfi_pspec_note ("note", _("Note"), NULL,
@@ -152,7 +152,7 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 			      PROP_GAIN,
 			      sfi_pspec_real ("gain", _("Gain [dB]"), NULL,
 					      3, -48., +48., 3,
-					      SFI_PARAM_DEFAULT ":dial"));
+					      SFI_PARAM_STANDARD ":dial"));
   bse_object_class_add_param (object_class, _("Emphasis"),
 			      PROP_NORM_TYPE,
 			      bse_param_spec_genum ("norm_type", _("Norm Type"),
@@ -160,31 +160,32 @@ bse_biquad_filter_class_init (BseBiquadFilterClass *class)
 						      "by highpass and lowpass)"),
 						    BSE_TYPE_BIQUAD_FILTER_NORM,
 						    BSE_BIQUAD_FILTER_NORM_PASSBAND,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, _("Modulation"),
 			      PROP_FM_PERC,
 			      sfi_pspec_real ("fm_perc", "Input Modulation [%]",
 					      _("Strength of linear frequency modulation"),
 					      0, 0.0, 100.0, 5.0,
-					      SFI_PARAM_DEFAULT ":scale"));
+					      SFI_PARAM_STANDARD ":scale"));
   bse_object_class_add_param (object_class, _("Modulation"),
 			      PROP_FM_EXP,
 			      sfi_pspec_bool ("exponential_fm", "Exponential FM",
 					      _("Perform exponential frequency modulation "
 						"instead of linear"),
-					      FALSE, SFI_PARAM_DEFAULT));
+					      FALSE, SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, _("Modulation"),
 			      PROP_FM_OCTAVES,
 			      sfi_pspec_real ("fm_n_octaves", "Octaves",
 					      _("Number of octaves to be affected by exponential frequency modulation"),
 					      1.0, 0, 5.0, 0.01,
-					      SFI_PARAM_DEFAULT ":scale"));
+					      SFI_PARAM_STANDARD ":scale"));
   bse_object_class_add_param (object_class, _("Modulation"),
 			      PROP_GAIN_PERC,
+			      /* xgettext:no-c-format */
 			      sfi_pspec_real ("gain_perc", _("Gain Modulation [%]"),
 					      _("Strength of gain modulation"),
 					      0.0, 0.0, 100.0, 5.0,
-					      SFI_PARAM_DEFAULT ":scale"));
+					      SFI_PARAM_STANDARD ":scale"));
   
   channel_id = bse_source_class_add_ichannel (source_class, "Audio In", _("Unfiltered Audio Signal"));
   g_assert (channel_id == BSE_BIQUAD_FILTER_ICHANNEL_AUDIO);
