@@ -57,8 +57,7 @@ extern ::BseExportIdentity bse_builtin_export_identity; /* sync with bseplugin.h
 /* --- enum registration --- */
 /* enum registration is based on a static ExportTypeKeeper
  * object, which provides the enum's get_type() implementation and
- * auto-registers the enum's export node with the plugin's
- * export_identity.
+ * auto-registers the enum's export node with the export_identity.
  */
 #define BSE_CXX_DECLARED_ENUM_TYPE(EnumType)                            \
   (bse_type_keeper__3##EnumType.get_type ())
@@ -99,34 +98,103 @@ EnumValue (int         int_value,
 }
 
 
+/* --- record registration --- */
+/* record registration is based on a static ExportTypeKeeper
+ * object, which provides the record's get_type() implementation and
+ * auto-registers the record's export node with the export_identity.
+ */
+#define BSE_CXX_DECLARED_RECORD_TYPE(RecordType)                        \
+  (bse_type_keeper__1##RecordType.get_type ())
+#define BSE_CXX_DECLARE_RECORD(RecordType)                              \
+  template<class E> static BseExportNode* bse_export_node ();           \
+  template<> static BseExportNode*                                      \
+  bse_export_node<RecordType> ()                                        \
+  {                                                                     \
+    static BseExportNodeBoxed bnode = {                                 \
+      { NULL, BSE_EXPORT_NODE_RECORD, NULL, },                          \
+    };                                                                  \
+    if (!bnode.node.name) {                                             \
+      bnode.node.name = RecordType::type_name();                        \
+      bnode.node.options = RecordType::options();                       \
+      bnode.node.authors = RecordType::authors();                       \
+      bnode.node.license = RecordType::license();                       \
+      bnode.node.blurb = RecordType::blurb();                           \
+      bnode.copy = Sfi::RecordHandle< RecordType >::boxed_copy;         \
+      bnode.free = Sfi::RecordHandle< RecordType >::boxed_free;         \
+      bnode.seqrec2boxed = ::Sfi::cxx_boxed_from_rec<RecordType>;       \
+      bnode.boxed2recseq = ::Sfi::cxx_boxed_to_rec<RecordType>;         \
+      bnode.func.get_fields = RecordType::get_fields;                   \
+    }                                                                   \
+    return &bnode.node;                                                 \
+  }                                                                     \
+  extern ::Bse::ExportTypeKeeper bse_type_keeper__1##RecordType;
+#define BSE_CXX_REGISTER_RECORD(RecordType)                             \
+  ::Bse::ExportTypeKeeper                                               \
+         bse_type_keeper__1##RecordType (bse_export_node<RecordType>,   \
+                                         &BSE_CXX_EXPORT_IDENTITY);
+
+
+/* --- sequence registration --- */
+/* sequence registration works similar to record registration */
+#define BSE_CXX_DECLARED_SEQUENCE_TYPE(SequenceType)                            \
+  (bse_type_keeper__1##SequenceType.get_type ())
+#define BSE_CXX_DECLARE_SEQUENCE(SequenceType)                                  \
+  template<class E> static BseExportNode* bse_export_node ();                   \
+  template<> static BseExportNode*                                              \
+  bse_export_node<SequenceType> ()                                              \
+  {                                                                             \
+    static BseExportNodeBoxed bnode = {                                         \
+      { NULL, BSE_EXPORT_NODE_SEQUENCE, NULL, },                                \
+    };                                                                          \
+    if (!bnode.node.name) {                                                     \
+      bnode.node.name = SequenceType::type_name();                              \
+      bnode.node.options = SequenceType::options();                             \
+      bnode.node.authors = SequenceType::authors();                             \
+      bnode.node.license = SequenceType::license();                             \
+      bnode.node.blurb = SequenceType::blurb();                                 \
+      bnode.copy = SequenceType::boxed_copy;                                    \
+      bnode.free = SequenceType::boxed_free;                                    \
+      bnode.seqrec2boxed = ::Sfi::cxx_boxed_from_seq<SequenceType>;             \
+      bnode.boxed2recseq = ::Sfi::cxx_boxed_to_seq<SequenceType>;               \
+      bnode.func.get_element = SequenceType::get_element;                       \
+    }                                                                           \
+    return &bnode.node;                                                         \
+  }                                                                             \
+  extern ::Bse::ExportTypeKeeper bse_type_keeper__1##SequenceType;
+#define BSE_CXX_REGISTER_SEQUENCE(SequenceType)                                 \
+  ::Bse::ExportTypeKeeper                                                       \
+         bse_type_keeper__1##SequenceType (bse_export_node<SequenceType>,       \
+                                           &BSE_CXX_EXPORT_IDENTITY);
+
+
 /* --- procedure registration --- */
 /* procedure registration works similar to enum registration. */
 #define BSE_CXX_DECLARED_PROC_TYPE(ProcType)                            \
   (bse_type_keeper__9##ProcType.get_type ())
 #define BSE_CXX_DECLARE_PROC(ProcType)                                  \
   extern ::Bse::ExportTypeKeeper bse_type_keeper__9##ProcType;
-#define BSE_CXX_REGISTER_PROC(ProcType)                                         \
+#define BSE_CXX_REGISTER_PROCEDURE(ProcType)                                    \
   template<class C> static ::BseExportNode* bse_export_node ();                 \
   template<> static ::BseExportNode*                                            \
-  bse_export_node<Procedure_##ProcType> ()                                      \
+  bse_export_node<Procedure::ProcType> ()                                       \
   {                                                                             \
     static ::BseExportNodeProc pnode = {                                        \
       { NULL, ::BSE_EXPORT_NODE_PROC, NULL, },                                  \
-      0, Procedure_##ProcType::init, Procedure_##ProcType::marshal,             \
+      0, Procedure::ProcType::init, Procedure::ProcType::marshal,               \
     };                                                                          \
     if (!pnode.node.name) {                                                     \
-      pnode.node.name = Procedure_##ProcType::type_name();                      \
-      pnode.node.options = Procedure_##ProcType::options();                     \
-      pnode.node.category = Procedure_##ProcType::category();                   \
-      pnode.node.authors = Procedure_##ProcType::authors();                     \
-      pnode.node.license = Procedure_##ProcType::license();                     \
-      pnode.node.pixstream = Procedure_##ProcType::pixstream();                 \
-      pnode.node.blurb = Procedure_##ProcType::blurb();                         \
+      pnode.node.name = Procedure::ProcType::type_name();                       \
+      pnode.node.options = Procedure::ProcType::options();                      \
+      pnode.node.category = Procedure::ProcType::category();                    \
+      pnode.node.authors = Procedure::ProcType::authors();                      \
+      pnode.node.license = Procedure::ProcType::license();                      \
+      pnode.node.pixstream = Procedure::ProcType::pixstream();                  \
+      pnode.node.blurb = Procedure::ProcType::blurb();                          \
     }                                                                           \
     return &pnode.node;                                                         \
   }                                                                             \
   ::Bse::ExportTypeKeeper                                                       \
-         bse_type_keeper__9##ProcType (bse_export_node<Procedure_##ProcType>,   \
+         bse_type_keeper__9##ProcType (bse_export_node<Procedure::ProcType>,    \
                                    &BSE_CXX_EXPORT_IDENTITY);
 
 
@@ -173,25 +241,6 @@ EnumValue (int         int_value,
   ::Bse::ExportTypeKeeper                                                       \
          bse_type_keeper__0##Effect (bse_export_node<Effect>,                   \
                                      &BSE_CXX_EXPORT_IDENTITY);
-/* effect method: create_module(); */
-#define BSE_CXX_DEFINE_CREATE_MODULE(ObjectType,ModuleType,ParamType)           \
-  Bse::SynthesisModule*                                                         \
-  ObjectType::create_module (unsigned int context_handle,                       \
-                             GslTrans    *trans)                                \
-  { /* create a synthesis module */                                             \
-    return new ModuleType();                                                    \
-  }
-/* effect method: module_configurator(); */
-#define BSE_CXX_DEFINE_MODULE_CONFIGURATOR(ObjectType,ModuleType,ParamType)     \
-Bse::SynthesisModule::Accessor*                                                 \
-ObjectType::module_configurator()                                               \
-{                                                                               \
-  return SynthesisModule::accessor (&ModuleType::config, ParamType (this));     \
-}
-/* convenience macro to define BseEffect module methods */
-#define BSE_EFFECT_INTEGRATE_MODULE(ObjectType,ModuleType,ParamType)            \
-  BSE_CXX_DEFINE_CREATE_MODULE (ObjectType,ModuleType,ParamType);               \
-  BSE_CXX_DEFINE_MODULE_CONFIGURATOR (ObjectType,ModuleType,ParamType);
 /* implement static_data portions used by auto-generated classes */
 #define BSE_CXX_DEFINE_STATIC_DATA(ObjectType)                                  \
   ObjectType::StaticData ObjectType::static_data;
