@@ -19,16 +19,9 @@ create_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 30 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", NULL,
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 28 "bsedatapocket.proc"
-  proc->help = ("Create a new entry in a data pocket. "
-	   "Entries have a unique ID which is required to set values in a data pocket.");
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 34 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -66,18 +59,12 @@ delete_entry_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 57 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", NULL,
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error code",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 56 "bsedatapocket.proc"
-  proc->help = "Delete an existing entry from a data pocket";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 64 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -117,15 +104,9 @@ get_n_entries_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 89 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("n_entries", "N Entries", "The number of entries in use",
-			 1, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 88 "bsedatapocket.proc"
-  proc->help = "Retrieve the number of entries created in a data pocket.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			 1, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 93 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -158,17 +139,11 @@ get_nth_entry_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
  {
 #line 112 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_index", "Entry Index", "index into number of entries present",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID (or 0 if there's no such entry)",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 111 "bsedatapocket.proc"
-  proc->help = "Retrieve the ID of an entry in the data pocket by sequential index.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 118 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -202,24 +177,16 @@ set_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 140 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("number", "Number", "The value to store in the data pocket entry",
-			  0, -G_MAXDOUBLE, G_MAXDOUBLE, 1, SFI_PARAM_DEFAULT);
+			  0, -G_MAXDOUBLE, G_MAXDOUBLE, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error code",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 137 "bsedatapocket.proc"
-  proc->help = ("Set a named floating point value in a data pocket entry. "
-	   "Names are required to distinguish different values from each other "
-	   "when accessing values in a data pocket.");
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 151 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -263,24 +230,16 @@ set_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
  {
 #line 182 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("number", "Number", "The value to store in the data pocket entry",
-			 0, G_MININT, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, G_MININT, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error code",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 179 "bsedatapocket.proc"
-  proc->help = ("Set a named integer value in a data pocket entry. "
-	   "Names are required to distinguish different values from each other "
-	   "when accessing values in a data pocket.");
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 193 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -324,24 +283,16 @@ set_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 224 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("item", "Item", "The value to store in the data pocket entry",
-				 BSE_TYPE_ITEM, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error code",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 221 "bsedatapocket.proc"
-  proc->help = ("Set a named object reference in a data pocket entry. "
-	   "Object references stored in a data pocket must exist within the "
-	   "same project that the data pocket belongs to");
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 235 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -386,22 +337,16 @@ set_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 265 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("string", "String", "The value to store in the data pocket entry",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error code",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 264 "bsedatapocket.proc"
-  proc->help = ("Set a named string in a data pocket entry.");
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 276 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -445,19 +390,13 @@ get_float_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 305 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_real ("number", "Number", "The value stored in the data pocket entry",
-			  0, -G_MAXDOUBLE, G_MAXDOUBLE, 1, SFI_PARAM_DEFAULT);
-#line 304 "bsedatapocket.proc"
-  proc->help = "Retrieve a previously set floating point value from a data pocket entry.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			  0, -G_MAXDOUBLE, G_MAXDOUBLE, 1, SFI_PARAM_STANDARD);
 #line 313 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -498,19 +437,13 @@ get_int_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
  {
 #line 339 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("number", "Number", "The value stored in the data pocket entry",
-			 0, G_MININT, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 338 "bsedatapocket.proc"
-  proc->help = "Retrieve a previously set integer value from a data pocket entry.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			 0, G_MININT, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 347 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -551,19 +484,13 @@ get_object_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 373 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("item", "Item", "The value stored in the data pocket entry",
-				 BSE_TYPE_ITEM, SFI_PARAM_DEFAULT);
-#line 372 "bsedatapocket.proc"
-  proc->help = "Retrieve a previously set object reference from a data pocket entry.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+				 BSE_TYPE_ITEM, SFI_PARAM_STANDARD);
 #line 381 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -604,19 +531,13 @@ get_string_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 407 "bsedatapocket.proc"
   *(in_pspecs++) = bse_param_spec_object ("data_pocket", "Data Pocket", "The data pocket storing values",
-				 BSE_TYPE_DATA_POCKET, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_DATA_POCKET, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("entry_id", "Entry ID", "The unique pocket entry ID",
-			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("name", "Name", "Name for the value",
-			    0, SFI_PARAM_DEFAULT);
+			    0, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("string", "String", "The value stored in the data pocket entry",
-			    0, SFI_PARAM_DEFAULT);
-#line 406 "bsedatapocket.proc"
-  proc->help = "Retrieve a previously set string from a data pocket entry.";
-#line 23 "bsedatapocket.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 24 "bsedatapocket.proc"
-  proc->license = "GNU General Public License";
+			    0, SFI_PARAM_STANDARD);
 #line 415 "bsedatapocket.proc"
 }  }
 static BseErrorType
@@ -653,62 +574,141 @@ get_string_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_create_entry = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+create-entry", "/Methods/BseDataPocket/General/Create Entry", NULL },
+    "BseDataPocket+create-entry", 
+    NULL,
+    "/Methods/BseDataPocket/General/Create Entry",
+    ("Create a new entry in a data pocket. "
+	   "Entries have a unique ID which is required to set values in a data pocket."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, create_entry_setup, create_entry_exec, 
 };
 static BseExportNodeProc __enode_delete_entry = {
   { (BseExportNode*) &__enode_create_entry, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+delete-entry", "/Methods/BseDataPocket/General/Delete Entry", NULL },
+    "BseDataPocket+delete-entry", 
+    NULL,
+    "/Methods/BseDataPocket/General/Delete Entry",
+    "Delete an existing entry from a data pocket",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, delete_entry_setup, delete_entry_exec, 
 };
 static BseExportNodeProc __enode_get_n_entries = {
   { (BseExportNode*) &__enode_delete_entry, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-n-entries", "/Methods/BseDataPocket/General/Get N Entries", NULL },
+    "BseDataPocket+get-n-entries", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get N Entries",
+    "Retrieve the number of entries created in a data pocket.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_n_entries_setup, get_n_entries_exec, 
 };
 static BseExportNodeProc __enode_get_nth_entry_id = {
   { (BseExportNode*) &__enode_get_n_entries, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-nth-entry-id", "/Methods/BseDataPocket/General/Get Nth Entry Id", NULL },
+    "BseDataPocket+get-nth-entry-id", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get Nth Entry Id",
+    "Retrieve the ID of an entry in the data pocket by sequential index.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_nth_entry_id_setup, get_nth_entry_id_exec, 
 };
 static BseExportNodeProc __enode_set_float = {
   { (BseExportNode*) &__enode_get_nth_entry_id, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+set-float", "/Methods/BseDataPocket/General/Set Float", NULL },
+    "BseDataPocket+set-float", 
+    NULL,
+    "/Methods/BseDataPocket/General/Set Float",
+    ("Set a named floating point value in a data pocket entry. "
+	   "Names are required to distinguish different values from each other "
+	   "when accessing values in a data pocket."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_float_setup, set_float_exec, 
 };
 static BseExportNodeProc __enode_set_int = {
   { (BseExportNode*) &__enode_set_float, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+set-int", "/Methods/BseDataPocket/General/Set Int", NULL },
+    "BseDataPocket+set-int", 
+    NULL,
+    "/Methods/BseDataPocket/General/Set Int",
+    ("Set a named integer value in a data pocket entry. "
+	   "Names are required to distinguish different values from each other "
+	   "when accessing values in a data pocket."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_int_setup, set_int_exec, 
 };
 static BseExportNodeProc __enode_set_object = {
   { (BseExportNode*) &__enode_set_int, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+set-object", "/Methods/BseDataPocket/General/Set Object", NULL },
+    "BseDataPocket+set-object", 
+    NULL,
+    "/Methods/BseDataPocket/General/Set Object",
+    ("Set a named object reference in a data pocket entry. "
+	   "Object references stored in a data pocket must exist within the "
+	   "same project that the data pocket belongs to"),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_object_setup, set_object_exec, 
 };
 static BseExportNodeProc __enode_set_string = {
   { (BseExportNode*) &__enode_set_object, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+set-string", "/Methods/BseDataPocket/General/Set String", NULL },
+    "BseDataPocket+set-string", 
+    NULL,
+    "/Methods/BseDataPocket/General/Set String",
+    ("Set a named string in a data pocket entry."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, set_string_setup, set_string_exec, 
 };
 static BseExportNodeProc __enode_get_float = {
   { (BseExportNode*) &__enode_set_string, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-float", "/Methods/BseDataPocket/General/Get Float", NULL },
+    "BseDataPocket+get-float", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get Float",
+    "Retrieve a previously set floating point value from a data pocket entry.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_float_setup, get_float_exec, 
 };
 static BseExportNodeProc __enode_get_int = {
   { (BseExportNode*) &__enode_get_float, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-int", "/Methods/BseDataPocket/General/Get Int", NULL },
+    "BseDataPocket+get-int", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get Int",
+    "Retrieve a previously set integer value from a data pocket entry.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_int_setup, get_int_exec, 
 };
 static BseExportNodeProc __enode_get_object = {
   { (BseExportNode*) &__enode_get_int, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-object", "/Methods/BseDataPocket/General/Get Object", NULL },
+    "BseDataPocket+get-object", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get Object",
+    "Retrieve a previously set object reference from a data pocket entry.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_object_setup, get_object_exec, 
 };
 static BseExportNodeProc __enode_get_string = {
   { (BseExportNode*) &__enode_get_object, BSE_EXPORT_NODE_PROC,
-    "BseDataPocket+get-string", "/Methods/BseDataPocket/General/Get String", NULL },
+    "BseDataPocket+get-string", 
+    NULL,
+    "/Methods/BseDataPocket/General/Get String",
+    "Retrieve a previously set string from a data pocket entry.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_string_setup, get_string_exec, 
 };
 BseExportNode* bse__builtin_init_bsedatapocket_gen_proc_c (void);
