@@ -70,6 +70,7 @@ typedef struct  _BseMidiSynthClass      BseMidiSynthClass;
 typedef struct  _BseMidiContext         BseMidiContext;
 typedef struct  _BseObject              BseObject;
 typedef struct  _BseObjectClass         BseObjectClass;
+typedef struct  _BseParasite		BseParasite;
 typedef struct  _BsePart		BsePart;
 typedef struct  _BsePartClass		BsePartClass;
 typedef struct  _BsePcmWriter           BsePcmWriter;
@@ -106,6 +107,7 @@ typedef struct  _BseWaveRepoClass       BseWaveRepoClass;
 
 /* --- BSE aux structures --- */
 typedef struct  _BseExportNode          BseExportNode;
+typedef struct  _BseExportNodeBoxed	BseExportNodeBoxed;
 typedef struct  _BseGlobals             BseGlobals;
 typedef struct  _BsePixdata             BsePixdata;
 typedef struct  _BsePlugin              BsePlugin;
