@@ -20,16 +20,10 @@ open_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_ps
  {
 #line 30 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
-#line 29 "bseeditablesample.proc"
-  proc->help = ("Open the sample for reading.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+				SFI_PARAM_STANDARD);
 #line 35 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -79,13 +73,7 @@ close_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_p
  {
 #line 70 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
-#line 69 "bseeditablesample.proc"
-  proc->help = ("Close an opened sample.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
 #line 72 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -120,15 +108,9 @@ get_length_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **
  {
 #line 93 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("length", NULL, "Number of values",
-			 1, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 92 "bseeditablesample.proc"
-  proc->help = ("Return the number of values in the sample.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+			 1, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 97 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -164,15 +146,9 @@ get_n_channels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 119 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_int ("n-channels", NULL, "Number of channels",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-#line 118 "bseeditablesample.proc"
-  proc->help = ("Return the number of channels in the sample.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 #line 123 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -205,15 +181,9 @@ get_osc_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 142 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(out_pspecs++) = bse_param_spec_freq_simple ("osc-freq", NULL, "Oscillator Frequency",
-				      SFI_PARAM_DEFAULT);
-#line 141 "bseeditablesample.proc"
-  proc->help = ("Return the oscillator frequency for the sample.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+				      SFI_PARAM_STANDARD);
 #line 146 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -246,16 +216,10 @@ read_samples_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 165 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("voffset", NULL, "Value offset",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_fblock ("sample_block", NULL, "Block of samples", SFI_PARAM_DEFAULT);
-#line 164 "bseeditablesample.proc"
-  proc->help = ("Read a set of samples from a specific offset.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_fblock ("sample_block", NULL, "Block of samples", SFI_PARAM_STANDARD);
 #line 170 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -308,24 +272,18 @@ collect_stats_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 209 "bseeditablesample.proc"
   *(in_pspecs++) = bse_param_spec_object ("esample", "Editable Sample", NULL,
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("voffset", NULL, "Offset of first stat block",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("offset_scale", NULL, "Factor to scale voffset increments with",
-			  0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			  0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("block_size", NULL, "Block size to compute stat pairs from",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("stepping", NULL, "Stepping within a stat block",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("max_pairs", NULL, "Maximum number of (min, max) pairs to collect",
-			 1, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
-  *(out_pspecs++) = sfi_pspec_fblock ("sample_block", NULL, "Block of samples", SFI_PARAM_DEFAULT);
-#line 208 "bseeditablesample.proc"
-  proc->help = ("Collect statistics from sample blocks as (minimum, maximum) pairs.");
-#line 24 "bseeditablesample.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseeditablesample.proc"
-  proc->license = "GNU General Public License";
+			 1, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
+  *(out_pspecs++) = sfi_pspec_fblock ("sample_block", NULL, "Block of samples", SFI_PARAM_STANDARD);
 #line 222 "bseeditablesample.proc"
 }  }
 static BseErrorType
@@ -408,37 +366,79 @@ collect_stats_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_open = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+open", "/Methods/BseEditableSample/General/Open", NULL },
+    "BseEditableSample+open", 
+    NULL,
+    "/Methods/BseEditableSample/General/Open",
+    ("Open the sample for reading."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, open_setup, open_exec, 
 };
 static BseExportNodeProc __enode_close = {
   { (BseExportNode*) &__enode_open, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+close", "/Methods/BseEditableSample/General/Close", NULL },
+    "BseEditableSample+close", 
+    NULL,
+    "/Methods/BseEditableSample/General/Close",
+    ("Close an opened sample."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, close_setup, close_exec, 
 };
 static BseExportNodeProc __enode_get_length = {
   { (BseExportNode*) &__enode_close, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+get-length", "/Methods/BseEditableSample/General/Get Length", NULL },
+    "BseEditableSample+get-length", 
+    NULL,
+    "/Methods/BseEditableSample/General/Get Length",
+    ("Return the number of values in the sample."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_length_setup, get_length_exec, 
 };
 static BseExportNodeProc __enode_get_n_channels = {
   { (BseExportNode*) &__enode_get_length, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+get-n-channels", "/Methods/BseEditableSample/General/Get N Channels", NULL },
+    "BseEditableSample+get-n-channels", 
+    NULL,
+    "/Methods/BseEditableSample/General/Get N Channels",
+    ("Return the number of channels in the sample."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_n_channels_setup, get_n_channels_exec, 
 };
 static BseExportNodeProc __enode_get_osc_freq = {
   { (BseExportNode*) &__enode_get_n_channels, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+get-osc-freq", "/Methods/BseEditableSample/General/Get Osc Freq", NULL },
+    "BseEditableSample+get-osc-freq", 
+    NULL,
+    "/Methods/BseEditableSample/General/Get Osc Freq",
+    ("Return the oscillator frequency for the sample."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, get_osc_freq_setup, get_osc_freq_exec, 
 };
 static BseExportNodeProc __enode_read_samples = {
   { (BseExportNode*) &__enode_get_osc_freq, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+read-samples", "/Methods/BseEditableSample/General/Read Samples", NULL },
+    "BseEditableSample+read-samples", 
+    NULL,
+    "/Methods/BseEditableSample/General/Read Samples",
+    ("Read a set of samples from a specific offset."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, read_samples_setup, read_samples_exec, 
 };
 static BseExportNodeProc __enode_collect_stats = {
   { (BseExportNode*) &__enode_read_samples, BSE_EXPORT_NODE_PROC,
-    "BseEditableSample+collect-stats", "/Methods/BseEditableSample/General/Collect Stats", NULL },
+    "BseEditableSample+collect-stats", 
+    NULL,
+    "/Methods/BseEditableSample/General/Collect Stats",
+    ("Collect statistics from sample blocks as (minimum, maximum) pairs."),
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, collect_stats_setup, collect_stats_exec, 
 };
 BseExportNode* bse__builtin_init_bseeditablesample_gen_proc_c (void);
