@@ -10,6 +10,8 @@ static GEnumValue bse_export_node_type_values[] = {
   { BSE_EXPORT_NODE_NONE, "BSE_EXPORT_NODE_NONE", "none" },
   { BSE_EXPORT_NODE_LINK, "BSE_EXPORT_NODE_LINK", "link" },
   { BSE_EXPORT_NODE_ENUM, "BSE_EXPORT_NODE_ENUM", "enum" },
+  { BSE_EXPORT_NODE_RECORD, "BSE_EXPORT_NODE_RECORD", "record" },
+  { BSE_EXPORT_NODE_SEQUENCE, "BSE_EXPORT_NODE_SEQUENCE", "sequence" },
   { BSE_EXPORT_NODE_CLASS, "BSE_EXPORT_NODE_CLASS", "class" },
   { BSE_EXPORT_NODE_PROC, "BSE_EXPORT_NODE_PROC", "proc" },
   { 0, NULL, NULL }
