@@ -20,15 +20,9 @@ bse_error_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
 #line 30 "bseenums.proc"
   *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("name", "Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
-#line 29 "bseenums.proc"
-  proc->help = "Retrieve the name of an error value";
-#line 24 "bseenums.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseenums.proc"
-  proc->license = "GNU Lesser General Public License";
+			    NULL, SFI_PARAM_STANDARD);
 #line 35 "bseenums.proc"
 }  }
 static BseErrorType
@@ -63,15 +57,9 @@ bse_error_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
 #line 54 "bseenums.proc"
   *(in_pspecs++) = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
   *(out_pspecs++) = sfi_pspec_string ("blurb", "Blurb", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
-#line 53 "bseenums.proc"
-  proc->help = "Retrieve the description of an error value";
-#line 24 "bseenums.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bseenums.proc"
-  proc->license = "GNU Lesser General Public License";
+			    NULL, SFI_PARAM_STANDARD);
 #line 59 "bseenums.proc"
 }  }
 static BseErrorType
@@ -101,12 +89,24 @@ bse_error_blurb_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_bse_error_name = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "bse-error-name", "/Proc/Error Name", NULL },
+    "bse-error-name", 
+    NULL,
+    "/Proc/Error Name",
+    "Retrieve the name of an error value",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, bse_error_name_setup, bse_error_name_exec, 
 };
 static BseExportNodeProc __enode_bse_error_blurb = {
   { (BseExportNode*) &__enode_bse_error_name, BSE_EXPORT_NODE_PROC,
-    "bse-error-blurb", "/Proc/Error Blurb", NULL },
+    "bse-error-blurb", 
+    NULL,
+    "/Proc/Error Blurb",
+    "Retrieve the description of an error value",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, bse_error_blurb_setup, bse_error_blurb_exec, 
 };
 BseExportNode* bse__builtin_init_bseenums_gen_proc_c (void);
