@@ -298,9 +298,16 @@ bglue_value_from_serializable (const GValue *svalue,
       g_value_init (value, dtype);
     }
   if (!dtype || !sfi_value_transform (svalue, value))
-    g_warning ("unable to convert to value type `%s' from serializable (`%s')",
-	       g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
-	       g_type_name (stype));
+    {
+      if (0)
+        g_printerr ("from=%s to=%s, transformable=%u\n",
+                    g_type_name (G_VALUE_TYPE (svalue)),
+                    g_type_name (dtype),
+                    g_value_type_transformable (G_VALUE_TYPE (svalue), dtype));
+      g_warning ("unable to convert to value type `%s' from serializable (`%s')",
+                 g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
+                 g_type_name (stype));
+    }
   return value;
 }
 
@@ -337,6 +344,15 @@ bglue_value_to_serializable (const GValue *svalue)
 	dtype = SFI_TYPE_REC;
       else if (sfi_boxed_get_sequence_info (vtype))
 	dtype = SFI_TYPE_SEQ;
+      else
+        {
+          SfiRecFields rfields = sfi_boxed_type_get_rec_fields (vtype);
+          GParamSpec *element = sfi_boxed_type_get_seq_element (vtype);
+          if (rfields.n_fields)
+            dtype = SFI_TYPE_REC;
+          else if (element)
+            dtype = SFI_TYPE_SEQ;
+        }
       break;
     case G_TYPE_ENUM:
       dtype = SFI_TYPE_CHOICE;
@@ -553,10 +569,9 @@ bglue_describe_proc (SfiGlueContext *context,
       guint i;
       
       p = sfi_glue_proc_new (g_type_name (type));
-      p->blurb = g_strdup (proc->blurb);
-      p->help = g_strdup (proc->help);
-      p->authors = g_strdup (proc->authors);
-      p->license = g_strdup (proc->license);
+      p->help = g_strdup (bse_type_get_blurb (type));
+      p->authors = g_strdup (bse_type_get_authors (type));
+      p->license = g_strdup (bse_type_get_license (type));
       if (proc->n_out_pspecs)
 	{
 	  GParamSpec *pspec = bglue_pspec_to_serializable (proc->out_pspecs[0]);
@@ -708,7 +723,12 @@ bglue_exec_proc (SfiGlueContext *context,
       g_slist_free (clearlist);
       
       if (error)
-        g_message ("while executing \"%s\": %s\n", proc->name, bse_error_blurb (error));
+        {
+          if (BSE_DBG_EXT)
+            g_warning ("while executing \"%s\": %s\n", BSE_PROCEDURE_NAME (proc), bse_error_blurb (error));
+          else
+            g_message ("while executing \"%s\": %s\n", BSE_PROCEDURE_NAME (proc), bse_error_blurb (error));
+        }
       if (proc->n_out_pspecs)
 	retval = bglue_value_to_serializable (ovalues + 0);
       for (i = 0; i < proc->n_out_pspecs; i++)
@@ -717,7 +737,12 @@ bglue_exec_proc (SfiGlueContext *context,
       g_type_class_unref (proc);
     }
   else
-    g_message ("failed to execute \"%s\": no such procedure\n", proc_name);
+    {
+      if (BSE_DBG_EXT)
+        g_warning ("failed to execute \"%s\": no such procedure\n", proc_name);
+      else
+        g_message ("failed to execute \"%s\": no such procedure\n", proc_name);
+    }
   
   return retval;
 }
