@@ -17,7 +17,7 @@
  */
 #include	"bsepcmdevice-oss.h"
 
-#include	"PKG_config.h"
+#include	"topconfig.h"
 
 #include	"gsldatautils.h"
 
@@ -25,7 +25,11 @@
 BSE_DUMMY_TYPE (BsePcmDeviceOSS);
 #else   /* BSE_PCM_DEVICE_CONF_OSS */
 
+#if HAVE_SYS_SOUNDCARD_H
 #include	<sys/soundcard.h>
+#elif HAVE_SOUNDCARD_H
+#include	<soundcard.h>
+#endif
 #include	<sys/ioctl.h>
 #include	<sys/types.h>
 #include	<sys/time.h>
