@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 1998-1999, 2000-2002 Tim Janik
+ * Copyright (C) 1998-1999, 2000-2004 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,20 +15,20 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
-#include        "bseprocedure.h"
-
-#include        <gobject/gvaluecollector.h>
-#include        "bseobject.h"
-#include        "bseserver.h"
-#include        "bsestorage.h"
-#include        "bseexports.h"
-#include        <string.h>
+#include "bseprocedure.h"
+#include "bsemain.h"
+#include <gobject/gvaluecollector.h>
+#include "bseobject.h"
+#include "bseserver.h"
+#include "bsestorage.h"
+#include "bseexports.h"
+#include <string.h>
 
 
 /* --- macros --- */
 #define parse_or_return         bse_storage_scanner_parse_or_return
 #define peek_or_return          bse_storage_scanner_peek_or_return
-#define DEBUG                   sfi_debug_keyfunc ("procs")
+#define EXEC_DEBUG              sfi_debug_keyfunc ("proc-exec")
 #define HACK_DEBUG /* very slow and leaks memory */ while (0) g_message
 
 
@@ -38,41 +38,19 @@ static void     bse_procedure_base_init           (BseProcedureClass        *pro
 static void     bse_procedure_base_finalize       (BseProcedureClass        *proc);
 static void     bse_procedure_init                (BseProcedureClass        *proc,
                                                    const BseExportNodeProc  *pnode);
+static void     procedure_class_unref             (BseProcedureClass        *proc);
 
 
 /* --- functions --- */
-extern void
-bse_type_register_procedure_info (GTypeInfo *info)
-{
-  static const GTypeInfo proc_info = {
-    sizeof (BseProcedureClass),
-    
-    (GBaseInitFunc) bse_procedure_base_init,
-    (GBaseFinalizeFunc) bse_procedure_base_finalize,
-    (GClassInitFunc) NULL,
-    (GClassFinalizeFunc) NULL,
-    NULL /* class_data */,
-    
-    /* non classed type stuff */
-    0, 0, NULL,
-  };
-  
-  *info = proc_info;
-}
-
 static void
 bse_procedure_base_init (BseProcedureClass *proc)
 {
-  proc->name = NULL;
-  proc->blurb = NULL;
   proc->private_id = 0;
-  proc->help = NULL;
-  proc->authors = NULL;
-  proc->license = NULL;
   proc->n_in_pspecs = 0;
   proc->in_pspecs = NULL;
   proc->n_out_pspecs = 0;
   proc->out_pspecs = NULL;
+  proc->cache_stamp = 0;
   proc->execute = NULL;
 }
 
@@ -81,12 +59,6 @@ bse_procedure_base_finalize (BseProcedureClass *proc)
 {
   guint i;
   
-  proc->name = NULL;
-  proc->blurb = NULL;
-  proc->help = NULL;
-  proc->authors = NULL;
-  proc->license = NULL;
-  
   /* give up type references */
   for (i = 0; proc->class_refs[i]; i++)
     g_type_class_unref (proc->class_refs[i]);
@@ -110,31 +82,16 @@ bse_procedure_init (BseProcedureClass       *proc,
   GParamSpec *in_pspecs[BSE_PROCEDURE_MAX_IN_PARAMS + 8];
   GParamSpec *out_pspecs[BSE_PROCEDURE_MAX_OUT_PARAMS + 8];
   guint i, j;
-  gchar *const_name, *const_blurb;
   
   memset (in_pspecs, 0, sizeof (in_pspecs));
   memset (out_pspecs, 0, sizeof (out_pspecs));
   
-  proc->name = g_type_name (BSE_PROCEDURE_TYPE (proc));
-  proc->blurb = bse_type_blurb (BSE_PROCEDURE_TYPE (proc));
   proc->private_id = pnode->private_id;
   
   /* init procedure class from plugin,
    * paranoia check certain class members
    */
-  const_name = proc->name;
-  const_blurb = proc->blurb;
   pnode->init (proc, in_pspecs, out_pspecs);
-  if (proc->name != const_name)
-    {
-      proc->name = const_name;
-      g_warning ("procedure \"%s\" redefines procedure name", proc->name);
-    }
-  if (proc->blurb != const_blurb)
-    {
-      proc->blurb = const_blurb;
-      g_warning ("procedure \"%s\" redefines procedure blurb", proc->name);
-    }
   if (proc->n_in_pspecs || proc->in_pspecs ||
       proc->n_out_pspecs || proc->out_pspecs ||
       proc->execute)
@@ -144,7 +101,7 @@ bse_procedure_init (BseProcedureClass       *proc,
       proc->n_out_pspecs = 0;
       proc->out_pspecs = NULL;
       proc->execute = NULL;
-      g_warning ("procedure \"%s\" messes with reserved class members", proc->name);
+      g_warning ("procedure \"%s\" messes with reserved class members", BSE_PROCEDURE_NAME (proc));
     }
   
   /* check input parameters and setup specifications */
@@ -153,8 +110,7 @@ bse_procedure_init (BseProcedureClass       *proc,
       {
         if ((in_pspecs[i]->flags & G_PARAM_READWRITE) != G_PARAM_READWRITE)
           g_warning ("procedure \"%s\": input parameter \"%s\" has invalid flags",
-                     proc->name,
-                     in_pspecs[i]->name);
+                     BSE_PROCEDURE_NAME (proc), in_pspecs[i]->name);
         g_param_spec_ref (in_pspecs[i]);
         g_param_spec_sink (in_pspecs[i]);
       }
@@ -162,7 +118,7 @@ bse_procedure_init (BseProcedureClass       *proc,
       break;
   if (i == BSE_PROCEDURE_MAX_IN_PARAMS && in_pspecs[i])
     g_warning ("procedure \"%s\" exceeds maximum number of input parameters (%u)",
-               proc->name, BSE_PROCEDURE_MAX_IN_PARAMS);
+               BSE_PROCEDURE_NAME (proc), BSE_PROCEDURE_MAX_IN_PARAMS);
   proc->n_in_pspecs = i;
   proc->in_pspecs = g_new (GParamSpec*, proc->n_in_pspecs + 1);
   memcpy (proc->in_pspecs, in_pspecs, sizeof (in_pspecs[0]) * proc->n_in_pspecs);
@@ -174,8 +130,7 @@ bse_procedure_init (BseProcedureClass       *proc,
       {
         if ((out_pspecs[i]->flags & G_PARAM_READWRITE) != G_PARAM_READWRITE)
           g_warning ("procedure \"%s\": output parameter \"%s\" has invalid flags",
-                     proc->name,
-                     out_pspecs[i]->name);
+                     BSE_PROCEDURE_NAME (proc), out_pspecs[i]->name);
         g_param_spec_ref (out_pspecs[i]);
         g_param_spec_sink (out_pspecs[i]);
       }
@@ -183,7 +138,7 @@ bse_procedure_init (BseProcedureClass       *proc,
       break;
   if (i == BSE_PROCEDURE_MAX_OUT_PARAMS && out_pspecs[i])
     g_warning ("procedure \"%s\" exceeds maximum number of output parameters (%u)",
-               proc->name, BSE_PROCEDURE_MAX_OUT_PARAMS);
+               BSE_PROCEDURE_NAME (proc), BSE_PROCEDURE_MAX_OUT_PARAMS);
   proc->n_out_pspecs = i;
   proc->out_pspecs = g_new (GParamSpec*, proc->n_out_pspecs + 1);
   memcpy (proc->out_pspecs, out_pspecs, sizeof (out_pspecs[0]) * proc->n_out_pspecs);
@@ -216,7 +171,6 @@ bse_procedure_complete_info (const BseExportNodeProc *pnode,
 
 const gchar*
 bse_procedure_type_register (const gchar *name,
-                             const gchar *blurb,
                              BsePlugin   *plugin,
                              GType       *ret_type)
 {
@@ -246,10 +200,7 @@ bse_procedure_type_register (const gchar *name,
         return "Procedure base type invalid";
     }
   
-  type = bse_type_register_dynamic (BSE_TYPE_PROCEDURE,
-                                    name,
-                                    blurb,
-                                    G_TYPE_PLUGIN (plugin));
+  type = bse_type_register_dynamic (BSE_TYPE_PROCEDURE, name, G_TYPE_PLUGIN (plugin));
   
   *ret_type = type;
   
@@ -280,10 +231,10 @@ signal_exec_status (BseErrorType       error,
     {
       BseErrorType verror = g_value_get_enum (first_ovalue);
       
-      bse_server_exec_status (bse_server_get (), BSE_EXEC_STATUS_DONE, proc->name, verror ? 0 : 1, verror);
+      bse_server_exec_status (bse_server_get (), BSE_EXEC_STATUS_DONE, BSE_PROCEDURE_NAME (proc), verror ? 0 : 1, verror);
     }
   else
-    bse_server_exec_status (bse_server_get (), BSE_EXEC_STATUS_DONE, proc->name, error ? 0 : 1, error);
+    bse_server_exec_status (bse_server_get (), BSE_EXEC_STATUS_DONE, BSE_PROCEDURE_NAME (proc), error ? 0 : 1, error);
 #endif
 }
 
@@ -304,7 +255,7 @@ call_proc (BseProcedureClass  *proc,
       if (g_param_value_validate (pspec, ivalues + i) && !(pspec->flags & G_PARAM_LAX_VALIDATION))
         {
           g_warning ("%s: input arg `%s' contains invalid value",
-                     proc->name,
+                     BSE_PROCEDURE_NAME (proc),
                      pspec->name);
           bail_out = TRUE;
         }
@@ -317,10 +268,10 @@ call_proc (BseProcedureClass  *proc,
       if (sfi_debug_test_key ("procs"))
         {
           if (proc->n_in_pspecs && G_TYPE_IS_OBJECT (G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[0])))
-            DEBUG ("executing procedure \"%s\" on object %s",
-                   proc->name, bse_object_debug_name (g_value_get_object (ivalues + 0)));
+            EXEC_DEBUG ("executing procedure \"%s\" on object %s",
+                   BSE_PROCEDURE_NAME (proc), bse_object_debug_name (g_value_get_object (ivalues + 0)));
           else
-            DEBUG ("executing procedure \"%s\"", proc->name);
+            EXEC_DEBUG ("executing procedure \"%s\"", BSE_PROCEDURE_NAME (proc));
         }
       if (marshal)
         error = marshal (marshal_data, proc, ivalues, ovalues);
@@ -328,13 +279,13 @@ call_proc (BseProcedureClass  *proc,
         error = proc->execute (proc, ivalues, ovalues);
     }
   
-  for (i = 0; i < proc->n_in_pspecs; i++)
+  for (i = 0; i < proc->n_out_pspecs; i++)
     {
-      GParamSpec *pspec = proc->in_pspecs[i];
+      GParamSpec *pspec = proc->out_pspecs[i];
       
-      if (g_param_value_validate (pspec, ivalues + i) && !(pspec->flags & G_PARAM_LAX_VALIDATION))
+      if (g_param_value_validate (pspec, ovalues + i) && !(pspec->flags & G_PARAM_LAX_VALIDATION))
         g_warning ("%s: internal procedure error: output arg `%s' had invalid value",
-                   proc->name,
+                   BSE_PROCEDURE_NAME (proc),
                    pspec->name);
     }
   
@@ -366,7 +317,7 @@ bse_procedure_marshal (GType               proc_type,
       if (!sfi_value_transform (ivalues + i, tmp_ivalues + i))
         {
           g_warning ("%s: input arg `%s' has invalid type `%s' (expected `%s')",
-                     proc->name,
+                     BSE_PROCEDURE_NAME (proc),
                      pspec->name,
                      G_VALUE_TYPE_NAME (ivalues + i),
                      g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)));
@@ -393,13 +344,13 @@ bse_procedure_marshal (GType               proc_type,
       
       if (!sfi_value_transform (tmp_ovalues + i, ovalues + i))
         g_warning ("%s: output arg `%s' of type `%s' cannot be converted into `%s'",
-                   proc->name,
+                   BSE_PROCEDURE_NAME (proc),
                    pspec->name,
                    g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
                    G_VALUE_TYPE_NAME (ovalues + i));
       g_value_unset (tmp_ovalues + i);
     }
-  g_type_class_unref (proc);
+  procedure_class_unref (proc);
   
   return error;
 }
@@ -418,14 +369,14 @@ bse_procedure_call_collect (BseProcedureClass  *proc,
   guint i, bail_out = FALSE;
   BseErrorType error = BSE_ERROR_NONE;
 
-  HACK_DEBUG ("call %s: ", proc->name);
+  HACK_DEBUG ("call %s: ", BSE_PROCEDURE_NAME (proc));
 
   /* collect first arg */
   if (first_value && first_value != ivalues) /* may skip this since call_proc() does extra validation */
     {
       if (proc->n_in_pspecs < 1)
         g_warning ("%s: input arg supplied for procedure taking `void'",
-                   proc->name);
+                   BSE_PROCEDURE_NAME (proc));
       else
         {
           GParamSpec *pspec = proc->in_pspecs[0];
@@ -434,7 +385,7 @@ bse_procedure_call_collect (BseProcedureClass  *proc,
           if (!sfi_value_transform (first_value, ivalues + 0))
             {
               g_warning ("%s: input arg `%s' has invalid type `%s' (expected `%s')",
-                         proc->name,
+                         BSE_PROCEDURE_NAME (proc),
                          pspec->name,
                          G_VALUE_TYPE_NAME (first_value),
                          g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)));
@@ -457,7 +408,7 @@ bse_procedure_call_collect (BseProcedureClass  *proc,
       if (error_msg)
         {
           g_warning ("%s: failed to collect arg `%s' of type `%s': %s",
-                     proc->name,
+                     BSE_PROCEDURE_NAME (proc),
                      pspec->name,
                      G_VALUE_TYPE_NAME (ivalues + i),
                      error_msg);
@@ -499,7 +450,7 @@ bse_procedure_call_collect (BseProcedureClass  *proc,
           if (error_msg)
             {
               g_warning ("%s: failed to return arg `%s' of type `%s': %s",
-                         proc->name,
+                         BSE_PROCEDURE_NAME (proc),
                          pspec->name,
                          G_VALUE_TYPE_NAME (ovalues + i),
                          error_msg);
@@ -548,7 +499,7 @@ bse_procedure_marshal_valist (GType               proc_type,
   proc = g_type_class_ref (proc_type);
   error = bse_procedure_call_collect (proc, first_value, marshal, marshal_data,
                                       FALSE, skip_ovalues, tmp_ivalues, tmp_ovalues, var_args);
-  g_type_class_unref (proc);
+  procedure_class_unref (proc);
   return error;
 }
 
@@ -574,10 +525,16 @@ bse_procedure_collect_input_args (BseProcedureClass  *proc,
                                   va_list             var_args,
                                   GValue              ivalues[BSE_PROCEDURE_MAX_IN_PARAMS])
 {
+  BseErrorType error;
   g_return_val_if_fail (BSE_IS_PROCEDURE_CLASS (proc), BSE_ERROR_INTERNAL);
 
-  return bse_procedure_call_collect (proc, first_value, NULL, NULL,
-                                     TRUE, TRUE, ivalues, NULL, var_args);
+  /* add an extra reference count to the class */
+  proc = g_type_class_ref (BSE_PROCEDURE_TYPE (proc));
+  error = bse_procedure_call_collect (proc, first_value, NULL, NULL,
+                                      TRUE, TRUE, ivalues, NULL, var_args);
+  /* so the class can enter the cache here */
+  procedure_class_unref (proc);
+  return error;
 }
 
 BseErrorType
@@ -651,14 +608,14 @@ bse_procedure_execvl (BseProcedureClass  *proc,
     memcpy (tmp_ivalues + i, slist->data, sizeof (tmp_ivalues[0]));
   if (slist || i != proc->n_in_pspecs)
     {
-      g_warning ("%s: invalid number of arguments supplied to procedure \"%s\"", G_STRLOC, proc->name);
+      g_warning ("%s: invalid number of arguments supplied to procedure \"%s\"", G_STRLOC, BSE_PROCEDURE_NAME (proc));
       return BSE_ERROR_PROC_PARAM_INVAL;
     }
   for (i = 0, slist = out_value_list; slist && i < proc->n_out_pspecs; i++, slist = slist->next)
     memcpy (tmp_ovalues + i, slist->data, sizeof (tmp_ovalues[0]));
   if (slist || i != proc->n_out_pspecs)
     {
-      g_warning ("%s: invalid number of arguments supplied to procedure \"%s\"", G_STRLOC, proc->name);
+      g_warning ("%s: invalid number of arguments supplied to procedure \"%s\"", G_STRLOC, BSE_PROCEDURE_NAME (proc));
       return BSE_ERROR_PROC_PARAM_INVAL;
     }
   error = bse_procedure_marshal (BSE_PROCEDURE_TYPE (proc), tmp_ivalues, tmp_ovalues, marshal, marshal_data);
@@ -666,3 +623,134 @@ bse_procedure_execvl (BseProcedureClass  *proc,
     memcpy (slist->data, tmp_ovalues + i, sizeof (tmp_ivalues[0]));
   return error;
 }
+
+static BseProcedureClass *proc_cache = NULL;
+static guint64            cache_time = 0;
+
+static gboolean
+proc_cache_prepare (GSource *source,
+                    gint    *timeout_p)
+{
+  gboolean need_dispatch = FALSE;
+  if (proc_cache)
+    {
+      const guint delay_msecs = 500;
+      GTimeVal current_time;
+      guint64 stime;
+      g_source_get_current_time (source, &current_time);
+      BSE_THREADS_ENTER ();
+      stime = current_time.tv_sec * 1000 + current_time.tv_usec / 1000; /* milliseconds */
+      if (stime >= cache_time + delay_msecs)
+        need_dispatch = TRUE;
+      else
+        {
+          if (stime < cache_time)       /* handle time warp */
+            cache_time = stime;
+          if (timeout_p)
+            *timeout_p = delay_msecs - (stime - cache_time);
+        }
+      BSE_THREADS_LEAVE ();
+    }
+  return need_dispatch;
+}
+
+static gboolean
+proc_cache_check (GSource *source)
+{
+  return proc_cache_prepare (source, NULL);
+}
+
+static gboolean
+proc_cache_dispatch (GSource    *source,
+                     GSourceFunc callback,
+                     gpointer    user_data)
+{
+  BseProcedureClass *ulist = NULL, *proc, *last = NULL;
+  GTimeVal current_time;
+
+  BSE_THREADS_ENTER ();
+  proc = proc_cache;
+  while (proc)
+    {
+      BseProcedureClass *next = proc->cache_next;
+      if (proc->cache_stamp < 2)        /* purging of old procs */
+        {
+          /* unlink */
+          if (last)
+            last->cache_next = next;
+          else
+            proc_cache = next;
+          /* enter free list */
+          proc->cache_next = ulist;
+          ulist = proc;
+          proc->cache_stamp = 0;
+        }
+      else
+        {
+          proc->cache_stamp = 1;        /* aging of recent procs */
+          last = proc;
+        }
+      proc = next;
+    }
+  while (ulist)
+    {
+      proc = ulist;
+      ulist = proc->cache_next;
+      proc->cache_next = NULL;
+      // g_printerr ("release-procedure: %s\n", BSE_PROCEDURE_NAME (proc));
+      g_type_class_unref (proc);
+    }
+  g_source_get_current_time (source, &current_time);
+  cache_time = current_time.tv_sec * 1000 + current_time.tv_usec / 1000; /* milliseconds */
+  BSE_THREADS_LEAVE ();
+  return TRUE;
+}
+
+static void
+procedure_class_unref (BseProcedureClass *proc)
+{
+  /* we cache procedure class creation here, to avoid recreating
+   * procedure classes over and over per-invocation
+   */
+  if (!proc->cache_stamp)
+    {
+      // g_printerr ("cache-procedure: %s\n", BSE_PROCEDURE_NAME (proc));
+      g_assert (proc->cache_next == NULL);
+      proc->cache_stamp = 2;        /* 'recent' stamp */
+      proc->cache_next = proc_cache;
+      proc_cache = proc;
+    }
+  else  /* cached already */
+    {
+      proc->cache_stamp = 2;        /* 'recent' stamp */
+      g_type_class_unref (proc);
+    }
+}
+
+extern void
+bse_type_register_procedure_info (GTypeInfo *info)
+{
+  static const GTypeInfo proc_info = {
+    sizeof (BseProcedureClass),
+    
+    (GBaseInitFunc) bse_procedure_base_init,
+    (GBaseFinalizeFunc) bse_procedure_base_finalize,
+    (GClassInitFunc) NULL,
+    (GClassFinalizeFunc) NULL,
+    NULL /* class_data */,
+    
+    /* non classed type stuff */
+    0, 0, NULL,
+  };
+  static GSourceFuncs proc_cache_source_funcs = {
+    proc_cache_prepare,
+    proc_cache_check,
+    proc_cache_dispatch,
+    NULL
+  };
+  GSource *source = g_source_new (&proc_cache_source_funcs, sizeof (*source));
+  g_source_set_priority (source, BSE_PRIORITY_BACKGROUND);
+  g_source_attach (source, bse_main_context);
+
+  *info = proc_info;
+}
