@@ -26,17 +26,11 @@ bse_note_to_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamS
 #line 31 "bseprocedure.proc"
  {
 #line 33 "bseprocedure.proc"
-  *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_DEFAULT);
+  *(in_pspecs++)    = bse_pspec_note_simple ("note", "Note", NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = bse_param_spec_fine_tune ("fine_tune", "Fine Tune", NULL);
   *(out_pspecs++)   = sfi_pspec_real ("frequency", "Frequency", NULL,
 			  BSE_KAMMER_FREQUENCY_f, 0, BSE_MAX_FREQUENCY_f, 0.1,
-			  SFI_PARAM_DEFAULT);
-#line 32 "bseprocedure.proc"
-  proc->help = "Retrieve the frequency of a certain note.";
-#line 28 "bseprocedure.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 29 "bseprocedure.proc"
-  proc->license = "GNU General Public License";
+			  SFI_PARAM_STANDARD);
 #line 38 "bseprocedure.proc"
 }  }
 static BseErrorType
@@ -77,14 +71,8 @@ bse_note_from_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
 #line 64 "bseprocedure.proc"
   *(in_pspecs++)    = sfi_pspec_real ("frequency", "Frequency", NULL,
 			  BSE_KAMMER_FREQUENCY_f, 0, BSE_MAX_FREQUENCY_f, 0.1,
-			  SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = sfi_pspec_note ("note", "Note", NULL, SFI_KAMMER_NOTE, SFI_MIN_NOTE, SFI_MAX_NOTE, TRUE, SFI_PARAM_DEFAULT);
-#line 63 "bseprocedure.proc"
-  proc->help = "Retrieve the note of a certain frequency.";
-#line 28 "bseprocedure.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 29 "bseprocedure.proc"
-  proc->license = "GNU General Public License";
+			  SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_note ("note", "Note", NULL, SFI_KAMMER_NOTE, SFI_MIN_NOTE, SFI_MAX_NOTE, TRUE, SFI_PARAM_STANDARD);
 #line 68 "bseprocedure.proc"
 }  }
 static BseErrorType
@@ -105,25 +93,19 @@ bse_note_from_freq_exec (BseProcedureClass *proc,
   return BSE_ERROR_NONE;
 }
 
-/* --- bse-type-blurb --- */
+/* --- bse-type-options --- */
 static void
-bse_type_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+bse_type_options_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
 #line 81 "bseprocedure.proc"
  {
 #line 83 "bseprocedure.proc"
-  *(in_pspecs++)    = sfi_pspec_string ("type", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = sfi_pspec_string ("blurb", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
-#line 82 "bseprocedure.proc"
-  proc->help = "Retrieve the blurb for a specific type.";
-#line 28 "bseprocedure.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 29 "bseprocedure.proc"
-  proc->license = "GNU General Public License";
+  *(in_pspecs++)    = sfi_pspec_string ("type", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_STANDARD);
 #line 85 "bseprocedure.proc"
 }  }
 static BseErrorType
 #line 85 "bseprocedure.proc"
-bse_type_blurb_exec (BseProcedureClass *proc,
+bse_type_options_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
 #line 88 "bseprocedure.proc"
@@ -142,7 +124,115 @@ bse_type_blurb_exec (BseProcedureClass *proc,
 
 #line 99 "bseprocedure.proc"
   
-  sfi_value_set_string (out_values++, type ? bse_type_blurb (type) : NULL);
+  sfi_value_set_string (out_values++, type ? bse_type_get_options (type) : NULL);
+
+  return BSE_ERROR_NONE;
+}
+
+/* --- bse-type-blurb --- */
+static void
+bse_type_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 105 "bseprocedure.proc"
+ {
+#line 107 "bseprocedure.proc"
+  *(in_pspecs++)    = sfi_pspec_string ("type", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+#line 109 "bseprocedure.proc"
+}  }
+static BseErrorType
+#line 109 "bseprocedure.proc"
+bse_type_blurb_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 112 "bseprocedure.proc"
+{
+#line 113 "bseprocedure.proc"
+  
+  gchar *stype = sfi_value_get_string (in_values++);
+  GType type;
+
+#line 117 "bseprocedure.proc"
+  
+  if (!stype)
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+  type = g_type_from_name (stype);
+
+#line 123 "bseprocedure.proc"
+  
+  sfi_value_set_string (out_values++, type ? bse_type_get_blurb (type) : NULL);
+
+  return BSE_ERROR_NONE;
+}
+
+/* --- bse-type-authors --- */
+static void
+bse_type_authors_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 129 "bseprocedure.proc"
+ {
+#line 131 "bseprocedure.proc"
+  *(in_pspecs++)    = sfi_pspec_string ("type", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+#line 133 "bseprocedure.proc"
+}  }
+static BseErrorType
+#line 133 "bseprocedure.proc"
+bse_type_authors_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 136 "bseprocedure.proc"
+{
+#line 137 "bseprocedure.proc"
+  
+  gchar *stype = sfi_value_get_string (in_values++);
+  GType type;
+
+#line 141 "bseprocedure.proc"
+  
+  if (!stype)
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+  type = g_type_from_name (stype);
+
+#line 147 "bseprocedure.proc"
+  
+  sfi_value_set_string (out_values++, type ? bse_type_get_authors (type) : NULL);
+
+  return BSE_ERROR_NONE;
+}
+
+/* --- bse-type-license --- */
+static void
+bse_type_license_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
+#line 153 "bseprocedure.proc"
+ {
+#line 155 "bseprocedure.proc"
+  *(in_pspecs++)    = sfi_pspec_string ("type", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+#line 157 "bseprocedure.proc"
+}  }
+static BseErrorType
+#line 157 "bseprocedure.proc"
+bse_type_license_exec (BseProcedureClass *proc,
+        const GValue      *in_values,
+        GValue            *out_values)
+#line 160 "bseprocedure.proc"
+{
+#line 161 "bseprocedure.proc"
+  
+  gchar *stype = sfi_value_get_string (in_values++);
+  GType type;
+
+#line 165 "bseprocedure.proc"
+  
+  if (!stype)
+    return BSE_ERROR_PROC_PARAM_INVAL;
+
+  type = g_type_from_name (stype);
+
+#line 171 "bseprocedure.proc"
+  
+  sfi_value_set_string (out_values++, type ? bse_type_get_license (type) : NULL);
 
   return BSE_ERROR_NONE;
 }
@@ -154,53 +244,47 @@ str2num (const gchar *str,
   gchar *num_any = ".0123456789", *num_first = num_any + 1;
   while (nth--)
     {
-#line 112 "bseprocedure.proc"
+#line 184 "bseprocedure.proc"
       
       if (*str && strchr (num_first, *str))
         do
           str++;
         while (*str && strchr (num_any, *str));
-#line 117 "bseprocedure.proc"
+#line 189 "bseprocedure.proc"
       
       while (*str && !strchr (num_first, *str))
         str++;
       if (!*str)
-#line 121 "bseprocedure.proc"
+#line 193 "bseprocedure.proc"
         return 0;       
     }
   if (strchr (num_first, *str))
     return g_strtod (str, NULL);
-#line 125 "bseprocedure.proc"
+#line 197 "bseprocedure.proc"
   return 0; 
 }
 
 /* --- bse-string-extract-number --- */
 static void
 bse_string_extract_number_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 128 "bseprocedure.proc"
+#line 200 "bseprocedure.proc"
  {
-#line 130 "bseprocedure.proc"
-  *(in_pspecs++)    = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = sfi_pspec_string ("format", NULL, NULL, NULL, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = sfi_pspec_real ("aux_base", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = sfi_pspec_real ("dflt", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = sfi_pspec_real ("number", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_DEFAULT);
-#line 129 "bseprocedure.proc"
-  proc->help = "Retrieve numbers from a string.";
-#line 28 "bseprocedure.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 29 "bseprocedure.proc"
-  proc->license = "GNU General Public License";
-#line 135 "bseprocedure.proc"
+#line 202 "bseprocedure.proc"
+  *(in_pspecs++)    = sfi_pspec_string ("string", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_string ("format", NULL, NULL, NULL, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_real ("aux_base", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = sfi_pspec_real ("dflt", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = sfi_pspec_real ("number", NULL, NULL, 0, -SFI_MAXNUM, SFI_MAXNUM, 0, SFI_PARAM_STANDARD);
+#line 207 "bseprocedure.proc"
 }  }
 static BseErrorType
-#line 135 "bseprocedure.proc"
+#line 207 "bseprocedure.proc"
 bse_string_extract_number_exec (BseProcedureClass *proc,
         const GValue      *in_values,
         GValue            *out_values)
-#line 138 "bseprocedure.proc"
+#line 210 "bseprocedure.proc"
 {
-#line 139 "bseprocedure.proc"
+#line 211 "bseprocedure.proc"
   
   gchar *string   = sfi_value_get_string (in_values++);
   gchar *format   = sfi_value_get_string (in_values++);
@@ -241,18 +325,18 @@ bse_string_extract_number_exec (BseProcedureClass *proc,
                 ep = (char*) format;
               break;
             default:
-#line 179 "bseprocedure.proc"
+#line 251 "bseprocedure.proc"
               
               number = 0;
               break;
             }
           if (ep && *ep)
             {
-#line 185 "bseprocedure.proc"
+#line 257 "bseprocedure.proc"
               if (*ep == 'm')       
                 number = gsl_temp_freq (gsl_get_config ()->kammer_freq,
                                         number - gsl_get_config ()->midi_kammer_note);
-#line 188 "bseprocedure.proc"
+#line 260 "bseprocedure.proc"
               else 
                 number = 0;
             }
@@ -267,22 +351,79 @@ bse_string_extract_number_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_bse_note_to_freq = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "bse-note-to-freq", "/Proc/Note to Freq", NULL },
+    "bse-note-to-freq", 
+    NULL,
+    "/Proc/Note to Freq",
+    "Retrieve the frequency of a certain note.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_note_to_freq_setup, bse_note_to_freq_exec, 
 };
 static BseExportNodeProc __enode_bse_note_from_freq = {
   { (BseExportNode*) &__enode_bse_note_to_freq, BSE_EXPORT_NODE_PROC,
-    "bse-note-from-freq", "/Proc/Note from Freq", NULL },
+    "bse-note-from-freq", 
+    NULL,
+    "/Proc/Note from Freq",
+    "Retrieve the note of a certain frequency.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_note_from_freq_setup, bse_note_from_freq_exec, 
 };
-static BseExportNodeProc __enode_bse_type_blurb = {
+static BseExportNodeProc __enode_bse_type_options = {
   { (BseExportNode*) &__enode_bse_note_from_freq, BSE_EXPORT_NODE_PROC,
-    "bse-type-blurb", "/Proc/Type Blurb", NULL },
+    "bse-type-options", 
+    NULL,
+    "/Proc/Type Options",
+    "Retrieve the options of a specific type.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
+  0, bse_type_options_setup, bse_type_options_exec, 
+};
+static BseExportNodeProc __enode_bse_type_blurb = {
+  { (BseExportNode*) &__enode_bse_type_options, BSE_EXPORT_NODE_PROC,
+    "bse-type-blurb", 
+    NULL,
+    "/Proc/Type Blurb",
+    "Retrieve the description of a specific type.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_type_blurb_setup, bse_type_blurb_exec, 
 };
-static BseExportNodeProc __enode_bse_string_extract_number = {
+static BseExportNodeProc __enode_bse_type_authors = {
   { (BseExportNode*) &__enode_bse_type_blurb, BSE_EXPORT_NODE_PROC,
-    "bse-string-extract-number", "/Proc/String Extract Number", NULL },
+    "bse-type-authors", 
+    NULL,
+    "/Proc/Type Authors",
+    "Retrieve the authors who implemented a specific type.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
+  0, bse_type_authors_setup, bse_type_authors_exec, 
+};
+static BseExportNodeProc __enode_bse_type_license = {
+  { (BseExportNode*) &__enode_bse_type_authors, BSE_EXPORT_NODE_PROC,
+    "bse-type-license", 
+    NULL,
+    "/Proc/Type License",
+    "Retrieve the license of a type impementation.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
+  0, bse_type_license_setup, bse_type_license_exec, 
+};
+static BseExportNodeProc __enode_bse_string_extract_number = {
+  { (BseExportNode*) &__enode_bse_type_license, BSE_EXPORT_NODE_PROC,
+    "bse-string-extract-number", 
+    NULL,
+    "/Proc/String Extract Number",
+    "Retrieve numbers from a string.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_string_extract_number_setup, bse_string_extract_number_exec, 
 };
 BseExportNode* bse__builtin_init_bseprocedure_gen_proc_c (void);
