@@ -25,7 +25,7 @@
 #include "bsegconfig.h"
 #include "bsemidinotifier.h"
 #include "bsemain.h"		/* threads enter/leave */
-#include "bsemidireceiver.h"
+#include "bsepcmwriter.h"
 #include "bsemididevice-null.h"
 #include "bsejanitor.h"
 #include <fcntl.h>
@@ -40,9 +40,10 @@
 /* --- parameters --- */
 enum
 {
-  PARAM_0,
-  PARAM_GCONFIG,
-  PARAM_PCM_LATENCY,
+  PROP_0,
+  PROP_GCONFIG,
+  PROP_PCM_LATENCY,
+  PROP_WAVE_FILE
 };
 
 
@@ -136,13 +137,17 @@ bse_server_class_init (BseServerClass *class)
   
   _bse_gconfig_init ();
   bse_object_class_add_param (object_class, "BSE Configuration",
-			      PARAM_GCONFIG,
+			      PROP_GCONFIG,
 			      bse_gconfig_pspec ());	/* "bse-preferences" */
   bse_object_class_add_param (object_class, "PCM Settings",
-			      PARAM_PCM_LATENCY,
+			      PROP_PCM_LATENCY,
 			      sfi_pspec_int ("latency", "Latency [ms]", NULL,
 					     50, 1, 2000, 5,
 					     SFI_PARAM_GUI));
+  bse_object_class_add_param (object_class, "PCM Recording",
+			      PROP_WAVE_FILE,
+			      sfi_pspec_string ("wave_file", "WAVE File", NULL,
+						NULL, SFI_PARAM_GUI));
   
   signal_registration = bse_object_class_add_signal (object_class, "registration",
 						     G_TYPE_NONE, 3,
@@ -178,7 +183,9 @@ rc_file_try_statement (gpointer   context_data,
       token = sfi_rstore_parse_param (rstore, value, bse_gconfig_pspec ());
       rec = sfi_value_get_rec (value);
       if (token == G_TOKEN_NONE && rec)
-	g_object_set (server, "bse-preferences", rec, NULL);
+	bse_item_set (server,
+                      "bse-preferences", rec,
+                      NULL);
       sfi_value_free (value);
       return token;
     }
@@ -187,28 +194,29 @@ rc_file_try_statement (gpointer   context_data,
 }
 
 static void
-bse_server_init (BseServer *server)
+bse_server_init (BseServer *self)
 {
   gchar *file_name;
   gint fd;
 
-  g_assert (BSE_OBJECT_ID (server) == 1);	/* assert being the first object */
+  g_assert (BSE_OBJECT_ID (self) == 1);	/* assert being the first object */
+  BSE_OBJECT_SET_FLAGS (self, BSE_ITEM_FLAG_SINGLETON);
 
-  server->engine_source = NULL;
-  server->projects = NULL;
-  server->dev_use_count = 0;
-  server->pcm_latency = 50;
-  server->pcm_device = NULL;
-  server->pcm_imodule = NULL;
-  server->pcm_omodule = NULL;
-  server->midi_device = NULL;
-  BSE_OBJECT_SET_FLAGS (server, BSE_ITEM_FLAG_SINGLETON);
+  self->engine_source = NULL;
+  self->projects = NULL;
+  self->dev_use_count = 0;
+  self->pcm_latency = 50;
+  self->pcm_device = NULL;
+  self->pcm_imodule = NULL;
+  self->pcm_omodule = NULL;
+  self->pcm_writer = NULL;
+  self->midi_device = NULL;
   
   /* keep the server singleton alive */
-  bse_item_use (BSE_ITEM (server));
+  bse_item_use (BSE_ITEM (self));
   
   /* start dispatching main thread stuff */
-  main_thread_source_setup (server);
+  main_thread_source_setup (self);
   
   /* read rc file */
   file_name = g_strconcat (g_get_home_dir (), "/.bserc", NULL);
@@ -217,7 +225,7 @@ bse_server_init (BseServer *server)
     {
       SfiRStore *rstore = sfi_rstore_new ();
       sfi_rstore_input_fd (rstore, fd, file_name);
-      sfi_rstore_parse_all (rstore, server, rc_file_try_statement, NULL);
+      sfi_rstore_parse_all (rstore, self, rc_file_try_statement, NULL);
       sfi_rstore_destroy (rstore);
       close (fd);
     }
@@ -245,17 +253,28 @@ bse_server_set_property (GObject      *object,
     {
       BsePcmHandle *handle;
       SfiRec *rec;
-    case PARAM_GCONFIG:
+    case PROP_GCONFIG:
       rec = sfi_value_get_rec (value);
       if (rec)
 	bse_gconfig_apply (rec);
       break;
-    case PARAM_PCM_LATENCY:
+    case PROP_PCM_LATENCY:
       server->pcm_latency = g_value_get_int (value);
       handle = server->pcm_device ? bse_pcm_device_get_handle (server->pcm_device) : NULL;
       if (handle)
 	bse_pcm_handle_set_watermark (handle, server->pcm_latency);
       break;
+    case PROP_WAVE_FILE:
+      if (!bse_gconfig_locked ())
+	{
+	  server->wave_file = g_strdup_stripped (g_value_get_string (value));
+	  if (!server->wave_file[0])
+	    {
+	      g_free (server->wave_file);
+	      server->wave_file = NULL;
+	    }
+	}
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (server, param_id, pspec);
       break;
@@ -272,14 +291,17 @@ bse_server_get_property (GObject    *object,
   switch (param_id)
     {
       SfiRec *rec;
-    case PARAM_GCONFIG:
+    case PROP_GCONFIG:
       rec = bse_gconfig_to_rec (bse_global_config);
       sfi_value_set_rec (value, rec);
       sfi_rec_unref (rec);
       break;
-    case PARAM_PCM_LATENCY:
+    case PROP_PCM_LATENCY:
       g_value_set_int (value, server->pcm_latency);
       break;
+    case PROP_WAVE_FILE:
+      g_value_set_string (value, server->wave_file);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (server, param_id, pspec);
       break;
@@ -449,6 +471,7 @@ bse_server_open_pcm_device (BseServer *server)
     return BSE_ERROR_DEVICE_NOT_AVAILABLE;
   
   server->pcm_device = g_object_new (choice, NULL);
+  bse_pcm_device_request (server->pcm_device, 2, bse_pcm_freq_mode_from_freq (BSE_GCONFIG (synth_mixing_freq)));
   error = bse_pcm_device_open (server->pcm_device);
   if (error)
     {
@@ -488,9 +511,7 @@ bse_server_open_midi_device (BseServer *server)
       choice = BSE_TYPE_MIDI_DEVICE_NULL;
     }
 
-  server->midi_device = g_object_new (choice,
-				      "midi_receiver", bse_server_get_midi_receiver (server, "default"),
-				      NULL);
+  server->midi_device = g_object_new (choice, NULL);
   error = bse_midi_device_open (server->midi_device);
   if (error)
     {
@@ -530,7 +551,20 @@ bse_server_open_devices (BseServer *self)
 				    self->pcm_latency);
       engine_init (self, bse_pcm_device_get_handle (self->pcm_device)->mix_freq);
       self->pcm_imodule = bse_pcm_imodule_insert (bse_pcm_device_get_handle (self->pcm_device), trans);
-      self->pcm_omodule = bse_pcm_omodule_insert (bse_pcm_device_get_handle (self->pcm_device), trans);
+      if (self->wave_file)
+	{
+	  BseErrorType error;
+	  self->pcm_writer = g_object_new (BSE_TYPE_PCM_WRITER, NULL);
+	  error = bse_pcm_writer_open (self->pcm_writer, self->wave_file, 2, gsl_engine_sample_freq ());
+	  if (error)
+	    {
+	      sfi_info ("failed to open WAV file \"%s\": %s", self->wave_file, bse_error_blurb (error));
+	      g_object_unref (self->pcm_writer);
+	      self->pcm_writer = NULL;
+	    }
+	}
+      self->pcm_omodule = bse_pcm_omodule_insert (bse_pcm_device_get_handle (self->pcm_device),
+						  self->pcm_writer, trans);
       gsl_trans_commit (trans);
       self->dev_use_count++;
     }
@@ -566,8 +600,13 @@ bse_server_close_devices (BseServer *self)
       self->pcm_imodule = NULL;
       bse_pcm_omodule_remove (self->pcm_omodule, trans);
       self->pcm_omodule = NULL;
-      /* we don't need to discard the midi_receiver */
-      // FIXME: discard midi_receiver modules
+      if (self->pcm_writer)
+	{
+	  if (self->pcm_writer->open)
+	    bse_pcm_writer_close (self->pcm_writer);
+	  g_object_unref (self->pcm_writer);
+	  self->pcm_writer = NULL;
+	}
       gsl_trans_commit (trans);
       /* wait until transaction has been processed */
       gsl_engine_wait_on_trans ();
@@ -635,20 +674,6 @@ bse_server_discard_pcm_input_module (BseServer *self,
   bse_server_close_devices (self);
 }
 
-BseMidiReceiver*
-bse_server_get_midi_receiver (BseServer   *self,
-			      const gchar *midi_name)
-{
-  g_return_val_if_fail (BSE_IS_SERVER (self), NULL);
-  g_return_val_if_fail (midi_name != NULL, NULL);
-  
-  if (!self->midi_receiver)
-    self->midi_receiver = bse_midi_receiver_new ("default");
-  // FIXME: we don't actually check the midi_receiver name
-  
-  return self->midi_receiver;
-}
-
 /* bse_server_script_start
  * @script_control: associated script control object
  *
@@ -808,13 +833,11 @@ static gboolean
 main_source_prepare (GSource *source,
 		     gint    *timeout_p)
 {
-  MainSource *xsource = (MainSource*) source;
+  // MainSource *xsource = (MainSource*) source;
   gboolean need_dispatch;
   
   BSE_THREADS_ENTER ();
   need_dispatch = FALSE;
-  if (xsource->server->midi_receiver)
-    need_dispatch |= bse_midi_receiver_has_notify_events (xsource->server->midi_receiver);
   BSE_THREADS_LEAVE ();
   
   return need_dispatch;
@@ -828,8 +851,6 @@ main_source_check (GSource *source)
   
   BSE_THREADS_ENTER ();
   need_dispatch = xsource->pfd.events & xsource->pfd.revents;
-  if (xsource->server->midi_receiver)
-    need_dispatch |= bse_midi_receiver_has_notify_events (xsource->server->midi_receiver);
   BSE_THREADS_LEAVE ();
   
   return need_dispatch;
@@ -840,11 +861,9 @@ main_source_dispatch (GSource    *source,
 		      GSourceFunc callback,
 		      gpointer    user_data)
 {
-  MainSource *xsource = (MainSource*) source;
+  // MainSource *xsource = (MainSource*) source;
   
   BSE_THREADS_ENTER ();
-  if (xsource->server->midi_receiver && xsource->server->midi_receiver->notifier)
-    bse_midi_notifier_dispatch (xsource->server->midi_receiver->notifier, xsource->server->midi_receiver);
   BSE_THREADS_LEAVE ();
   
   return TRUE;
@@ -1058,9 +1077,10 @@ engine_init (BseServer *server,
       engine_is_initialized = TRUE;
       gsl_engine_init (1, BSE_GCONFIG (synth_block_size), mix_freq, 63);
     }
-  else
-    g_assert (mix_freq == gsl_engine_sample_freq () && BSE_GCONFIG (synth_block_size) == gsl_engine_block_size ());
-  
+  else if (mix_freq != gsl_engine_sample_freq () || BSE_GCONFIG (synth_block_size) != gsl_engine_block_size ())
+    g_warning ("mix frequency or block size mistmatch (%f == %u, %u == %u) restart recommended", /* FIXME */
+               mix_freq, gsl_engine_sample_freq (), BSE_GCONFIG (synth_block_size), gsl_engine_block_size ());
+
   g_source_attach (server->engine_source, bse_main_context);
 }
 
