@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 1997-2002 Tim Janik
+ * Copyright (C) 1997-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,7 @@
 #include        <bse/bsesnet.h>
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 /* --- BSE type macros --- */
@@ -45,7 +43,7 @@ struct _BseSong
   BseSNet           parent_instance;
   
   guint		    tpqn;		/* ticks per querter note */
-  guint		    nominator;
+  guint		    numerator;
   guint		    denominator;
   gfloat            bpm;
   gfloat            volume_factor;      /* 1-based factor */
@@ -53,12 +51,17 @@ struct _BseSong
   GList            *parts;              /* of type BsePart* */
 
   BseSource	   *context_merger;
+  BseSource	   *postprocess;
   BseSource	   *output;
 
+  BseSNet         *pnet;
+
   /* song position pointer */
   SfiInt	    last_position;
   guint		    position_handler;
 
+  BseMidiReceiver  *midi_receiver_SL;
+
   /* fields protected by sequencer mutex */
   gdouble	    tpsi_SL;		/* ticks per stamp increment (sample) */
   SfiRing	   *tracks_SL;		/* of type BseTrack* */
@@ -87,8 +90,6 @@ void		bse_song_get_timing		(BseSong	*self,
 void		bse_song_timing_get_default	(BseSongTiming	*timing);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __BSE_SONG_H__ */
