@@ -20,23 +20,17 @@ set_input_by_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSp
  {
 #line 31 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("imodule", "Input Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("omodule", "Output Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("output-channel", "Output Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 30 "bsesource.proc"
-  proc->help = "Connect a module input to another module's output.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 43 "bsesource.proc"
  }
 static BseErrorType
@@ -80,23 +74,17 @@ set_input_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 72 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("imodule", "Input Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("input-channel", "Input Channel", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("omodule", "Output Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("output-channel", "Output Channel", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 71 "bsesource.proc"
-  proc->help = "Connect a module input to another module's output.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 84 "bsesource.proc"
  }
 static BseErrorType
@@ -144,23 +132,17 @@ unset_input_by_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
  {
 #line 117 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("omodule", "Output Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("output-channel", "Output Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 116 "bsesource.proc"
-  proc->help = "Disconnect a module input.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 129 "bsesource.proc"
  }
 static BseErrorType
@@ -209,23 +191,17 @@ unset_input_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
  {
 #line 163 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("input-channel", "Input Channel", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++) = bse_param_spec_object ("omodule", "Output Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("output-channel", "Output Channel", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 162 "bsesource.proc"
-  proc->help = "Disconnect a module input.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 175 "bsesource.proc"
  }
 static BseErrorType
@@ -278,14 +254,8 @@ clear_inputs_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 213 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
 }
-#line 212 "bsesource.proc"
-  proc->help = "Disconnect all module inputs.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 216 "bsesource.proc"
  }
 static BseErrorType
@@ -323,14 +293,8 @@ clear_outputs_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 240 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
 }
-#line 239 "bsesource.proc"
-  proc->help = "Disconnect all module outputs.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 243 "bsesource.proc"
  }
 static BseErrorType
@@ -368,16 +332,10 @@ has_outputs_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
  {
 #line 267 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("has_outputs", "Has Outputs", NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
+			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 266 "bsesource.proc"
-  proc->help = "Check whether a module has output channel connections.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 272 "bsesource.proc"
  }
 static BseErrorType
@@ -410,16 +368,10 @@ n_ichannels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
  {
 #line 291 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_channels", "Number of Channels", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 290 "bsesource.proc"
-  proc->help = "Get the number of input channels of a module.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 296 "bsesource.proc"
  }
 static BseErrorType
@@ -452,18 +404,12 @@ ichannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 315 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 314 "bsesource.proc"
-  proc->help = "Get input channel name.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 322 "bsesource.proc"
  }
 static BseErrorType
@@ -497,18 +443,12 @@ ichannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 342 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 341 "bsesource.proc"
-  proc->help = "Get canonical input channel name.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 349 "bsesource.proc"
  }
 static BseErrorType
@@ -542,18 +482,12 @@ ichannel_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 369 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_blurb", "Channel Blurb", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 368 "bsesource.proc"
-  proc->help = "Get input channel description.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 376 "bsesource.proc"
  }
 static BseErrorType
@@ -587,18 +521,12 @@ is_joint_ichannel_by_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs,
  {
 #line 396 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("is_jchannel", "Is Joint Channel", NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
+			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 395 "bsesource.proc"
-  proc->help = "Check if an input channel is a joint (multi-connect) channel.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 403 "bsesource.proc"
  }
 static BseErrorType
@@ -632,18 +560,12 @@ is_joint_ichannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParam
  {
 #line 423 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("input-channel", "Input Channel", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_bool ("is_jchannel", "Is Joint Channel", NULL,
-			  FALSE, SFI_PARAM_DEFAULT);
+			  FALSE, SFI_PARAM_STANDARD);
 }
-#line 422 "bsesource.proc"
-  proc->help = "Check if an input channel is a joint (multi-connect) channel.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 430 "bsesource.proc"
  }
 static BseErrorType
@@ -680,18 +602,12 @@ ichannel_get_n_joints_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
  {
 #line 453 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_joints", "Number of Connections", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 452 "bsesource.proc"
-  proc->help = "Retrieve the number of inputs connected to an input channel.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 460 "bsesource.proc"
  }
 static BseErrorType
@@ -730,20 +646,14 @@ ichannel_get_osource_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPa
  {
 #line 485 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-joint", "Input Joint", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("osource", "Output Source", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
 }
-#line 484 "bsesource.proc"
-  proc->help = "Retrieve output module connected to a specific joint of an input channel";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 494 "bsesource.proc"
  }
 static BseErrorType
@@ -785,20 +695,14 @@ ichannel_get_ochannel_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GP
  {
 #line 522 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-joint", "Input Joint", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("ochannel", "Output Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 521 "bsesource.proc"
-  proc->help = "Retrieve output channel of the module connected to a specific joint of an input channel.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 531 "bsesource.proc"
  }
 static BseErrorType
@@ -840,16 +744,10 @@ n_ochannels_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec *
  {
 #line 559 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_channels", "Number of Channels", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 558 "bsesource.proc"
-  proc->help = "Get the number of output channels of a module.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 564 "bsesource.proc"
  }
 static BseErrorType
@@ -882,18 +780,12 @@ ochannel_name_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 583 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 582 "bsesource.proc"
-  proc->help = "Get output channel name.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 590 "bsesource.proc"
  }
 static BseErrorType
@@ -927,18 +819,12 @@ ochannel_ident_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 610 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_name", "Channel Name", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 609 "bsesource.proc"
-  proc->help = "Get canonical output channel name.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 617 "bsesource.proc"
  }
 static BseErrorType
@@ -972,18 +858,12 @@ ochannel_blurb_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpe
  {
 #line 637 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_int ("input-channel", "Input Channel", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_string ("channel_blurb", "Channel Blurb", NULL,
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
 }
-#line 636 "bsesource.proc"
-  proc->help = "Get output channel description.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 644 "bsesource.proc"
  }
 static BseErrorType
@@ -1017,23 +897,12 @@ set_pos_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out
  {
 #line 669 "bsesource.proc"
   *(in_pspecs++) = bse_param_spec_object ("module", "Module", NULL,
-				 BSE_TYPE_SOURCE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_SOURCE, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("x-pos", "X Position", NULL,
-                          0, -SFI_MAXREAL, SFI_MAXREAL, 1, SFI_PARAM_DEFAULT);
+                          0, -SFI_MAXREAL, SFI_MAXREAL, 1, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_real ("y-pos", "Y Position", NULL,
-                          0, -SFI_MAXREAL, SFI_MAXREAL, 1, SFI_PARAM_DEFAULT);
+                          0, -SFI_MAXREAL, SFI_MAXREAL, 1, SFI_PARAM_STANDARD);
 }
-#line 663 "bsesource.proc"
-  proc->help = "Set the x and y position of a module. In contrast to setting the position "
-          "through ordinary object property setters, this function will not update "
-          "the module position if the passed in arguments are sufficiently equal to "
-          "the values already set on the object. As such, it does not record an extra "
-          "undo step for setting properties to values they already have and if necessary "
-          "turns setting of x and y positions into an atomic undo operation.";
-#line 26 "bsesource.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 27 "bsesource.proc"
-  proc->license = "GNU Lesser General Public License";
 #line 676 "bsesource.proc"
  }
 static BseErrorType
@@ -1075,107 +944,238 @@ set_pos_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_set_input_by_id = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseSource+set-input-by-id", "/Methods/BseSource/General/Set Input By Id", NULL },
+    "BseSource+set-input-by-id", 
+    NULL,
+    "/Methods/BseSource/General/Set Input By Id",
+    "Connect a module input to another module's output.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, set_input_by_id_setup, set_input_by_id_exec, 
 };
 static BseExportNodeProc __enode_set_input = {
   { (BseExportNode*) &__enode_set_input_by_id, BSE_EXPORT_NODE_PROC,
-    "BseSource+set-input", "/Methods/BseSource/General/Set Input", NULL },
+    "BseSource+set-input", 
+    NULL,
+    "/Methods/BseSource/General/Set Input",
+    "Connect a module input to another module's output.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, set_input_setup, set_input_exec, 
 };
 static BseExportNodeProc __enode_unset_input_by_id = {
   { (BseExportNode*) &__enode_set_input, BSE_EXPORT_NODE_PROC,
-    "BseSource+unset-input-by-id", "/Methods/BseSource/General/Unset Input By Id", NULL },
+    "BseSource+unset-input-by-id", 
+    NULL,
+    "/Methods/BseSource/General/Unset Input By Id",
+    "Disconnect a module input.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, unset_input_by_id_setup, unset_input_by_id_exec, 
 };
 static BseExportNodeProc __enode_unset_input = {
   { (BseExportNode*) &__enode_unset_input_by_id, BSE_EXPORT_NODE_PROC,
-    "BseSource+unset-input", "/Methods/BseSource/General/Unset Input", NULL },
+    "BseSource+unset-input", 
+    NULL,
+    "/Methods/BseSource/General/Unset Input",
+    "Disconnect a module input.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, unset_input_setup, unset_input_exec, 
 };
 static BseExportNodeProc __enode_clear_inputs = {
   { (BseExportNode*) &__enode_unset_input, BSE_EXPORT_NODE_PROC,
-    "BseSource+clear-inputs", "/Methods/BseSource/General/Clear Inputs", NULL },
+    "BseSource+clear-inputs", 
+    NULL,
+    "/Methods/BseSource/General/Clear Inputs",
+    "Disconnect all module inputs.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, clear_inputs_setup, clear_inputs_exec, 
 };
 static BseExportNodeProc __enode_clear_outputs = {
   { (BseExportNode*) &__enode_clear_inputs, BSE_EXPORT_NODE_PROC,
-    "BseSource+clear-outputs", "/Methods/BseSource/General/Clear Outputs", NULL },
+    "BseSource+clear-outputs", 
+    NULL,
+    "/Methods/BseSource/General/Clear Outputs",
+    "Disconnect all module outputs.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, clear_outputs_setup, clear_outputs_exec, 
 };
 static BseExportNodeProc __enode_has_outputs = {
   { (BseExportNode*) &__enode_clear_outputs, BSE_EXPORT_NODE_PROC,
-    "BseSource+has-outputs", "/Methods/BseSource/General/Has Outputs", NULL },
+    "BseSource+has-outputs", 
+    NULL,
+    "/Methods/BseSource/General/Has Outputs",
+    "Check whether a module has output channel connections.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, has_outputs_setup, has_outputs_exec, 
 };
 static BseExportNodeProc __enode_n_ichannels = {
   { (BseExportNode*) &__enode_has_outputs, BSE_EXPORT_NODE_PROC,
-    "BseSource+n-ichannels", "/Methods/BseSource/General/N Ichannels", NULL },
+    "BseSource+n-ichannels", 
+    NULL,
+    "/Methods/BseSource/General/N Ichannels",
+    "Get the number of input channels of a module.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, n_ichannels_setup, n_ichannels_exec, 
 };
 static BseExportNodeProc __enode_ichannel_name = {
   { (BseExportNode*) &__enode_n_ichannels, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-name", "/Methods/BseSource/General/Ichannel Name", NULL },
+    "BseSource+ichannel-name", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Name",
+    "Get input channel name.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_name_setup, ichannel_name_exec, 
 };
 static BseExportNodeProc __enode_ichannel_ident = {
   { (BseExportNode*) &__enode_ichannel_name, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-ident", "/Methods/BseSource/General/Ichannel Ident", NULL },
+    "BseSource+ichannel-ident", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Ident",
+    "Get canonical input channel name.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_ident_setup, ichannel_ident_exec, 
 };
 static BseExportNodeProc __enode_ichannel_blurb = {
   { (BseExportNode*) &__enode_ichannel_ident, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-blurb", "/Methods/BseSource/General/Ichannel Blurb", NULL },
+    "BseSource+ichannel-blurb", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Blurb",
+    "Get input channel description.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_blurb_setup, ichannel_blurb_exec, 
 };
 static BseExportNodeProc __enode_is_joint_ichannel_by_id = {
   { (BseExportNode*) &__enode_ichannel_blurb, BSE_EXPORT_NODE_PROC,
-    "BseSource+is-joint-ichannel-by-id", "/Methods/BseSource/General/Is Joint Ichannel By Id", NULL },
+    "BseSource+is-joint-ichannel-by-id", 
+    NULL,
+    "/Methods/BseSource/General/Is Joint Ichannel By Id",
+    "Check if an input channel is a joint (multi-connect) channel.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, is_joint_ichannel_by_id_setup, is_joint_ichannel_by_id_exec, 
 };
 static BseExportNodeProc __enode_is_joint_ichannel = {
   { (BseExportNode*) &__enode_is_joint_ichannel_by_id, BSE_EXPORT_NODE_PROC,
-    "BseSource+is-joint-ichannel", "/Methods/BseSource/General/Is Joint Ichannel", NULL },
+    "BseSource+is-joint-ichannel", 
+    NULL,
+    "/Methods/BseSource/General/Is Joint Ichannel",
+    "Check if an input channel is a joint (multi-connect) channel.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, is_joint_ichannel_setup, is_joint_ichannel_exec, 
 };
 static BseExportNodeProc __enode_ichannel_get_n_joints = {
   { (BseExportNode*) &__enode_is_joint_ichannel, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-get-n-joints", "/Methods/BseSource/General/Ichannel Get N Joints", NULL },
+    "BseSource+ichannel-get-n-joints", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Get N Joints",
+    "Retrieve the number of inputs connected to an input channel.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_get_n_joints_setup, ichannel_get_n_joints_exec, 
 };
 static BseExportNodeProc __enode_ichannel_get_osource = {
   { (BseExportNode*) &__enode_ichannel_get_n_joints, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-get-osource", "/Methods/BseSource/General/Ichannel Get Osource", NULL },
+    "BseSource+ichannel-get-osource", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Get Osource",
+    "Retrieve output module connected to a specific joint of an input channel",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_get_osource_setup, ichannel_get_osource_exec, 
 };
 static BseExportNodeProc __enode_ichannel_get_ochannel = {
   { (BseExportNode*) &__enode_ichannel_get_osource, BSE_EXPORT_NODE_PROC,
-    "BseSource+ichannel-get-ochannel", "/Methods/BseSource/General/Ichannel Get Ochannel", NULL },
+    "BseSource+ichannel-get-ochannel", 
+    NULL,
+    "/Methods/BseSource/General/Ichannel Get Ochannel",
+    "Retrieve output channel of the module connected to a specific joint of an input channel.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ichannel_get_ochannel_setup, ichannel_get_ochannel_exec, 
 };
 static BseExportNodeProc __enode_n_ochannels = {
   { (BseExportNode*) &__enode_ichannel_get_ochannel, BSE_EXPORT_NODE_PROC,
-    "BseSource+n-ochannels", "/Methods/BseSource/General/N Ochannels", NULL },
+    "BseSource+n-ochannels", 
+    NULL,
+    "/Methods/BseSource/General/N Ochannels",
+    "Get the number of output channels of a module.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, n_ochannels_setup, n_ochannels_exec, 
 };
 static BseExportNodeProc __enode_ochannel_name = {
   { (BseExportNode*) &__enode_n_ochannels, BSE_EXPORT_NODE_PROC,
-    "BseSource+ochannel-name", "/Methods/BseSource/General/Ochannel Name", NULL },
+    "BseSource+ochannel-name", 
+    NULL,
+    "/Methods/BseSource/General/Ochannel Name",
+    "Get output channel name.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ochannel_name_setup, ochannel_name_exec, 
 };
 static BseExportNodeProc __enode_ochannel_ident = {
   { (BseExportNode*) &__enode_ochannel_name, BSE_EXPORT_NODE_PROC,
-    "BseSource+ochannel-ident", "/Methods/BseSource/General/Ochannel Ident", NULL },
+    "BseSource+ochannel-ident", 
+    NULL,
+    "/Methods/BseSource/General/Ochannel Ident",
+    "Get canonical output channel name.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ochannel_ident_setup, ochannel_ident_exec, 
 };
 static BseExportNodeProc __enode_ochannel_blurb = {
   { (BseExportNode*) &__enode_ochannel_ident, BSE_EXPORT_NODE_PROC,
-    "BseSource+ochannel-blurb", "/Methods/BseSource/General/Ochannel Blurb", NULL },
+    "BseSource+ochannel-blurb", 
+    NULL,
+    "/Methods/BseSource/General/Ochannel Blurb",
+    "Get output channel description.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, ochannel_blurb_setup, ochannel_blurb_exec, 
 };
 static BseExportNodeProc __enode_set_pos = {
   { (BseExportNode*) &__enode_ochannel_blurb, BSE_EXPORT_NODE_PROC,
-    "BseSource+set-pos", "/Methods/BseSource/General/Set Pos", NULL },
+    "BseSource+set-pos", 
+    NULL,
+    "/Methods/BseSource/General/Set Pos",
+    "Set the x and y position of a module. In contrast to setting the position "
+          "through ordinary object property setters, this function will not update "
+          "the module position if the passed in arguments are sufficiently equal to "
+          "the values already set on the object. As such, it does not record an extra "
+          "undo step for setting properties to values they already have and if necessary "
+          "turns setting of x and y positions into an atomic undo operation.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU Lesser General Public License",
+  },
   0, set_pos_setup, set_pos_exec, 
 };
 BseExportNode* bse__builtin_init_bsesource_gen_proc_c (void);
