@@ -20,21 +20,15 @@ load_wave_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **o
  {
 #line 30 "bsewave.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", "Wave object to store loaded contents",
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("file_name", "File Name", "The wave file to read wave chunks from",
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_string ("wave_name", "Wave Name", "The name of the wave to read wave chunks from",
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", "BSE error type",
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 29 "bsewave.proc"
-  proc->help = "Load sample chunks from a wave file";
-#line 24 "bsewave.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsewave.proc"
-  proc->license = "GNU General Public License";
 #line 40 "bsewave.proc"
  }
 static BseErrorType
@@ -56,7 +50,7 @@ load_wave_exec (BseProcedureClass *proc,
   if (!BSE_IS_WAVE (wave) || !file_name || !wave_name)
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-  error = bse_wave_load_wave_file (wave, file_name, wave_name, NULL, NULL);
+  error = bse_wave_load_wave_file (wave, file_name, wave_name, NULL, NULL, TRUE);
   
 #line 56 "bsewave.proc"
   
@@ -72,16 +66,10 @@ n_wave_chunks_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 64 "bsewave.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_int ("n_chunks", "Number of Wave Chunks", NULL,
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
 }
-#line 63 "bsewave.proc"
-  proc->help = "Get the number of wave chunks of a wave";
-#line 24 "bsewave.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsewave.proc"
-  proc->license = "GNU General Public License";
 #line 69 "bsewave.proc"
  }
 static BseErrorType
@@ -114,18 +102,12 @@ use_editable_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec
  {
 #line 88 "bsewave.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("chunk_index", NULL, "Index of chunk to edit",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_object ("esample", NULL, "Editable sample",
-				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_EDITABLE_SAMPLE, SFI_PARAM_STANDARD);
 }
-#line 87 "bsewave.proc"
-  proc->help = "Retrieve an editable sample object for a wave chunk.";
-#line 24 "bsewave.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsewave.proc"
-  proc->license = "GNU General Public License";
 #line 95 "bsewave.proc"
  }
 static BseErrorType
@@ -170,19 +152,13 @@ chunk_get_osc_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
  {
 #line 126 "bsewave.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("chunk_index", "Chunk Index", "Index of chunk",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_real ("osc_freq", NULL, NULL,
 			  BSE_KAMMER_FREQUENCY_f, BSE_MIN_OSC_FREQUENCY_f, BSE_MAX_OSC_FREQUENCY_f, 10.0,
-			  SFI_PARAM_DEFAULT);
+			  SFI_PARAM_STANDARD);
 }
-#line 125 "bsewave.proc"
-  proc->help = "Retrieve oscillating frequency of a wave chunk.";
-#line 24 "bsewave.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsewave.proc"
-  proc->license = "GNU General Public License";
 #line 134 "bsewave.proc"
  }
 static BseErrorType
@@ -217,20 +193,14 @@ chunk_get_mix_freq_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GPara
  {
 #line 156 "bsewave.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
   *(in_pspecs++)    = sfi_pspec_int ("chunk_index", "Chunk Index", "Index of chunk",
-			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
+			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = sfi_pspec_real ("mix_freq", NULL, NULL,
 #line 161 "bsewave.proc"
 			  0, 0, 44100 * 16 , 10.0,
-			  SFI_PARAM_DEFAULT);
+			  SFI_PARAM_STANDARD);
 }
-#line 155 "bsewave.proc"
-  proc->help = "Retrieve mixing frequency of a wave chunk.";
-#line 24 "bsewave.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 25 "bsewave.proc"
-  proc->license = "GNU General Public License";
 #line 164 "bsewave.proc"
  }
 static BseErrorType
@@ -261,27 +231,57 @@ chunk_get_mix_freq_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_load_wave = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseWave+load-wave", "/Methods/BseWave/General/Load Wave", NULL },
+    "BseWave+load-wave", 
+    NULL,
+    "/Methods/BseWave/General/Load Wave",
+    "Load sample chunks from a wave file",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, load_wave_setup, load_wave_exec, 
 };
 static BseExportNodeProc __enode_n_wave_chunks = {
   { (BseExportNode*) &__enode_load_wave, BSE_EXPORT_NODE_PROC,
-    "BseWave+n-wave-chunks", "/Methods/BseWave/General/N Wave Chunks", NULL },
+    "BseWave+n-wave-chunks", 
+    NULL,
+    "/Methods/BseWave/General/N Wave Chunks",
+    "Get the number of wave chunks of a wave",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, n_wave_chunks_setup, n_wave_chunks_exec, 
 };
 static BseExportNodeProc __enode_use_editable = {
   { (BseExportNode*) &__enode_n_wave_chunks, BSE_EXPORT_NODE_PROC,
-    "BseWave+use-editable", "/Methods/BseWave/General/Use Editable", NULL },
+    "BseWave+use-editable", 
+    NULL,
+    "/Methods/BseWave/General/Use Editable",
+    "Retrieve an editable sample object for a wave chunk.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, use_editable_setup, use_editable_exec, 
 };
 static BseExportNodeProc __enode_chunk_get_osc_freq = {
   { (BseExportNode*) &__enode_use_editable, BSE_EXPORT_NODE_PROC,
-    "BseWave+chunk-get-osc-freq", "/Methods/BseWave/General/Chunk Get Osc Freq", NULL },
+    "BseWave+chunk-get-osc-freq", 
+    NULL,
+    "/Methods/BseWave/General/Chunk Get Osc Freq",
+    "Retrieve oscillating frequency of a wave chunk.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, chunk_get_osc_freq_setup, chunk_get_osc_freq_exec, 
 };
 static BseExportNodeProc __enode_chunk_get_mix_freq = {
   { (BseExportNode*) &__enode_chunk_get_osc_freq, BSE_EXPORT_NODE_PROC,
-    "BseWave+chunk-get-mix-freq", "/Methods/BseWave/General/Chunk Get Mix Freq", NULL },
+    "BseWave+chunk-get-mix-freq", 
+    NULL,
+    "/Methods/BseWave/General/Chunk Get Mix Freq",
+    "Retrieve mixing frequency of a wave chunk.",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, chunk_get_mix_freq_setup, chunk_get_mix_freq_exec, 
 };
 BseExportNode* bse__builtin_init_bsewave_gen_proc_c (void);
