@@ -1,5 +1,5 @@
 /* BSE - Bedevilled Sound Engine
- * Copyright (C) 2001, 2002 Tim Janik
+ * Copyright (C) 2001-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 #include "bsewaveosc.h"
-
 #include <bse/bsemain.h>
 #include <bse/bsecategories.h>
 #include <bse/bseeditablesample.h>
@@ -35,32 +34,31 @@ enum
   PARAM_WAVE,
   PARAM_FM_PERC,
   PARAM_FM_EXP,
-  PARAM_FM_OCTAVES,
-  PARAM_EDITABLE_SAMPLE
+  PARAM_FM_OCTAVES
 };
 
 
 /* --- prototypes --- */
-static void	bse_wave_osc_init		(BseWaveOsc		*self);
-static void	bse_wave_osc_class_init		(BseWaveOscClass	*class);
-static void	bse_wave_osc_dispose		(GObject		*object);
-static void	bse_wave_osc_finalize		(GObject		*object);
-static void	bse_wave_osc_set_property	(GObject		*object,
-						 guint			 param_id,
-						 const GValue		*value,
-						 GParamSpec		*pspec);
-static void	bse_wave_osc_get_property	(GObject		*object,
-						 guint			 param_id,
-						 GValue			*value,
-						 GParamSpec		*pspec);
-static BseProxySeq* bse_wave_osc_list_proxies   (BseItem		*item,
-						 guint			 param_id,
-						 GParamSpec		*pspec);
-static void	bse_wave_osc_context_create	(BseSource		*source,
-						 guint			 context_handle,
-						 GslTrans		*trans);
-static void   bse_wave_osc_update_config_wchunk (BseWaveOsc		*self);
-static void	bse_wave_osc_update_modules	(BseWaveOsc		*self);
+static void     bse_wave_osc_init               (BseWaveOsc             *self);
+static void     bse_wave_osc_class_init         (BseWaveOscClass        *class);
+static void     bse_wave_osc_dispose            (GObject                *object);
+static void     bse_wave_osc_finalize           (GObject                *object);
+static void     bse_wave_osc_set_property       (GObject                *object,
+                                                 guint                   param_id,
+                                                 const GValue           *value,
+                                                 GParamSpec             *pspec);
+static void     bse_wave_osc_get_property       (GObject                *object,
+                                                 guint                   param_id,
+                                                 GValue                 *value,
+                                                 GParamSpec             *pspec);
+static BseProxySeq* bse_wave_osc_list_proxies   (BseItem                *item,
+                                                 guint                   param_id,
+                                                 GParamSpec             *pspec);
+static void     bse_wave_osc_context_create     (BseSource              *source,
+                                                 guint                   context_handle,
+                                                 GslTrans               *trans);
+static void   bse_wave_osc_update_config_wchunk (BseWaveOsc             *self);
+static void     bse_wave_osc_update_modules     (BseWaveOsc             *self);
 
 
 /* --- variables --- */
@@ -93,16 +91,16 @@ BSE_BUILTIN_TYPE (BseWaveOsc)
   GType type;
   
   type = bse_type_register_static (BSE_TYPE_SOURCE,
-				   "BseWaveOsc",
-				   "BseWaveOsc is a wave based oscillator module. "
-				   "It plays waves at arbitrary frequency with little to no "
-				   "aliasing artefacts by using a tschbyscheff type II resampling filter. "
-				   "The plaback frequency can be specified through a frequency input, and be "
-				   "modulated by another control signal with linear or exponential frequency "
-				   "response.",
-				   &type_info);
+                                   "BseWaveOsc",
+                                   "BseWaveOsc is a wave based oscillator module. "
+                                   "It plays waves at arbitrary frequency with little to no "
+                                   "aliasing artefacts by using a tschbyscheff type II resampling filter. "
+                                   "The plaback frequency can be specified through a frequency input, and be "
+                                   "modulated by another control signal with linear or exponential frequency "
+                                   "response.",
+                                   &type_info);
   bse_categories_register_icon ("/Modules/Audio Sources/Wave Oscillator",
-				type, &pixdata);
+                                type, &pixdata);
   return type;
 }
 
@@ -127,38 +125,32 @@ bse_wave_osc_class_init (BseWaveOscClass *class)
   source_class->context_create = bse_wave_osc_context_create;
   
   bse_object_class_add_param (object_class, "Wave",
-			      PARAM_WAVE,
-			      bse_param_spec_object ("wave", "Wave", "Wave to play",
-						     BSE_TYPE_WAVE, SFI_PARAM_DEFAULT));
+                              PARAM_WAVE,
+                              bse_param_spec_object ("wave", "Wave", "Wave to play",
+                                                     BSE_TYPE_WAVE, SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "Modulation",
-			      PARAM_FM_PERC,
-			      sfi_pspec_real ("fm_perc", "Input Modulation [%]",
-					      "Modulation Strength for linear frequency modulation",
-					      10.0, 0, 100.0,5.0,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_SCALE));
+                              PARAM_FM_PERC,
+                              sfi_pspec_real ("fm_perc", "Input Modulation [%]",
+                                              "Modulation Strength for linear frequency modulation",
+                                              10.0, 0, 100.0,5.0,
+                                              SFI_PARAM_STANDARD ":scale"));
   bse_object_class_add_param (object_class, "Modulation",
-			      PARAM_FM_EXP,
-			      sfi_pspec_bool ("exponential_fm", "Exponential FM",
-					      "Perform exponential frequency modulation"
-					      "instead of linear",
-					      FALSE, SFI_PARAM_DEFAULT));
+                              PARAM_FM_EXP,
+                              sfi_pspec_bool ("exponential_fm", "Exponential FM",
+                                              "Perform exponential frequency modulation"
+                                              "instead of linear",
+                                              FALSE, SFI_PARAM_STANDARD));
   bse_object_class_add_param (object_class, "Modulation",
-			      PARAM_FM_OCTAVES,
-			      sfi_pspec_real ("fm_n_octaves", "Octaves",
-					      "Number of octaves to be affected by exponential frequency modulation",
-					      1.0, 0, 3.0, 0.01,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_SCALE));
-  
-  bse_object_class_add_param (object_class, NULL,
-			      PARAM_EDITABLE_SAMPLE,
-			      bse_param_spec_object ("editable_sample", NULL, NULL,
-						     BSE_TYPE_EDITABLE_SAMPLE,
-						     SFI_PARAM_READABLE));
+                              PARAM_FM_OCTAVES,
+                              sfi_pspec_real ("fm_n_octaves", "Octaves",
+                                              "Number of octaves to be affected by exponential frequency modulation",
+                                              1.0, 0, 3.0, 0.01,
+                                              SFI_PARAM_STANDARD ":scale"));
   
   signal_notify_pcm_position = bse_object_class_add_signal (object_class, "notify_pcm_position",
-							    G_TYPE_NONE, 2,
-							    SFI_TYPE_NUM,
-							    G_TYPE_INT);
+                                                            G_TYPE_NONE, 2,
+                                                            SFI_TYPE_NUM,
+                                                            G_TYPE_INT);
   
   ichannel = bse_source_class_add_ichannel (source_class, "Freq In", "Frequency Input");
   g_assert (ichannel == BSE_WAVE_OSC_ICHANNEL_FREQ);
@@ -176,9 +168,9 @@ static void
 bse_wave_osc_init (BseWaveOsc *self)
 {
   self->wave = NULL;
+  self->esample_wchunk = NULL;
   self->fm_strength = 10.0;
   self->n_octaves = 1;
-  self->esample_wchunk = NULL;
   self->config.start_offset = 0;
   self->config.play_dir = +1;
   self->config.wchunk_data = NULL;
@@ -188,46 +180,10 @@ bse_wave_osc_init (BseWaveOsc *self)
   self->config.cfreq = 440.;
 }
 
-static void
-bse_wave_osc_dispose (GObject *object)
-{
-  BseWaveOsc *self = BSE_WAVE_OSC (object);
-  
-  g_assert (self->wave == NULL);	/* paranoid */
-  
-  /* chain parent class' handler */
-  G_OBJECT_CLASS (parent_class)->dispose (object);
-}
-
-static void
-bse_wave_osc_finalize (GObject *object)
-{
-  BseWaveOsc *self = BSE_WAVE_OSC (object);
-  
-  if (self->esample_wchunk)
-    gsl_wave_chunk_close (self->esample_wchunk);
-  self->esample_wchunk = NULL;
-  
-  /* chain parent class' handler */
-  G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-static gboolean
-check_wrepo (BseItem *item)
-{
-  return BSE_IS_WAVE_REPO (item);
-}
-
-static gboolean
-check_wave (BseItem *item)
-{
-  return BSE_IS_WAVE (item);
-}
-
 static BseProxySeq*
 bse_wave_osc_list_proxies (BseItem    *item,
-			   guint       param_id,
-			   GParamSpec *pspec)
+                           guint       param_id,
+                           GParamSpec *pspec)
 {
   BseWaveOsc *self = BSE_WAVE_OSC (item);
   BseProxySeq *pseq = bse_proxy_seq_new ();
@@ -237,14 +193,11 @@ bse_wave_osc_list_proxies (BseItem    *item,
     case PARAM_WAVE:
       project = bse_item_get_project (item);
       if (project)
-	{
-	  BseWaveRepo *wrepo = bse_project_get_wave_repo (project);
-	  
-	  bse_item_gather_proxies (BSE_ITEM (wrepo), pseq, BSE_TYPE_WAVE,
-				   (BseItemCheckContainer) check_wrepo,
-				   (BseItemCheckProxy) check_wave,
-				   NULL);
-	}
+        {
+          BseWaveRepo *wrepo = bse_project_get_wave_repo (project);
+          
+          bse_item_gather_proxies_typed (BSE_ITEM (wrepo), pseq, BSE_TYPE_WAVE, BSE_TYPE_WAVE_REPO, FALSE);
+        }
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -254,123 +207,132 @@ bse_wave_osc_list_proxies (BseItem    *item,
 }
 
 static void
-notify_wave_changed (BseWaveOsc *self)
+wave_osc_uncross_wave (BseItem *owner,
+                       BseItem *ref_item)
 {
-  g_object_notify (G_OBJECT (self), "wave");
+  BseWaveOsc *self = BSE_WAVE_OSC (owner);
+  bse_item_set (self, "wave", NULL, NULL);
 }
 
 static void
-wave_uncross (BseItem *owner,
-	      BseItem *ref_item)
+clear_wave_and_esample (BseWaveOsc *self)
 {
-  BseWaveOsc *self = BSE_WAVE_OSC (owner);
-  BseWave *wave = self->wave;
-  
-  g_object_disconnect (wave, "any_signal", notify_wave_changed, self, NULL);
-  self->wave = NULL;
-  bse_wave_osc_update_config_wchunk (self);
-  bse_wave_osc_update_modules (self);
-  if (BSE_SOURCE_PREPARED (self))
+  if (self->wave)
     {
-      /* need to make sure our modules know about BseWave vanishing
-       * before we return (the wave will destroy the wchunk index next)
-       */
-      gsl_engine_wait_on_trans ();
+      BseWave *wave = self->wave;
+      bse_item_cross_unlink (BSE_ITEM (self), BSE_ITEM (self->wave), wave_osc_uncross_wave);
+      bse_object_unproxy_notifies (self->wave, self, "notify::wave");
+      self->wave = NULL;
+      bse_wave_osc_update_config_wchunk (self);
+      bse_wave_osc_update_modules (self);
+      if (BSE_SOURCE_PREPARED (self))
+        {
+          /* need to make sure our modules know about BseWave vanishing
+           * before we continue (since bse_wave_drop_index() will destroy
+           * the wchunk index)
+           */
+          gsl_engine_wait_on_trans ();
+        }
+      bse_wave_drop_index (wave);
+      g_object_notify (self, "wave");
+    }
+
+  if (self->esample_wchunk)
+    {
+      GslWaveChunk *esample_wchunk = self->esample_wchunk;
+      self->esample_wchunk = NULL;
+      bse_wave_osc_update_config_wchunk (self);
+      bse_wave_osc_update_modules (self);
+      if (BSE_SOURCE_PREPARED (self))
+        {
+          /* need to make sure our modules know about the wave chunk vanishing
+           * before we return (so the wchunk update propagates)
+           */
+          gsl_engine_wait_on_trans ();
+        }
+      gsl_wave_chunk_close (esample_wchunk);
+    }
+}
+
+void
+bse_wave_osc_set_from_esample (BseWaveOsc        *self,
+                               BseEditableSample *esample)
+{
+  g_return_if_fail (BSE_WAVE_OSC (self));
+
+  clear_wave_and_esample (self);
+  if (esample)
+    {
+      g_return_if_fail (BSE_EDITABLE_SAMPLE (esample));
+
+      if (esample->wchunk && gsl_wave_chunk_open (esample->wchunk) == GSL_ERROR_NONE)
+        {
+          self->esample_wchunk = esample->wchunk;
+          bse_wave_osc_update_config_wchunk (self);
+          bse_wave_osc_update_modules (self);
+          if (BSE_SOURCE_PREPARED (self))
+            gsl_engine_wait_on_trans ();
+        }
     }
-  bse_wave_drop_index (wave);
-  g_object_notify (G_OBJECT (self), "wave");
 }
 
 static void
 bse_wave_osc_set_property (GObject      *object,
-			   guint         param_id,
-			   const GValue *value,
-			   GParamSpec   *pspec)
+                           guint         param_id,
+                           const GValue *value,
+                           GParamSpec   *pspec)
 {
   BseWaveOsc *self = BSE_WAVE_OSC (object);
   
   switch (param_id)
     {
-      BseEditableSample *esample;
       BseWave *wave;
     case PARAM_WAVE:
       wave = bse_value_get_object (value);
       if (wave != self->wave)
-	{
-	  if (self->wave)
-	    {
-	      bse_item_uncross (BSE_ITEM (self), BSE_ITEM (self->wave)); // FIXME: use uncross_ref
-	      g_assert (self->wave == NULL);	/* paranoid */
-	    }
-	  if (self->esample_wchunk)
-	    g_object_set (self, "editable_sample", NULL, NULL);
-	  g_assert (self->esample_wchunk == NULL);	/* paranoid */
-	  self->wave = wave;
-	  if (self->wave)
-	    {
-	      bse_item_cross_link (BSE_ITEM (self), BSE_ITEM (self->wave), wave_uncross);
-	      g_object_connect (self->wave, "swapped_signal::notify::name", notify_wave_changed, self, NULL);
-	      bse_wave_request_index (self->wave);
-	      bse_wave_osc_update_config_wchunk (self);
-	      bse_wave_osc_update_modules (self);
-	      if (BSE_SOURCE_PREPARED (self))
-		{
-		  /* need to make sure our modules know about BseWave vanishing
-		   * before we return (so the wchunk update propagates)
-		   */
-		  gsl_engine_wait_on_trans ();
-		}
-	    }
-	}
-      break;
-    case PARAM_EDITABLE_SAMPLE:
-      if (self->esample_wchunk)
-	{
-	  GslWaveChunk *esample_wchunk = self->esample_wchunk;
-	  self->esample_wchunk = NULL;
-	  bse_wave_osc_update_config_wchunk (self);
-	  bse_wave_osc_update_modules (self);
-	  if (BSE_SOURCE_PREPARED (self))
-	    gsl_engine_wait_on_trans ();
-	  gsl_wave_chunk_close (esample_wchunk);
-	}
-      if (self->wave)
-	g_object_set (self, "wave", NULL, NULL);
-      g_assert (self->wave == NULL);	/* paranoid */
-      esample = bse_value_get_object (value);
-      if (esample && esample->wchunk)
-	{
-	  if (gsl_wave_chunk_open (esample->wchunk) == GSL_ERROR_NONE)
-	    self->esample_wchunk = esample->wchunk;
-	  bse_wave_osc_update_config_wchunk (self);
-	  bse_wave_osc_update_modules (self);
-	  if (BSE_SOURCE_PREPARED (self))
-	    gsl_engine_wait_on_trans ();
-	}
+        {
+          clear_wave_and_esample (self);
+          self->wave = wave;
+          if (self->wave)
+            {
+              bse_item_cross_link (BSE_ITEM (self), BSE_ITEM (self->wave), wave_osc_uncross_wave);
+              bse_object_proxy_notifies (self->wave, self, "notify::wave");
+              bse_wave_request_index (self->wave);
+              bse_wave_osc_update_config_wchunk (self);
+              bse_wave_osc_update_modules (self);
+              if (BSE_SOURCE_PREPARED (self))
+                {
+                  /* need to make sure our modules know about BseWave vanishing
+                   * before we return (so the wchunk update propagates)
+                   */
+                  gsl_engine_wait_on_trans ();
+                }
+            }
+        }
       break;
     case PARAM_FM_PERC:
       self->fm_strength = sfi_value_get_real (value);
       if (!self->config.exponential_fm)
-	{
-	  self->config.fm_strength = self->fm_strength / 100.0;
-	  bse_wave_osc_update_modules (self);
-	}
+        {
+          self->config.fm_strength = self->fm_strength / 100.0;
+          bse_wave_osc_update_modules (self);
+        }
       break;
     case PARAM_FM_EXP:
       self->config.exponential_fm = sfi_value_get_bool (value);
       if (self->config.exponential_fm)
-	self->config.fm_strength = self->n_octaves;
+        self->config.fm_strength = self->n_octaves;
       else
-	self->config.fm_strength = self->fm_strength / 100.0;
+        self->config.fm_strength = self->fm_strength / 100.0;
       bse_wave_osc_update_modules (self);
       break;
     case PARAM_FM_OCTAVES:
       self->n_octaves = sfi_value_get_real (value);
       if (self->config.exponential_fm)
-	{
-	  self->config.fm_strength = self->n_octaves;
-	  bse_wave_osc_update_modules (self);
-	}
+        {
+          self->config.fm_strength = self->n_octaves;
+          bse_wave_osc_update_modules (self);
+        }
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (self, param_id, pspec);
@@ -380,9 +342,9 @@ bse_wave_osc_set_property (GObject      *object,
 
 static void
 bse_wave_osc_get_property (GObject    *object,
-			   guint       param_id,
-			   GValue     *value,
-			   GParamSpec *pspec)
+                           guint       param_id,
+                           GValue     *value,
+                           GParamSpec *pspec)
 {
   BseWaveOsc *self = BSE_WAVE_OSC (object);
   
@@ -406,9 +368,33 @@ bse_wave_osc_get_property (GObject    *object,
     }
 }
 
+static void
+bse_wave_osc_dispose (GObject *object)
+{
+  BseWaveOsc *self = BSE_WAVE_OSC (object);
+
+  clear_wave_and_esample (self);
+  
+  /* chain parent class' handler */
+  G_OBJECT_CLASS (parent_class)->dispose (object);
+}
+
+static void
+bse_wave_osc_finalize (GObject *object)
+{
+  BseWaveOsc *self = BSE_WAVE_OSC (object);
+  
+  if (self->esample_wchunk)
+    gsl_wave_chunk_close (self->esample_wchunk);
+  self->esample_wchunk = NULL;
+  
+  /* chain parent class' handler */
+  G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
 static void
 wosc_access (GslModule *module,
-	     gpointer   data)
+             gpointer   data)
 {
   GslWaveOscData *wosc = module->user_data;
   GslWaveOscConfig *config = data;
@@ -420,7 +406,7 @@ wosc_access (GslModule *module,
 
 static GslWaveChunk*
 wchunk_from_data (gpointer wchunk_data,
-		  gfloat   freq)
+                  gfloat   freq)
 {
   return wchunk_data;
 }
@@ -435,7 +421,7 @@ bse_wave_osc_update_config_wchunk (BseWaveOsc *self)
       BseWaveIndex *index = bse_wave_get_index_for_modules (self->wave);
       self->config.wchunk_data = index && index->n_wchunks ? index : NULL;
       if (self->config.wchunk_data)
-	self->config.wchunk_from_freq = (gpointer) bse_wave_index_lookup_best;
+        self->config.wchunk_from_freq = (gpointer) bse_wave_index_lookup_best;
     }
   else if (self->esample_wchunk)
     {
@@ -449,15 +435,15 @@ bse_wave_osc_update_modules (BseWaveOsc *self)
 {
   if (BSE_SOURCE_PREPARED (self))
     bse_source_access_modules (BSE_SOURCE (self),
-			       wosc_access,
-			       g_memdup (&self->config, sizeof (self->config)),
-			       g_free,
-			       NULL);
+                               wosc_access,
+                               g_memdup (&self->config, sizeof (self->config)),
+                               g_free,
+                               NULL);
 }
 
 static void
 wosc_free (gpointer        data,
-	   const GslClass *klass)
+           const GslClass *klass)
 {
   GslWaveOscData *wosc = data;
   
@@ -467,20 +453,20 @@ wosc_free (gpointer        data,
 
 static void
 wosc_process (GslModule *module,
-	      guint      n_values)
+              guint      n_values)
 {
   GslWaveOscData *wosc = module->user_data;
   gfloat gate;
   
   gsl_wave_osc_process (wosc,
-			n_values,
-			(GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_FREQ).connected ?
-			 GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_FREQ) : NULL),
-			(GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_MOD).connected ?
-			 GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_MOD) : NULL),
-			(GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_SYNC).connected ?
-			 GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_SYNC) : NULL),
-			GSL_MODULE_OBUFFER (module, BSE_WAVE_OSC_OCHANNEL_WAVE));
+                        n_values,
+                        (GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_FREQ).connected ?
+                         GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_FREQ) : NULL),
+                        (GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_MOD).connected ?
+                         GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_MOD) : NULL),
+                        (GSL_MODULE_ISTREAM (module, BSE_WAVE_OSC_ICHANNEL_SYNC).connected ?
+                         GSL_MODULE_IBUFFER (module, BSE_WAVE_OSC_ICHANNEL_SYNC) : NULL),
+                        GSL_MODULE_OBUFFER (module, BSE_WAVE_OSC_OCHANNEL_WAVE));
   
   gate = wosc->done ? 0.0 : 1.0;
   module->ostreams[BSE_WAVE_OSC_OCHANNEL_GATE].values = gsl_engine_const_values (gate);
@@ -495,18 +481,18 @@ wosc_reset (GslModule *module)
 
 static void
 bse_wave_osc_context_create (BseSource *source,
-			     guint      context_handle,
-			     GslTrans  *trans)
+                             guint      context_handle,
+                             GslTrans  *trans)
 {
   static const GslClass wosc_class = {
-    BSE_WAVE_OSC_N_ICHANNELS,	/* n_istreams */
+    BSE_WAVE_OSC_N_ICHANNELS,   /* n_istreams */
     0,                          /* n_jstreams */
-    BSE_WAVE_OSC_N_OCHANNELS,	/* n_ostreams */
-    wosc_process,		/* process */
+    BSE_WAVE_OSC_N_OCHANNELS,   /* n_ostreams */
+    wosc_process,               /* process */
     NULL,                       /* process_defer */
-    wosc_reset,			/* reset */
-    wosc_free,			/* free */
-    GSL_COST_NORMAL,		/* cost */
+    wosc_reset,                 /* reset */
+    wosc_free,                  /* free */
+    GSL_COST_NORMAL,            /* cost */
   };
   BseWaveOsc *self = BSE_WAVE_OSC (source);
   GslWaveOscData *wosc = g_new0 (GslWaveOscData, 1);
@@ -532,12 +518,12 @@ typedef struct {
   BseWaveOsc *wosc;
   gfloat      perc;
   guint64     stamp;
-  guint	      module_pcm_position;
+  guint       module_pcm_position;
 } PcmPos;
 
 static void
 pcm_pos_access (GslModule *module,
-		gpointer   data)
+                gpointer   data)
 {
   GslWaveOscData *wosc = module->user_data;
   PcmPos *pos = data;
@@ -571,7 +557,7 @@ pcm_pos_access_free (gpointer data)
 
 void
 bse_wave_osc_request_pcm_position (BseWaveOsc *self,
-				   gfloat      perc)
+                                   gfloat      perc)
 {
   g_return_if_fail (BSE_IS_WAVE_OSC (self));
 
@@ -584,9 +570,9 @@ bse_wave_osc_request_pcm_position (BseWaveOsc *self,
       pos->perc = perc;
       pos->wosc = g_object_ref (self);
       bse_source_access_modules (BSE_SOURCE (self),
-				 pcm_pos_access,
-				 pos,
-				 pcm_pos_access_free,
-				 NULL);
+                                 pcm_pos_access,
+                                 pos,
+                                 pcm_pos_access_free,
+                                 NULL);
     }
 }
