@@ -49,13 +49,14 @@ load_file (BseWaveRepo *wrepo,
   wave = g_object_new (BSE_TYPE_WAVE,
 		       "uname", fname,
 		       NULL);
+  bse_wave_set_description_bits (wave, wdsc, TRUE);
   g_free (fname);
   for (i = 0; i < wdsc->n_chunks; i++)
     {
       GslWaveChunk *wchunk = gsl_wave_chunk_create (wdsc, i, error ? NULL : &error);
       
       if (wchunk)
-	bse_wave_add_chunk (wave, wchunk);
+        bse_wave_add_chunk (wave, wchunk);
     }
   bse_wave_set_locator (wave, file_name, wdsc->name);
   
@@ -75,41 +76,35 @@ load_file (BseWaveRepo *wrepo,
 }
 
 
-#line 88 "bsewaverepo.proc"
+#line 89 "bsewaverepo.proc"
 
-#line 91 "bsewaverepo.proc"
+#line 92 "bsewaverepo.proc"
 
 
 /* --- load-file --- */
 static void
 load_file_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 93 "bsewaverepo.proc"
+#line 94 "bsewaverepo.proc"
  {
-#line 95 "bsewaverepo.proc"
+#line 96 "bsewaverepo.proc"
   *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
-				 BSE_TYPE_WAVE_REPO, SFI_PARAM_DEFAULT);
+				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
   *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to import waves from",
-			    NULL, SFI_PARAM_DEFAULT);
+			    NULL, SFI_PARAM_STANDARD);
   *(out_pspecs++)   = bse_param_spec_genum ("error", "Error", NULL,
 				BSE_TYPE_ERROR_TYPE, BSE_ERROR_NONE,
-				SFI_PARAM_DEFAULT);
+				SFI_PARAM_STANDARD);
 }
-#line 94 "bsewaverepo.proc"
-  proc->help = "Load wave from file";
-#line 89 "bsewaverepo.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 90 "bsewaverepo.proc"
-  proc->license = "GNU General Public License";
-#line 103 "bsewaverepo.proc"
+#line 104 "bsewaverepo.proc"
  }
 static BseErrorType
-#line 103 "bsewaverepo.proc"
+#line 104 "bsewaverepo.proc"
 load_file_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 106 "bsewaverepo.proc"
-{
 #line 107 "bsewaverepo.proc"
+{
+#line 108 "bsewaverepo.proc"
   
   BseWaveRepo *self    = (BseWaveRepo*) bse_value_get_object (in_values++);
   gchar *file_name     = sfi_value_get_string (in_values++);
@@ -117,7 +112,7 @@ load_file_exec (BseProcedureClass *proc,
   BseErrorType error;
   BseWave *wave;
   
-#line 114 "bsewaverepo.proc"
+#line 115 "bsewaverepo.proc"
   
   if (!BSE_IS_WAVE_REPO (self) || !file_name)
     return BSE_ERROR_PROC_PARAM_INVAL;
@@ -128,7 +123,7 @@ load_file_exec (BseProcedureClass *proc,
     bse_item_push_undo_proc (self, "remove-wave", wave);
   bse_item_undo_close (ustack);
   
-#line 124 "bsewaverepo.proc"
+#line 125 "bsewaverepo.proc"
   
   g_value_set_enum (out_values++, error);
   
@@ -138,53 +133,47 @@ load_file_exec (BseProcedureClass *proc,
 /* --- remove-wave --- */
 static void
 remove_wave_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 130 "bsewaverepo.proc"
- {
-#line 132 "bsewaverepo.proc"
-  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
-				 BSE_TYPE_WAVE_REPO, SFI_PARAM_DEFAULT);
-  *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
-				 BSE_TYPE_WAVE, SFI_PARAM_DEFAULT);
 #line 131 "bsewaverepo.proc"
-  proc->help = "Remove a wave from repository";
-#line 89 "bsewaverepo.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 90 "bsewaverepo.proc"
-  proc->license = "GNU General Public License";
-#line 136 "bsewaverepo.proc"
+ {
+#line 133 "bsewaverepo.proc"
+  *(in_pspecs++)    = bse_param_spec_object ("wave_repo", "Wave Repo", NULL,
+				 BSE_TYPE_WAVE_REPO, SFI_PARAM_STANDARD);
+  *(in_pspecs++)    = bse_param_spec_object ("wave", "Wave", NULL,
+				 BSE_TYPE_WAVE, SFI_PARAM_STANDARD);
+#line 137 "bsewaverepo.proc"
 }  }
 static BseErrorType
-#line 136 "bsewaverepo.proc"
+#line 137 "bsewaverepo.proc"
 remove_wave_exec (BseProcedureClass *proc,
 	const GValue      *in_values,
 	GValue            *out_values)
-#line 139 "bsewaverepo.proc"
-{
 #line 140 "bsewaverepo.proc"
+{
+#line 141 "bsewaverepo.proc"
   
   BseWaveRepo *self = (BseWaveRepo*) bse_value_get_object (in_values++);
   BseItem *child    = (BseItem*) bse_value_get_object (in_values++);
   BseUndoStack *ustack;
 
-#line 145 "bsewaverepo.proc"
+#line 146 "bsewaverepo.proc"
   
   if (!BSE_IS_WAVE_REPO (self) || !BSE_IS_WAVE (child) ||
       child->parent != BSE_ITEM (self))
     return BSE_ERROR_PROC_PARAM_INVAL;
   
-#line 150 "bsewaverepo.proc"
+#line 151 "bsewaverepo.proc"
   
   ustack = bse_item_undo_open (self, "remove-wave %s", bse_object_debug_name (child));
-#line 152 "bsewaverepo.proc"
+#line 153 "bsewaverepo.proc"
   
   bse_container_uncross_undoable (BSE_CONTAINER (self), child);
-#line 154 "bsewaverepo.proc"
+#line 155 "bsewaverepo.proc"
   
   bse_item_push_redo_proc (self, "remove-wave", child);
-#line 156 "bsewaverepo.proc"
+#line 157 "bsewaverepo.proc"
   
   bse_container_remove_backedup (BSE_CONTAINER (self), child, ustack);
-#line 158 "bsewaverepo.proc"
+#line 159 "bsewaverepo.proc"
   
   bse_item_undo_close (ustack);
   
@@ -194,41 +183,35 @@ remove_wave_exec (BseProcedureClass *proc,
 /* --- bse-sample-file-info --- */
 static void
 bse_sample_file_info_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
-#line 164 "bsewaverepo.proc"
- {
-#line 166 "bsewaverepo.proc"
-  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to load info from",
-			    NULL, SFI_PARAM_DEFAULT);
-  *(out_pspecs++)   = bse_param_spec_boxed ("sample_file_info", NULL, NULL, BSE_TYPE_SAMPLE_FILE_INFO, SFI_PARAM_DEFAULT);
-}
 #line 165 "bsewaverepo.proc"
-  proc->help = "Load sample file info from file";
-#line 89 "bsewaverepo.proc"
-  proc->authors = "Tim Janik <timj@gtk.org>";
-#line 90 "bsewaverepo.proc"
-  proc->license = "GNU General Public License";
-#line 170 "bsewaverepo.proc"
+ {
+#line 167 "bsewaverepo.proc"
+  *(in_pspecs++) = sfi_pspec_string ("file_name", "File Name", "The file to load info from",
+			    NULL, SFI_PARAM_STANDARD);
+  *(out_pspecs++)   = bse_param_spec_boxed ("sample_file_info", NULL, NULL, BSE_TYPE_SAMPLE_FILE_INFO, SFI_PARAM_STANDARD);
+}
+#line 171 "bsewaverepo.proc"
  }
 static BseErrorType
-#line 170 "bsewaverepo.proc"
+#line 171 "bsewaverepo.proc"
 bse_sample_file_info_exec (BseProcedureClass *proc,
       const GValue      *in_values,
       GValue            *out_values)
-#line 173 "bsewaverepo.proc"
-{
 #line 174 "bsewaverepo.proc"
+{
+#line 175 "bsewaverepo.proc"
   
   gchar *filename = sfi_value_get_string (in_values++);
   BseSampleFileInfo info = { 0, };
   GslWaveFileInfo *wfi = NULL;
   struct stat sbuf = { 0, };
 
-#line 180 "bsewaverepo.proc"
+#line 181 "bsewaverepo.proc"
   
   if (!filename)
     return BSE_ERROR_PROC_PARAM_INVAL;
 
-#line 184 "bsewaverepo.proc"
+#line 185 "bsewaverepo.proc"
   
   info.file = filename;
   info.waves = bse_string_seq_new ();
@@ -248,11 +231,11 @@ bse_sample_file_info_exec (BseProcedureClass *proc,
 	}
     }
 
-#line 203 "bsewaverepo.proc"
+#line 204 "bsewaverepo.proc"
   
   bse_value_set_boxed (out_values++, &info);
 
-#line 206 "bsewaverepo.proc"
+#line 207 "bsewaverepo.proc"
   
   bse_string_seq_free (info.waves);
   if (wfi)
@@ -264,17 +247,35 @@ bse_sample_file_info_exec (BseProcedureClass *proc,
 /* --- Export to BSE --- */
 static BseExportNodeProc __enode_load_file = {
   { NULL, BSE_EXPORT_NODE_PROC,
-    "BseWaveRepo+load-file", "/Methods/BseWaveRepo/General/Load File", NULL },
+    "BseWaveRepo+load-file", 
+    NULL,
+    "/Methods/BseWaveRepo/General/Load File",
+    "Load wave from file",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, load_file_setup, load_file_exec, 
 };
 static BseExportNodeProc __enode_remove_wave = {
   { (BseExportNode*) &__enode_load_file, BSE_EXPORT_NODE_PROC,
-    "BseWaveRepo+remove-wave", "/Methods/BseWaveRepo/General/Remove Wave", NULL },
+    "BseWaveRepo+remove-wave", 
+    NULL,
+    "/Methods/BseWaveRepo/General/Remove Wave",
+    "Remove a wave from repository",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, remove_wave_setup, remove_wave_exec, 
 };
 static BseExportNodeProc __enode_bse_sample_file_info = {
   { (BseExportNode*) &__enode_remove_wave, BSE_EXPORT_NODE_PROC,
-    "bse-sample-file-info", "/Proc/Sample File Info", NULL },
+    "bse-sample-file-info", 
+    NULL,
+    "/Proc/Sample File Info",
+    "Load sample file info from file",
+    "Tim Janik <timj@gtk.org>",
+    "GNU General Public License",
+  },
   0, bse_sample_file_info_setup, bse_sample_file_info_exec, 
 };
 BseExportNode* bse__builtin_init_bsewaverepo_gen_proc_c (void);
