@@ -91,8 +91,9 @@ gsl_module_new (const GslClass *klass,
     }
   node->flow_jobs = NULL;
   node->boundary_jobs = NULL;
-  node->tjob_first = NULL;
-  node->tjob_last = NULL;
+  node->reply_jobs = NULL;
+  node->rjob_first = NULL;
+  node->rjob_last = NULL;
   
   return &node->module;
 }
@@ -124,9 +125,10 @@ gsl_module_tick_stamp (GslModule *module)
  *
  * Check whether @istream may be disconnected via
  * gsl_job_disconnect(). This is not an indication for whether
- * @istream will be connected during process(), as the source
- * may be a dangling virtual module, resulting in an unconnected
- * input stream after the next scheduling phase.
+ * GSL_MODULE_ISTREAM (@module, @istream).connected will be %TRUE
+ * during process(), as the source may be a dangling virtual module,
+ * resulting in GSL_MODULE_ISTREAM (@module, @istream).connected
+ * being %FALSE.
  * See also gsl_module_new_virtual().
  * This function is MT-safe and may be called from any thread.
  */
@@ -394,8 +396,9 @@ gsl_job_set_consumer (GslModule *module,
  * @module: The module to be reset
  * @Returns: New job suitable for gsl_trans_add()
  *
- * Forces an immediate reset of @module if its class
- * provides a reset() implementation. This is usually
+ * Forces a reset of @module before its next call to
+ * process(), if its class provides a reset()
+ * implementation. This is usually
  * not a good idea, as forcing an immediate reset can
  * lead to multiple unnecessary reset() invocations.
  * The logic used to invoke reset() automatically is
@@ -461,6 +464,46 @@ gsl_job_access (GslModule    *module,
   return job;
 }
 
+/**
+ * gsl_job_request_reply
+ * @module:      The module to access
+ * @data:        Data passed in to the accessor
+ * @reply_func:  Function invoked with @data in the user thread upon reply
+ * @Returns:     New job suitable for gsl_trans_add()
+ *
+ * Create a new transaction job which inserts @reply_func
+ * with @data into the reply job queue of @module.
+ * Reply jobs are jobs with limited impact on modules, which
+ * processed by the module on demand. Once a module has processed
+ * a reply job, the job is returned to the user thread before the
+ * next block boundary, so @reply_func() can be invoked as early
+ * as possible.
+ * This function is MT-safe and may be called from any thread.
+ */
+GslJob*
+gsl_job_request_reply (GslModule    *module,
+                       gpointer      data,
+                       GslReplyFunc  reply_func)
+{
+  GslJob *job;
+  EngineReplyJob *rjob;
+
+  g_return_val_if_fail (module != NULL, NULL);
+  g_return_val_if_fail (ENGINE_MODULE_IS_VIRTUAL (module) == FALSE, NULL);
+  g_return_val_if_fail (reply_func != NULL, NULL);
+  
+  rjob = g_new0 (EngineReplyJob, 1);
+  rjob->reply_func = reply_func;
+  rjob->data = data;
+
+  job = sfi_new_struct0 (GslJob, 1);
+  job->job_id = ENGINE_JOB_REQUEST_REPLY;
+  job->data.reply_job.node = ENGINE_NODE (module);
+  job->data.reply_job.rjob = rjob;
+  
+  return job;
+}
+
 /**
  * gsl_flow_job_access
  * @module:      The module to access
@@ -483,7 +526,7 @@ gsl_job_flow_access (GslModule    *module,
 		     guint64       tick_stamp,
 		     GslAccessFunc access_func,
 		     gpointer      data,
-		     GslFreeFunc   free_func)
+		     GslReplyFunc  reply_func)
 {
   GslJob *job;
   EngineTimedJob *tjob;
@@ -493,11 +536,11 @@ gsl_job_flow_access (GslModule    *module,
   g_return_val_if_fail (tick_stamp < GSL_MAX_TICK_STAMP, NULL);
   g_return_val_if_fail (access_func != NULL, NULL);
   
-  tjob = sfi_new_struct0 (EngineTimedJob, 1);
+  tjob = g_new0 (EngineTimedJob, 1);
+  tjob->reply_func = reply_func;
+  tjob->data = data;
   tjob->tick_stamp = tick_stamp;
   tjob->access_func = access_func;
-  tjob->data = data;
-  tjob->free_func = free_func;
 
   job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_FLOW_JOB;
@@ -528,7 +571,7 @@ gsl_job_boundary_access (GslModule    *module,
                          guint64       tick_stamp,
                          GslAccessFunc access_func,
                          gpointer      data,
-                         GslFreeFunc   free_func)
+                         GslReplyFunc  reply_func)
 {
   GslJob *job;
   EngineTimedJob *tjob;
@@ -538,11 +581,11 @@ gsl_job_boundary_access (GslModule    *module,
   g_return_val_if_fail (tick_stamp < GSL_MAX_TICK_STAMP, NULL);
   g_return_val_if_fail (access_func != NULL, NULL);
   
-  tjob = sfi_new_struct0 (EngineTimedJob, 1);
+  tjob = g_new0 (EngineTimedJob, 1);
+  tjob->reply_func = reply_func;
+  tjob->data = data;
   tjob->tick_stamp = tick_stamp;
   tjob->access_func = access_func;
-  tjob->data = data;
-  tjob->free_func = free_func;
 
   job = sfi_new_struct0 (GslJob, 1);
   job->job_id = ENGINE_JOB_BOUNDARY_JOB;
@@ -1107,7 +1150,7 @@ static gboolean		gsl_engine_initialized = FALSE;
 static gboolean		gsl_engine_threaded = FALSE;
 static SfiThread       *master_thread = NULL;
 static EngineMasterData master_data;
-guint			gsl_externvar_bsize = 0;
+guint			gsl_externvar_block_size = 0;
 guint			gsl_externvar_sample_freq = 0;
 guint			gsl_externvar_sub_sample_mask = 0;
 guint			gsl_externvar_sub_sample_steps = 0;
@@ -1139,7 +1182,7 @@ gsl_engine_init (gboolean run_threaded,
   
   gsl_engine_initialized = TRUE;
   gsl_engine_threaded = run_threaded;
-  gsl_externvar_bsize = block_size;
+  gsl_externvar_block_size = block_size;
   gsl_externvar_sample_freq = sample_freq;
   gsl_externvar_sub_sample_mask = sub_sample_mask << 2;	/* shift out sizeof (float) alignment */
   gsl_externvar_sub_sample_steps = sub_sample_mask + 1;
