@@ -20,11 +20,7 @@
 
 #include <bse/gsldefs.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
-
+G_BEGIN_DECLS
 
 /* --- constants --- */
 #define	GSL_STREAM_MAX_VALUES		        (2048 /* power of 2, <= 16384 */)	/* FIXME */
@@ -54,6 +50,8 @@ typedef guint    (*GslProcessDeferFunc)	(GslModule     *module,
 					 guint		n_ivalues,
 					 guint		n_ovalues);
 typedef void     (*GslResetFunc)	(GslModule     *module);
+typedef void     (*GslReplyFunc)	(gpointer       data,   /* sync with GslFreeFunc */
+                                         gboolean       processed);
 /* gsldefs.h:
  * typedef void  (*GslAccessFunc)	(GslModule	*module,
  *					 gpointer	 data);
@@ -117,6 +115,8 @@ GslModule*	gsl_module_new_virtual	(guint		  n_iostreams,
 					 gpointer	  user_data,
 					 GslFreeFunc	  free_data);
 guint64		gsl_module_tick_stamp	(GslModule	 *module);
+gboolean        gsl_module_has_source   (GslModule       *module,
+                                         guint            istream);
 GslJob*		gsl_job_connect		(GslModule	 *src_module,
 					 guint		  src_ostream,
 					 GslModule	 *dest_module,
@@ -135,13 +135,16 @@ GslJob*		gsl_job_kill_inputs	(GslModule	 *module);
 GslJob*		gsl_job_kill_outputs	(GslModule	 *module);
 GslJob*		gsl_job_integrate	(GslModule	 *module);
 GslJob*		gsl_job_discard		(GslModule	 *module);
+GslJob*		gsl_job_force_reset	(GslModule	 *module);
 GslJob*		gsl_job_access		(GslModule	 *module,
 					 GslAccessFunc	  access_func,	/* EngineThread */
 					 gpointer	  data,
 					 GslFreeFunc	  free_func);	/* UserThread */
 GslJob*		gsl_job_set_consumer	(GslModule	 *module,
 					 gboolean	  is_toplevel_consumer);
-GslJob*		gsl_job_suspend		(GslModule	 *module);
+GslJob*		gsl_job_suspend_now	(GslModule	 *module);
+GslJob*		gsl_job_resume_at	(GslModule	 *module,
+					 guint64	  tick_stamp);
 GslJob*		gsl_job_debug		(const gchar	 *debug);
 GslJob*		gsl_job_add_poll	(GslPollFunc	  poll_func,
 					 gpointer	  data,
@@ -164,24 +167,32 @@ void		gsl_trans_commit_delayed(GslTrans	 *trans,
 void		gsl_trans_dismiss	(GslTrans	 *trans);
 void		gsl_transact		(GslJob		 *job,
 					 ...);
-GslJob*		gsl_flow_job_access	(GslModule	 *module,
+GslJob*		gsl_job_request_reply	(GslModule	 *module,
+					 gpointer	  data,
+					 GslReplyFunc	  reply_func);	/* UserThread */
+GslJob*		gsl_job_flow_access	(GslModule	 *module,
 					 guint64	  tick_stamp,
 					 GslAccessFunc	  access_func,	/* EngineThread */
 					 gpointer	  data,
-					 GslFreeFunc	  free_func);	/* UserThread */
-GslJob*		gsl_flow_job_resume	(GslModule	 *module,
-					 guint64	  tick_stamp);
+					 GslReplyFunc	  reply_func);	/* UserThread */
+GslJob*		gsl_job_boundary_access	(GslModule	 *module,
+					 guint64	  tick_stamp,
+					 GslAccessFunc	  access_func,	/* EngineThread */
+					 gpointer	  data,
+					 GslReplyFunc     reply_func);	/* UserThread */
 
 
-/* --- module utilities --- */
-gfloat*		gsl_engine_const_values	(gfloat		 value);
+/* --- module utilities (EngineThread functions) --- */
+gfloat*	      gsl_engine_const_values   (gfloat		  value);
+gpointer      gsl_module_peek_reply     (GslModule       *module);
+gpointer      gsl_module_process_reply  (GslModule       *module);
 
 
 /* --- initialization & main loop --- */
-void	        gsl_engine_init		(gboolean	 threaded,
-					 guint		 block_size,
-					 guint		 sample_freq,
-					 guint		 sub_sample_mask);
+void	        gsl_engine_init		(gboolean	  threaded,
+					 guint		  block_size,
+					 guint		  sample_freq,
+					 guint		  sub_sample_mask);
 typedef struct
 {
   glong		timeout;
@@ -200,7 +211,7 @@ gboolean      gsl_engine_has_garbage		 (void);
 void	      gsl_engine_garbage_collect	 (void);
 void	      gsl_engine_wait_on_trans		 (void);
 guint64	      gsl_engine_tick_stamp_from_systime (guint64	systime);
-#define	      gsl_engine_block_size()		 ((const guint)	gsl_externvar_bsize + 0)
+#define	      gsl_engine_block_size()		 ((const guint)	gsl_externvar_block_size + 0)
 #define	      gsl_engine_sample_freq()		 ((const guint)	gsl_externvar_sample_freq + 0)
 #define	      gsl_engine_sub_sample_mask()	 ((const guint)	gsl_externvar_sub_sample_mask + 0)
 #define	      gsl_engine_sub_sample_steps()	 ((const guint)	gsl_externvar_sub_sample_steps + 0)
@@ -209,13 +220,11 @@ guint64	      gsl_engine_tick_stamp_from_systime (guint64	systime);
 
 
 /*< private >*/
-extern guint	gsl_externvar_bsize;
+extern guint	gsl_externvar_block_size;
 extern guint	gsl_externvar_sample_freq;
 extern guint	gsl_externvar_sub_sample_mask;
 extern guint	gsl_externvar_sub_sample_steps;
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* __GSL_ENGINE_H__ */
