@@ -1,5 +1,5 @@
 /* GSL Engine - Flow module operation engine
- * Copyright (C) 2001, 2002 Tim Janik
+ * Copyright (C) 2001-2003 Tim Janik
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,9 @@
 
 #define DEBUG        sfi_debug_keyfunc ("engine")
 #define JOB_DEBUG    sfi_debug_keyfunc ("job")
-#define FJOB_DEBUG   sfi_debug_keyfunc ("fjob")
+#define TJOB_DEBUG   sfi_debug_keyfunc ("tjob")
 
-#define	NODE_FLAG_RECONNECT(node)  G_STMT_START { /*(node)->needs_reset = (node)->module.klass->reset != NULL*/; } G_STMT_END
+#define	NODE_FLAG_RECONNECT(node)  G_STMT_START { /*(node)->needs_reset = TRUE*/; } G_STMT_END
 
 
 /* --- time stamping (debugging) --- */
@@ -88,9 +88,11 @@ static guint           master_n_pollfds = 0;
 static guint           master_pollfds_changed = FALSE;
 static GPollFD         master_pollfds[GSL_ENGINE_MAX_POLLFDS];
 static EngineSchedule *master_schedule = NULL;
+static SfiRing        *boundary_node_list = NULL;
+static gboolean        master_new_boundary_jobs = FALSE;
 
 
-/* --- functions --- */
+/* --- node state functions --- */
 static void
 add_consumer (EngineNode *node)
 {
@@ -119,18 +121,18 @@ remove_consumer (EngineNode *node)
 }
 
 static void
-recurse_flag_suspension_update (EngineNode *node)
+propagate_update_suspend (EngineNode *node)
 {
-  if (!node->local_suspend && !node->suspension_update)
+  if (!node->update_suspend)
     {
       guint i, j;
-      node->suspension_update = TRUE;
+      node->update_suspend = TRUE;
       for (i = 0; i < ENGINE_NODE_N_ISTREAMS (node); i++)
 	if (node->inputs[i].src_node)
-	  recurse_flag_suspension_update (node->inputs[i].src_node);
+	  propagate_update_suspend (node->inputs[i].src_node);
       for (j = 0; j < ENGINE_NODE_N_JSTREAMS (node); j++)
 	for (i = 0; i < node->module.jstreams[j].jcount; i++)
-	  recurse_flag_suspension_update (node->jinputs[j][i].src_node);
+	  propagate_update_suspend (node->jinputs[j][i].src_node);
     }
 }
 
@@ -155,7 +157,7 @@ master_idisconnect_node (EngineNode *node,
   NODE_FLAG_RECONNECT (node);
   NODE_FLAG_RECONNECT (src_node);
   /* update suspension state of input */
-  recurse_flag_suspension_update (src_node);
+  propagate_update_suspend (src_node);
   /* add to consumer list */
   if (!was_consumer && ENGINE_NODE_IS_CONSUMER (src_node))
     add_consumer (src_node);
@@ -184,7 +186,7 @@ master_jdisconnect_node (EngineNode *node,
   NODE_FLAG_RECONNECT (node);
   NODE_FLAG_RECONNECT (src_node);
   /* update suspension state of input */
-  recurse_flag_suspension_update (src_node);
+  propagate_update_suspend (src_node);
   /* add to consumer list */
   if (!was_consumer && ENGINE_NODE_IS_CONSUMER (src_node))
     add_consumer (src_node);
@@ -205,6 +207,113 @@ master_disconnect_node_outputs (EngineNode *src_node,
 	master_jdisconnect_node (dest_node, j, i--);
 }
 
+
+/* --- timed job handling --- */
+static inline void
+insert_trash_job (EngineNode      *node,
+                  EngineReplyJob  *rjob)
+{
+  rjob->next = node->rjob_first;
+  node->rjob_first = rjob;
+  if (!node->rjob_last)
+    node->rjob_last = node->rjob_first;
+}
+
+static inline EngineTimedJob*
+node_pop_flow_job (EngineNode  *node,
+                   guint64      tick_stamp)
+{
+  EngineTimedJob *tjob = node->flow_jobs;
+  if_reject (tjob != NULL)
+    {
+      if (tjob->tick_stamp <= tick_stamp)
+        {
+          node->flow_jobs = tjob->next;
+          insert_trash_job (node, (EngineReplyJob*) tjob);
+        }
+      else
+        tjob = NULL;
+    }
+  return tjob;
+}
+
+static inline EngineTimedJob*
+node_pop_boundary_job (EngineNode  *node,
+                       guint64      tick_stamp,
+                       SfiRing     *blist_node)
+{
+  EngineTimedJob *tjob = node->boundary_jobs;
+  if (tjob != NULL)
+    {
+      if (tjob->tick_stamp <= tick_stamp)
+        {
+          node->boundary_jobs = tjob->next;
+          insert_trash_job (node, (EngineReplyJob*) tjob);
+          if (!node->boundary_jobs)
+            boundary_node_list = sfi_ring_remove_node (boundary_node_list, blist_node);
+        }
+      else
+        tjob = NULL;
+    }
+  return tjob;
+}
+
+static inline EngineTimedJob*
+insert_timed_job (EngineTimedJob *head,
+                  EngineTimedJob *tjob)
+{
+  EngineTimedJob *last = NULL, *tmp = head;
+  /* find next position */
+  while (tmp && tmp->tick_stamp <= tjob->tick_stamp)
+    {
+      last = tmp;
+      tmp = last->next;
+    }
+  /* insert before */
+  tjob->next = tmp;
+  if (last)
+    last->next = tjob;
+  else
+    head = tjob;
+  return head;
+}
+
+static void
+node_insert_flow_job (EngineNode      *node,
+                      EngineTimedJob  *tjob)
+{
+  node->flow_jobs = insert_timed_job (node->flow_jobs, tjob);
+}
+
+static void
+node_insert_boundary_job (EngineNode      *node,
+                          EngineTimedJob  *tjob)
+{
+  if (!node->boundary_jobs)
+    boundary_node_list = sfi_ring_append (boundary_node_list, node);
+  node->boundary_jobs = insert_timed_job (node->boundary_jobs, tjob);
+}
+
+static inline guint64
+node_peek_flow_job_stamp (EngineNode *node)
+{
+  EngineTimedJob *tjob = node->flow_jobs;
+  if_reject (tjob != NULL)
+    return tjob->tick_stamp;
+  return GSL_MAX_TICK_STAMP;
+}
+
+static inline guint64
+node_peek_boundary_job_stamp (EngineNode *node)
+{
+  EngineTimedJob *tjob = node->boundary_jobs;
+  if_reject (tjob != NULL)
+    return tjob->tick_stamp;
+  return GSL_MAX_TICK_STAMP;
+}
+
+
+/* --- job processing --- */
 static void
 master_process_job (GslJob *job)
 {
@@ -213,21 +322,25 @@ master_process_job (GslJob *job)
       EngineNode *node, *src_node;
       Poll *poll, *poll_last;
       Timer *timer;
+      guint64 stamp;
       guint istream, jstream, ostream, con;
-      EngineFlowJob *fjob;
+      EngineTimedJob *tjob;
+      EngineReplyJob *rjob;
       gboolean was_consumer;
     case ENGINE_JOB_INTEGRATE:
       node = job->data.node;
       JOB_DEBUG ("integrate(%p)", node);
       g_return_if_fail (node->integrated == FALSE);
       g_return_if_fail (node->sched_tag == FALSE);
+      job->data.node = NULL;  /* ownership taken over */
       _engine_mnl_integrate (node);
       if (ENGINE_NODE_IS_CONSUMER (node))
 	add_consumer (node);
-      node->counter = 0;
+      node->counter = GSL_TICK_STAMP;
       NODE_FLAG_RECONNECT (node);
-      node->outputs_suspended = TRUE;
-      node->suspension_update = TRUE;
+      node->local_active = 0;   /* by default not suspended */
+      node->update_suspend = TRUE;
+      node->needs_reset = TRUE;
       master_need_reflow |= TRUE;
       break;
     case ENGINE_JOB_KILL_INPUTS:
@@ -275,11 +388,15 @@ master_process_job (GslJob *job)
       node->counter = GSL_MAX_TICK_STAMP;
       master_need_reflow |= TRUE;
       master_schedule_discard ();	/* discard schedule so node may be freed */
-      /* nuke pending flow jobs */
+      /* nuke pending timed jobs */
       do
-	fjob = _engine_node_pop_flow_job (node, GSL_MAX_TICK_STAMP);
-      while (fjob);
-      _engine_node_collect_flow_jobs (node);
+        tjob = node_pop_flow_job (node, GSL_MAX_TICK_STAMP);
+      while (tjob);
+      if (node->boundary_jobs)
+        do
+          tjob = node_pop_boundary_job (node, GSL_MAX_TICK_STAMP, sfi_ring_find (boundary_node_list, node));
+        while (tjob);
+      _engine_node_collect_jobs (node);
       break;
     case ENGINE_JOB_SET_CONSUMER:
     case ENGINE_JOB_UNSET_CONSUMER:
@@ -298,17 +415,28 @@ master_process_job (GslJob *job)
 	}
       break;
     case ENGINE_JOB_SUSPEND:
-      node = job->data.node;
-      JOB_DEBUG ("suspend(%p)", node);
+      node = job->data.tick.node;
+      stamp = job->data.tick.stamp;
+      JOB_DEBUG ("suspend(%p,%llu)", node, stamp);
       g_return_if_fail (node->integrated == TRUE);
-      if (!node->local_suspend)
+      if (node->local_active < stamp)
 	{
-	  /* order matters for the next two lines, because
-	   * recurse_flag_suspension_update() aborts on local_suspend==TRUE
-	   */
-	  recurse_flag_suspension_update (node);
-	  node->local_suspend = TRUE;
-	  node->needs_reset = node->module.klass->reset != NULL;
+	  propagate_update_suspend (node);
+	  node->local_active = stamp;
+	  node->needs_reset = TRUE;
+	  master_need_reflow |= TRUE;
+	}
+      break;
+    case ENGINE_JOB_RESUME:
+      node = job->data.tick.node;
+      stamp = job->data.tick.stamp;
+      JOB_DEBUG ("resume(%p,%llu)", node, stamp);
+      g_return_if_fail (node->integrated == TRUE);
+      if (node->local_active > stamp)
+	{
+	  propagate_update_suspend (node);
+	  node->local_active = stamp;
+	  node->needs_reset = TRUE;
 	  master_need_reflow |= TRUE;
 	}
       break;
@@ -332,7 +460,7 @@ master_process_job (GslJob *job)
       NODE_FLAG_RECONNECT (node);
       NODE_FLAG_RECONNECT (src_node);
       /* update suspension state of input */
-      recurse_flag_suspension_update (src_node);
+      propagate_update_suspend (src_node);
       if (was_consumer && !ENGINE_NODE_IS_CONSUMER (src_node))
 	remove_consumer (src_node);
       master_need_reflow |= TRUE;
@@ -359,7 +487,7 @@ master_process_job (GslJob *job)
       NODE_FLAG_RECONNECT (node);
       NODE_FLAG_RECONNECT (src_node);
       /* update suspension state of input */
-      recurse_flag_suspension_update (src_node);
+      propagate_update_suspend (src_node);
       if (was_consumer && !ENGINE_NODE_IS_CONSUMER (src_node))
 	remove_consumer (src_node);
       master_need_reflow |= TRUE;
@@ -392,20 +520,46 @@ master_process_job (GslJob *job)
       else
 	g_warning ("jdisconnect(dest:%p,%u,src:%p,%u): no such connection", node, jstream, src_node, ostream);
       break;
+    case ENGINE_JOB_FORCE_RESET:
+      node = job->data.node;
+      JOB_DEBUG ("reset(%p)", node);
+      g_return_if_fail (node->integrated == TRUE);
+      node->counter = GSL_TICK_STAMP;
+      node->needs_reset = TRUE;
+      break;
     case ENGINE_JOB_ACCESS:
       node = job->data.access.node;
       JOB_DEBUG ("access node(%p): %p(%p)", node, job->data.access.access_func, job->data.access.data);
       g_return_if_fail (node->integrated == TRUE);
+      node->counter = GSL_TICK_STAMP;
       job->data.access.access_func (&node->module, job->data.access.data);
       break;
-    case ENGINE_JOB_FLOW_JOB:
-      node = job->data.flow_job.node;
-      fjob = job->data.flow_job.fjob;
-      JOB_DEBUG ("add flow_job(%p,%p)", node, fjob);
+    case ENGINE_JOB_REQUEST_REPLY:
+      node = job->data.timed_job.node;
+      rjob = job->data.reply_job.rjob;
+      JOB_DEBUG ("add reply_request(%p,%p)", node, rjob);
       g_return_if_fail (node->integrated == TRUE);
-      job->data.flow_job.fjob = NULL;	/* ownership taken over */
-      _engine_node_insert_flow_job (node, fjob);
-      _engine_mnl_reorder (node);
+      job->data.reply_job.rjob = NULL;  /* ownership taken over */
+      rjob->next = node->reply_jobs;
+      node->reply_jobs = rjob;
+      break;
+    case ENGINE_JOB_FLOW_JOB:
+      node = job->data.timed_job.node;
+      tjob = job->data.timed_job.tjob;
+      JOB_DEBUG ("add flow_job(%p,%p)", node, tjob);
+      g_return_if_fail (node->integrated == TRUE);
+      job->data.timed_job.tjob = NULL;	/* ownership taken over */
+      node_insert_flow_job (node, tjob);
+      _engine_mnl_node_changed (node);
+      break;
+    case ENGINE_JOB_BOUNDARY_JOB:
+      node = job->data.timed_job.node;
+      tjob = job->data.timed_job.tjob;
+      JOB_DEBUG ("add boundary_job(%p,%p)", node, tjob);
+      g_return_if_fail (node->integrated == TRUE);
+      job->data.timed_job.tjob = NULL;	/* ownership taken over */
+      node_insert_boundary_job (node, tjob);
+      master_new_boundary_jobs = TRUE;
       break;
     case ENGINE_JOB_DEBUG:
       JOB_DEBUG ("debug");
@@ -537,98 +691,77 @@ master_tick_stamp_inc (void)
     }
 }
 
-static void
-propagate_resume (EngineNode *node)
-{
-  guint i, j;
-
-  /* though resumption propagation can only work within scheduled
-   * node branches (since non-scheduled nodes don't have properly
-   * updated suspension state), we use src_node (not real_node) and
-   * jcount (not n_connections) for the propagation walk, in order
-   * to ensure that virtual nodes behave like normal nodes regarding
-   * suspension propagation (they cannot be suspended/resumed locally
-   * though).
-   */
-  g_return_if_fail (!ENGINE_NODE_IS_SUSPENDED (node));
-
-  for (i = 0; i < ENGINE_NODE_N_ISTREAMS (node); i++)
-    {
-      EngineNode *src_node = node->inputs[i].src_node;
-      if (src_node && src_node->outputs_suspended)
-	{
-	  src_node->outputs_suspended = FALSE;
-	  src_node->needs_reset = src_node->module.klass->reset != NULL;
-	  if (!ENGINE_NODE_IS_SUSPENDED (src_node))
-	    propagate_resume (src_node);
-	}
-    }
-  for (j = 0; j < ENGINE_NODE_N_JSTREAMS (node); j++)
-    for (i = 0; i < node->module.jstreams[j].n_connections; i++)
-      {
-	EngineNode *src_node = node->jinputs[j][i].src_node;
-	if (src_node->outputs_suspended)
-	  {
-	    src_node->outputs_suspended = FALSE;
-	    src_node->needs_reset = src_node->module.klass->reset != NULL;
-	    if (!ENGINE_NODE_IS_SUSPENDED (src_node))
-	      propagate_resume (src_node);
-	  }
-      }
-}
-
 static inline guint64
-master_handle_flow_jobs (EngineNode *node,
-			 guint64     max_tick)
+master_update_node_state (EngineNode *node,
+                          guint64     max_tick)
 {
-  EngineFlowJob *fjob = _engine_node_pop_flow_job (node, max_tick);
-
-  /* node is not necessarily scheduled */
-  
-  if_reject (fjob)
+  /* the node is not necessarily scheduled */
+  EngineTimedJob *tjob;
+  /* if a reset is pending, it needs to be handled *before*
+   * flow jobs change state.
+   */
+  if_reject (node->needs_reset && !ENGINE_NODE_IS_SUSPENDED (node, node->counter))
+    {
+      /* for suspended nodes, reset() occours later */
+      if (node->module.klass->reset)
+        node->module.klass->reset (&node->module);
+      node->needs_reset = FALSE;
+    }
+  tjob = node_pop_flow_job (node, max_tick);
+  if_reject (tjob != NULL)
     do
       {
-	FJOB_DEBUG ("FJob (%s) for (%p:s=%u) at:%lld current:%lld\n",
-		    fjob->fjob_id == ENGINE_FLOW_JOB_RESUME ? "resume" : "access",
-		    node, node->sched_tag, fjob->any.tick_stamp, node->counter);
-	switch (fjob->fjob_id)
-	  {
-	  case ENGINE_FLOW_JOB_ACCESS:
-	    fjob->access.access_func (&node->module, fjob->access.data);
-	    break;
-	  case ENGINE_FLOW_JOB_RESUME:
-	    if (node->local_suspend)
-	      {
-		node->local_suspend = FALSE;
-		node->needs_reset = node->module.klass->reset != NULL;
-		if (ENGINE_NODE_IS_SCHEDULED (node) && !ENGINE_NODE_IS_SUSPENDED (node))
-		  propagate_resume (node);
-	      }
-	    break;
-	  default:
-	    g_assert_not_reached ();
-	  }
-	fjob = _engine_node_pop_flow_job (node, max_tick);
+	TJOB_DEBUG ("flow-access for (%p:s=%u) at:%lld current:%lld\n",
+		    node, node->sched_tag, tjob->tick_stamp, node->counter);
+        tjob->access_func (&node->module, tjob->data);
+        tjob = node_pop_flow_job (node, max_tick);
       }
-    while (fjob);
-  
-  return _engine_node_peek_flow_job_stamp (node);
+    while (tjob);
+  return node_peek_flow_job_stamp (node);
+}
+
+gpointer
+gsl_module_peek_reply (GslModule *module)
+{
+  EngineNode *node = ENGINE_NODE (module);
+  g_return_val_if_fail (ENGINE_NODE_IS_SCHEDULED (node), NULL);
+  return node->reply_jobs ? node->reply_jobs->data : NULL;
+}
+
+gpointer
+gsl_module_process_reply (GslModule *module)
+{
+  EngineNode *node = ENGINE_NODE (module);
+  g_return_val_if_fail (ENGINE_NODE_IS_SCHEDULED (node), NULL);
+  if (G_UNLIKELY (node->reply_jobs))
+    {
+      EngineReplyJob *rjob = node->reply_jobs;
+      node->reply_jobs = rjob->next;
+      insert_trash_job (node, rjob);
+      return rjob->data;
+    }
+  return NULL;
 }
 
 static void
 master_process_locked_node (EngineNode *node,
 			    guint       n_values)
 {
-  guint64 final_counter = GSL_TICK_STAMP + n_values;
-
+  guint64 next_counter, new_counter, final_counter = GSL_TICK_STAMP + n_values;
+  guint i, j, diff;
+  
   g_return_if_fail (node->integrated && node->sched_tag);
   
   while (node->counter < final_counter)
     {
-      guint64 next_counter = master_handle_flow_jobs (node, node->counter);
-      guint64 new_counter = MIN (next_counter, final_counter);
-      guint i, j, diff = node->counter - GSL_TICK_STAMP;
-      
+      /* call reset() and exec flow jobs */
+      next_counter = master_update_node_state (node, node->counter);
+      /* figure n_values to process */
+      new_counter = MIN (next_counter, final_counter);
+      if (node->next_active > node->counter)
+        new_counter = MIN (node->next_active, new_counter);
+      diff = node->counter - GSL_TICK_STAMP;
+      /* ensure all istream inputs have n_values available */
       for (i = 0; i < ENGINE_NODE_N_ISTREAMS (node); i++)
 	{
 	  EngineNode *inode = node->inputs[i].real_node;
@@ -645,6 +778,7 @@ master_process_locked_node (EngineNode *node,
 	  else
 	    node->module.istreams[i].values = gsl_engine_master_zero_block;
 	}
+      /* ensure all jstream inputs have n_values available */
       for (j = 0; j < ENGINE_NODE_N_JSTREAMS (node); j++)
 	for (i = 0; i < node->module.jstreams[j].n_connections; i++) /* assumes scheduled node */
 	  {
@@ -657,22 +791,21 @@ master_process_locked_node (EngineNode *node,
 	    node->module.jstreams[j].values[i] += diff;
 	    ENGINE_NODE_UNLOCK (inode);
 	  }
+      /* update obuffer pointer */
       for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
 	node->module.ostreams[i].values = node->outputs[i].buffer + diff;
-      if_reject (node->needs_reset)
+      /* process() node */
+      if_reject (ENGINE_NODE_IS_SUSPENDED (node, node->counter))
 	{
-	  node->module.klass->reset (&node->module);
-	  node->needs_reset = FALSE;
-	}
-      if (ENGINE_NODE_IS_SUSPENDED (node))
-	{
-	  /* suspended node processing method */
+	  /* suspended node processing behaviour */
 	  for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
 	    if (node->module.ostreams[i].connected)
 	      node->module.ostreams[i].values = gsl_engine_const_values (0.0);
+          node->needs_reset = TRUE;
 	}
       else
-	node->module.klass->process (&node->module, new_counter - node->counter);
+        node->module.klass->process (&node->module, new_counter - node->counter);
+      /* catch obuffer pointer changes */
       for (i = 0; i < ENGINE_NODE_N_OSTREAMS (node); i++)
 	{
 	  /* FIXME: this takes the worst possible performance hit to support virtualization */
@@ -680,6 +813,7 @@ master_process_locked_node (EngineNode *node,
 	    memcpy (node->outputs[i].buffer + diff, node->module.ostreams[i].values,
 		    (new_counter - node->counter) * sizeof (gfloat));
 	}
+      /* update node counter */
       node->counter = new_counter;
     }
 }
@@ -751,9 +885,9 @@ master_process_flow (void)
       while (node && GSL_MNL_UNSCHEDULED_FLOW_NODE (node))
 	{
 	  EngineNode *tmp = node->mnl_next;
-
-	  master_handle_flow_jobs (node, final_counter);
-	  _engine_mnl_reorder (node);
+          node->counter = final_counter;
+          master_update_node_state (node, node->counter - 1);
+	  _engine_mnl_node_changed (node);      /* collects trash jobs */
 	  node = tmp;
 	}
 
@@ -875,18 +1009,50 @@ _engine_master_check (const GslEngineLoop *loop)
 void
 _engine_master_dispatch_jobs (void)
 {
-  GslJob *job;
-  
-  /* here, we have to process _all_ pending jobs
-   * in a row. a popped job stays valid until the
-   * next call to _engine_pop_job().
+  guint64 CURRENT_STAMP = GSL_TICK_STAMP;
+  guint64 last_block_tick = CURRENT_STAMP + gsl_engine_block_size() - 1;
+  GslJob *job = _engine_pop_job ();
+  /* here, we have to process _all_ pending jobs in a row. a popped job
+   * stays valid until the next call to _engine_pop_job().
    */
-  job = _engine_pop_job ();
   while (job)
     {
       master_process_job (job);
       job = _engine_pop_job ();
     }
+  /* process boundary jobs and possibly newly queued jobs after that. */
+  if_reject (boundary_node_list != NULL)
+    do
+      {
+        SfiRing *ring = boundary_node_list;
+        master_new_boundary_jobs = FALSE;       /* to catch new boundary jobs */
+        while (ring)
+          {
+            SfiRing *current = ring;
+            EngineNode *node = ring->data;
+            EngineTimedJob *tjob;
+            ring = sfi_ring_walk (ring, boundary_node_list);
+            tjob = node_pop_boundary_job (node, last_block_tick, current);
+            if (tjob)
+              node->counter = CURRENT_STAMP;
+            while (tjob)
+              {
+                TJOB_DEBUG ("boundary-access for (%p:s=%u) at:%lld current:%lld\n",
+                            node, node->sched_tag, tjob->tick_stamp, node->counter);
+                tjob->access_func (&node->module, tjob->data);
+                tjob = node_pop_boundary_job (node, last_block_tick, current);
+              }
+          }
+        /* process newly queued jobs if any */
+        job = _engine_pop_job ();
+        while (job)
+          {
+            master_process_job (job);
+            job = _engine_pop_job ();
+          }
+        /* need to repeat if master_process_job() just queued a new boundary job */
+      }
+    while (master_new_boundary_jobs);   /* new boundary jobs arrived */
 }
 
 void
@@ -942,7 +1108,7 @@ _engine_master_thread (EngineMasterData *mdata)
 	  if (err >= 0)
 	    loop.revents_filled = TRUE;
 	  else if (errno != EINTR)
-	    g_printerr (G_STRLOC ": poll() error: %s\n", g_strerror (errno));
+	    g_printerr ("%s: poll() error: %s\n", G_STRFUNC, g_strerror (errno));
 	  
 	  if (loop.revents_filled)
 	    need_dispatch = _engine_master_check (&loop);
