@@ -1,5 +1,6 @@
 #include <bse/bsecxxbase.h>
 #include <bse/bsemain.h>
+#include <bse/bseamplifier.gen-idl.h>
 
 namespace {
 using namespace Bse;
@@ -26,7 +27,9 @@ main (int   argc,
 {
   g_thread_init (NULL);
   bse_init_intern (&argc, &argv, NULL);
-
+  std::set_terminate (__gnu_cxx::__verbose_terminate_handler);
+  // g_log_set_always_fatal ((GLogLevelFlags) (G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL | (int) g_log_set_always_fatal ((GLogLevelFlags) G_LOG_FATAL_MASK)));
+   
   // test closure Arg types
   Arg<FooTest*> a1;
   a1.token();
@@ -42,13 +45,11 @@ main (int   argc,
   a5.token();
   // tokenize_gtype (0);
 
-#if 0   // need non-abstract C++ object in the core for this test
-  GObject *o = (GObject*) g_object_new (BSE_TYPE_CXX_BASE, NULL);
+  GObject *o = (GObject*) g_object_new (BSE_TYPE_AMPLIFIER, NULL);
   CxxBase *b = cast (o);
   Foo f;
   b->connect ("notify", Closure (&f, &Foo::bar));
   b->connect ("notify", Closure (&f, &Foo::baz));
-#endif
   
   return 0;
 }
