@@ -53,22 +53,17 @@ static void	bse_simple_adsr_update_modules	(BseSimpleADSR		*simple_adsr,
 						 GslTrans		*trans);
 
 
+/* --- Export to BSE --- */
+#include "./icons/adsr.c"
+BSE_REGISTER_OBJECT (BseSimpleADSR, BseSource, "/Modules/Other Sources/Simple ADSR",
+                     "Simple ADSR envelope generator",
+                     adsr_icon,
+                     bse_simple_adsr_class_init, NULL, bse_simple_adsr_init);
+BSE_DEFINE_EXPORTS (BSE_PLUGIN_NAME);
+
+
 /* --- variables --- */
-static GType	       type_id_simple_adsr = 0;
 static gpointer	       parent_class = NULL;
-static const GTypeInfo type_info_simple_adsr = {
-  sizeof (BseSimpleADSRClass),
-  
-  (GBaseInitFunc) NULL,
-  (GBaseFinalizeFunc) NULL,
-  (GClassInitFunc) bse_simple_adsr_class_init,
-  (GClassFinalizeFunc) NULL,
-  NULL /* class_data */,
-  
-  sizeof (BseSimpleADSR),
-  0 /* n_preallocs */,
-  (GInstanceInitFunc) bse_simple_adsr_init,
-};
 
 
 /* --- functions --- */
@@ -92,22 +87,22 @@ bse_simple_adsr_class_init (BseSimpleADSRClass *class)
 			      PARAM_ATTACK_TIME,
 			      sfi_pspec_real ("attack_time", "Attack Time [%]", NULL,
 					      10.0, 0.0, 100.0, 1.0,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_DIAL SFI_PARAM_FLOAT));
+					      SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, "Envelope",
 			      PARAM_DECAY_TIME,
 			      sfi_pspec_real ("decay_time", "Decay Time [%]", NULL,
 					      30.0, 0.0, 100.0, 1.0,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_DIAL SFI_PARAM_FLOAT));
+					      SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, "Envelope",
 			      PARAM_SUSTAIN_LEVEL,
 			      sfi_pspec_real ("sustain_level", "Sustain Level [%]", NULL,
 					      50.0, 0.0, 100.0, 1.0,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_DIAL SFI_PARAM_FLOAT));
+					      SFI_PARAM_STANDARD ":f:dial"));
   bse_object_class_add_param (object_class, "Envelope",
 			      PARAM_RELEASE_TIME,
 			      sfi_pspec_real ("release_time", "Release Time [%]", NULL,
 					      40.0, 0.0, 100.0, 1.0,
-					      SFI_PARAM_DEFAULT SFI_PARAM_HINT_DIAL SFI_PARAM_FLOAT));
+					      SFI_PARAM_STANDARD ":f:dial"));
   desc = g_strdup_printf ("Time ranges in seconds: %.1f %.1f %.1f",
 			  BSE_TIME_RANGE_SHORT_ms / 1000.0,
 			  BSE_TIME_RANGE_MEDIUM_ms / 1000.0,
@@ -117,7 +112,7 @@ bse_simple_adsr_class_init (BseSimpleADSRClass *class)
 			      bse_param_spec_genum ("time_range", "Time Range", desc,
 						    BSE_TYPE_TIME_RANGE_TYPE,
 						    BSE_TIME_RANGE_SHORT,
-						    SFI_PARAM_DEFAULT));
+						    SFI_PARAM_STANDARD));
   g_free (desc);
   
   ichannel = bse_source_class_add_ichannel (source_class, "Gate In", "Gate input (activates/deactivates envelope)");
@@ -445,20 +440,3 @@ bse_simple_adsr_context_create (BseSource *source,
   /* update module data */
   bse_simple_adsr_update_modules (simple_adsr, trans);
 }
-
-
-/* --- Export to BSE --- */
-#include "./icons/adsr.c"
-BSE_EXPORTS_BEGIN (BSE_PLUGIN_NAME);
-BSE_EXPORT_OBJECTS = {
-  { &type_id_simple_adsr, "BseSimpleADSR", "BseSource",
-    "Simple ADSR envelope generator",
-    &type_info_simple_adsr,
-    "/Modules/Other Sources/Simple ADSR",
-    { ADSR_IMAGE_BYTES_PER_PIXEL | BSE_PIXDATA_1BYTE_RLE,
-      ADSR_IMAGE_WIDTH, ADSR_IMAGE_HEIGHT,
-      ADSR_IMAGE_RLE_PIXEL_DATA, },
-  },
-  { NULL, },
-};
-BSE_EXPORTS_END;
