@@ -21,6 +21,24 @@
 #include "glib-extra.h"
 
 
+void
+g_object_disconnect_any (gpointer object,
+                         gpointer function,
+                         gpointer data)
+{
+  g_return_if_fail (G_IS_OBJECT (object));
+  g_return_if_fail (function != NULL);
+  /* FIXME: the only reason we have this function is that
+   * g_object_disconnect() throws a warning for an any-signal::
+   * disconnection that does not exist (it may do so for all-signals
+   * instead).
+   */
+  g_signal_handlers_disconnect_matched (object, G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+                                        0, 0, 0,
+                                        function, data);
+}
+
+
 /* --- string functions --- */
 gchar**
 g_straddv (gchar      **str_array,
@@ -1694,7 +1712,7 @@ g_scanner_sync_file_offset (GScanner *scanner)
   g_return_if_fail (scanner != NULL);
 
   /* for file input, rewind the filedescriptor to the current
-   * buffer position and blow the file read ahead buffer. usefull for
+   * buffer position and blow the file read ahead buffer. useful for
    * third party uses of our filedescriptor, which hooks onto the current
    * scanning position.
    */
