@@ -88,16 +88,18 @@ enum ExtraToken {
   TOKEN_SEQUENCE,
   TOKEN_PROPERTY,
   TOKEN_GROUP,
+  TOKEN_USING,
   TOKEN_CONST,
   TOKEN_INFO,
   TOKEN_ISTREAM,
   TOKEN_JSTREAM,
   TOKEN_OSTREAM,
+  TOKEN_ERROR
 };
 
 const char *token_symbols[] = {
   "namespace", "class", "choice", "record", "sequence",
-  "property", "group",
+  "property", "group", "using",
   "Const", "Info", "IStream", "JStream", "OStream",
   0
 };
@@ -197,21 +199,21 @@ bool Parser::isClass(const string& type) const
   return (i != typeMap.end()) && ((i->second & (~tdProto)) == tdClass);
 }
 
-Type Parser::typeOf(const string& type) const
+Type Parser::typeOf (const string& type) const
 {
-  if (type == "void")	  return VOID;
-  if (type == "Bool")	  return BOOL;
-  if (type == "Int")	  return INT;
-  if (type == "Num")	  return NUM;
-  if (type == "Real")	  return REAL;
-  if (type == "String")   return STRING;
-  if (isChoice (type))	  return CHOICE;
-  if (type == "BBlock")   return BBLOCK;
-  if (type == "FBlock")   return FBLOCK;
-  if (type == "Rec")      return SFIREC;
-  if (isSequence (type))  return SEQUENCE;
-  if (isRecord (type))    return RECORD;
-  if (isClass (type))     return OBJECT;
+  if (type == "void")	      return VOID;
+  if (type == "Sfi::Bool")    return BOOL;
+  if (type == "Sfi::Int")     return INT;
+  if (type == "Sfi::Num")     return NUM;
+  if (type == "Sfi::Real")    return REAL;
+  if (type == "Sfi::String")  return STRING;
+  if (isChoice (type))	      return CHOICE;
+  if (type == "Sfi::BBlock")  return BBLOCK;
+  if (type == "Sfi::FBlock")  return FBLOCK;
+  if (type == "Sfi::Rec")     return SFIREC;
+  if (isSequence (type))      return SEQUENCE;
+  if (isRecord (type))	      return RECORD;
+  if (isClass (type))	      return OBJECT;
   g_error (("invalid type: " + type).c_str());
   return VOID;
 }
@@ -238,6 +240,16 @@ Record Parser::findRecord(const string& name) const
   return Record();
 }
 
+const Class*
+Parser::findClass (const string& name) const
+{
+  for (vector<Class>::const_iterator ci = classes.begin(); ci != classes.end(); ci++)
+    if (ci->name == name)
+      return &*ci;
+
+  return 0;
+}
+
 Parser::Parser () : options (*Options::the())
 {
   scanner = g_scanner_new (&scanner_config_template);
@@ -310,7 +322,13 @@ static bool fileExists(const string& filename)
 
 static void loadFile(const char *filename, vector<char>& v)
 {
-  FILE *f = fopen(filename,"r");
+  FILE *f = 0;
+
+  if (strcmp (filename, "-") == 0) /* stdin */
+    f = stdin;
+  else
+    f = fopen (filename,"r");
+
   if(!f)
     {
       fprintf(stderr,"file '%s' not found\n",filename);
@@ -319,7 +337,7 @@ static void loadFile(const char *filename, vector<char>& v)
 
   char buffer[1024];
   long l;
-  while((l = fread(buffer,1,1024,f)) > 0)
+  while (!feof (f) && (l = fread(buffer,1,1024,f)) > 0)
     v.insert(v.end(),buffer, buffer+l);
   fclose(f);
 }
@@ -383,7 +401,7 @@ void Parser::preprocess (const string& filename, bool includeImpl)
 void Parser::preprocessContents (const string& input_filename)
 {
   string filename;
-  bool includeImpl;
+  bool includeImpl = false; // always initialized again, this just silences the compiler
   enum
     {
       lineStart, idlCode, commentC, commentCxx,
@@ -393,7 +411,7 @@ void Parser::preprocessContents (const string& input_filename)
 
   LineInfo linfo;
   linfo.line = 1;
-  linfo.filename = input_filename;
+  linfo.filename = (input_filename == "-") ? "stdin" : input_filename;
 
   vector<char> input;
   loadFile (input_filename.c_str(), input);
@@ -571,6 +589,53 @@ bool Parser::insideInclude () const
   return scannerLineInfo[scanner_line].isInclude;
 }
 
+/*
+ * comparation class, used to sort classes in such an order that bases
+ * classes appear before derived classes
+ */
+class ClassCompare {
+public:
+  const Parser& parser;
+  map<string, int> inheritanceLevel;
+
+  ClassCompare (const Parser& parser) : parser (parser)
+  {
+    vector<Class>::const_iterator ci;
+
+    /*
+     * precompute the inheritance levels, as the classes data structure within the
+     * parser will be modified by sort() during sorting with ClassCompare ; besides,
+     * it should be more efficient that way
+     */
+    for (ci = parser.getClasses().begin(); ci != parser.getClasses().end(); ci++)
+      computeInheritanceLevel (*ci);
+  }
+
+  int computeInheritanceLevel (const Class& cdef)
+  {
+    int& level = inheritanceLevel[cdef.name];
+    if (!level)
+      {
+	const Class *parent = (cdef.inherits == "") ? 0 : parser.findClass (cdef.inherits);
+	if (parent)
+	  level = computeInheritanceLevel (*parent) + 1;
+	else
+	  level = 1;
+      }
+    return level;
+  }
+
+  /* return true if c1 is to be placed before c2 */
+  bool operator()(const Class& c1, const Class& c2)
+  {
+    int l1 = inheritanceLevel[c1.name];
+    int l2 = inheritanceLevel[c2.name];
+    if (l1 < l2) return true;
+    if (l1 > l2) return false;
+    return c1.name < c2.name;
+  }
+};
+
 /* --- parsing functions --- */
 
 bool Parser::parse (const string& filename)
@@ -581,6 +646,10 @@ bool Parser::parse (const string& filename)
   /* provide abosulte input file name for fileName() */
   if (g_path_is_absolute (filename.c_str()))
     scanner->input_name = g_strdup (filename.c_str());
+  else if (filename == "-") /* stdin */
+    {
+      scanner->input_name = "stdin";
+    }
   else
     {
       gchar *dir = g_get_current_dir();
@@ -589,16 +658,20 @@ bool Parser::parse (const string& filename)
     }
   /* FIXME: we leak scanner->input_name later on */
 
+  currentNamespace = &rootNamespace;
+
   /* define primitive types into the basic namespace */
-  ModuleHelper::define("Bool");
-  ModuleHelper::define("Int");
-  ModuleHelper::define("Num");
-  ModuleHelper::define("Real");
-  ModuleHelper::define("String");
-  ModuleHelper::define("BBlock");
-  ModuleHelper::define("FBlock");
-  ModuleHelper::define("Rec");
-  
+  enterNamespace ("Sfi");
+  defineSymbol ("Bool");
+  defineSymbol ("Int");
+  defineSymbol ("Num");
+  defineSymbol ("Real");
+  defineSymbol ("String");
+  defineSymbol ("BBlock");
+  defineSymbol ("FBlock");
+  defineSymbol ("Rec");
+  leaveNamespace ();
+
   GTokenType expected_token = G_TOKEN_NONE;
   
   while (!g_scanner_eof (scanner) && expected_token == G_TOKEN_NONE)
@@ -613,7 +686,7 @@ bool Parser::parse (const string& filename)
         expected_token = G_TOKEN_EOF; /* '('; */
     }
   
-  if (expected_token != G_TOKEN_NONE)
+  if (expected_token != G_TOKEN_NONE && expected_token != (GTokenType)TOKEN_ERROR)
     {
       g_scanner_unexp_token (scanner, expected_token, NULL, NULL, NULL, NULL, TRUE);
       return false;
@@ -622,6 +695,8 @@ bool Parser::parse (const string& filename)
   if (scanner->parse_errors > 0)
     return false;
 
+  /* postprocessing of the data structures: */
+  sort (classes.begin(), classes.end(), ClassCompare (*this));
   return true;
 }
 
@@ -629,7 +704,9 @@ GTokenType Parser::parseNamespace()
 {
   DEBUG("parse namespace\n");
   parse_or_return (G_TOKEN_IDENTIFIER);
-  ModuleHelper::enter (scanner->value.v_identifier);
+
+  if (!enterNamespace (scanner->value.v_identifier))
+    return GTokenType (TOKEN_ERROR);
   
   parse_or_return (G_TOKEN_LEFT_CURLY);
 
@@ -673,7 +750,7 @@ GTokenType Parser::parseNamespace()
 	      if (expected_token != G_TOKEN_NONE)
 		return expected_token;
 
-	      procedure.name = ModuleHelper::define (procedure.name.c_str());
+	      procedure.name = defineSymbol (procedure.name.c_str());
 	      procedure.file = fileName();
 	      addProcedureTodo (procedure);
 	    }
@@ -685,6 +762,26 @@ GTokenType Parser::parseNamespace()
 		return expected_token;
 	    }
 	    break;
+	  case TOKEN_USING:
+	    {
+	      parse_or_return (TOKEN_USING);
+	      parse_or_return (TOKEN_NAMESPACE);
+	      parse_or_return (G_TOKEN_IDENTIFIER);
+
+	      if (!usingNamespace (scanner->value.v_identifier))
+		return GTokenType (TOKEN_ERROR);
+
+	      parse_or_return (';');
+	    }
+	    break;
+	  case TOKEN_NAMESPACE:
+	    {
+	      parse_or_return (TOKEN_NAMESPACE);
+	      GTokenType expected_token = parseNamespace ();
+	      if (expected_token != G_TOKEN_NONE)
+		return expected_token;
+	    }
+	    break;
 	  default:
 	    ready = true;
 	}
@@ -692,9 +789,12 @@ GTokenType Parser::parseNamespace()
   while (!ready);
   
   parse_or_return (G_TOKEN_RIGHT_CURLY);
-  parse_or_return (';');
+
+  /* semicolon after namespaces is optional (like in C++) */
+  if (g_scanner_peek_next_token (scanner) == GTokenType(';'))
+    parse_or_return (';');
   
-  ModuleHelper::leave();
+  leaveNamespace();
   
   return G_TOKEN_NONE;
 }
@@ -713,7 +813,7 @@ GTokenType Parser::parseTypeName (string& type)
       type += scanner->value.v_identifier;
     }
 
-  string qtype = ModuleHelper::qualify (type.c_str());
+  string qtype = qualifySymbol (type.c_str());
 
   if (qtype == "")
     printError ("can't find prior definition for type '%s'", type.c_str());
@@ -773,7 +873,7 @@ GTokenType Parser::parseConstant ()
 
   parse_or_return (TOKEN_CONST);
   parse_or_return (G_TOKEN_IDENTIFIER);
-  cdef.name = ModuleHelper::define (scanner->value.v_identifier);
+  cdef.name = defineSymbol (scanner->value.v_identifier);
   cdef.file = fileName();
   
   parse_or_return ('=');
@@ -829,7 +929,7 @@ GTokenType Parser::parseChoice ()
   
   parse_or_return (TOKEN_CHOICE);
   parse_or_return (G_TOKEN_IDENTIFIER);
-  choice.name = ModuleHelper::define (scanner->value.v_identifier);
+  choice.name = defineSymbol (scanner->value.v_identifier);
   choice.file = fileName();
   if (g_scanner_peek_next_token (scanner) == GTokenType(';'))
     {
@@ -874,7 +974,7 @@ GTokenType Parser::parseChoiceValue (ChoiceValue& comp, int& value, int& sequent
   */
   
   parse_or_return (G_TOKEN_IDENTIFIER);
-  comp.name = scanner->value.v_identifier;
+  comp.name = defineSymbol(scanner->value.v_identifier);
   comp.file = fileName();
   comp.neutral = false;
   
@@ -953,7 +1053,7 @@ GTokenType Parser::parseRecord ()
   
   parse_or_return (TOKEN_RECORD);
   parse_or_return (G_TOKEN_IDENTIFIER);
-  record.name = ModuleHelper::define (scanner->value.v_identifier);
+  record.name = defineSymbol (scanner->value.v_identifier);
   record.file = fileName();
   if (g_scanner_peek_next_token (scanner) == GTokenType(';'))
     {
@@ -1028,7 +1128,7 @@ GTokenType Parser::parseRecordField (Param& def, const IString& group)
   if (expected_token != G_TOKEN_NONE)
     return expected_token;
 
-  def.pspec = def.type;
+  def.pspec = NamespaceHelper::nameOf (def.type); // FIXME: correct?
   def.group = group;
   def.line = scanner->line;
   
@@ -1115,7 +1215,7 @@ GTokenType Parser::parseParamHints (Param &def)
 	case G_TOKEN_IDENTIFIER:
           {
             vector<Constant>::iterator ci;
-            string coname = ModuleHelper::qualify (scanner->value.v_identifier);
+            string coname = qualifySymbol (scanner->value.v_identifier);
             /* FIXME: there should be a generic const_to_string() function */
             for (ci = constants.begin(); ci != constants.end(); ci++)
               if (ci->name == coname)
@@ -1194,7 +1294,7 @@ GTokenType Parser::parseSequence ()
   
   parse_or_return (TOKEN_SEQUENCE);
   parse_or_return (G_TOKEN_IDENTIFIER);
-  sequence.name = ModuleHelper::define (scanner->value.v_identifier);
+  sequence.name = defineSymbol (scanner->value.v_identifier);
   sequence.file = fileName();
   if (g_scanner_peek_next_token (scanner) == GTokenType(';'))
     {
@@ -1230,7 +1330,7 @@ GTokenType Parser::parseClass ()
   
   parse_or_return (TOKEN_CLASS);
   parse_or_return (G_TOKEN_IDENTIFIER);
-  cdef.name = ModuleHelper::define (scanner->value.v_identifier);
+  cdef.name = defineSymbol (scanner->value.v_identifier);
   cdef.file = fileName();
   
   if (g_scanner_peek_next_token (scanner) == GTokenType(';'))
@@ -1361,7 +1461,7 @@ GTokenType Parser::parseMethod (Method& method)
       method.result.file = fileName();
     }
 
-  method.result.pspec = method.result.type;
+  method.result.pspec = NamespaceHelper::nameOf (method.result.type); // FIXME: correct?
 
   parse_or_return (G_TOKEN_IDENTIFIER);
   method.name = scanner->value.v_identifier;
@@ -1376,7 +1476,7 @@ GTokenType Parser::parseMethod (Method& method)
       if (expected_token != G_TOKEN_NONE)
 	return expected_token;
 
-      def.pspec = def.type;
+      def.pspec = NamespaceHelper::nameOf (def.type); // FIXME: correct?
   
       parse_or_return (G_TOKEN_IDENTIFIER);
       def.name = scanner->value.v_identifier;
@@ -1600,6 +1700,210 @@ void Parser::addPrototype (const std::string& type, TypeDeclaration typeDecl)
     }
 }
 
+string Parser::defineSymbol (const string& name)
+{
+  Symbol *sym = currentNamespace->find (name);
+  if (!sym)
+    {
+      sym = new Symbol();
+      sym->name = name;
+      currentNamespace->insert (sym);
+    }
+  return sym->fullName();
+}
+
+static list<string> symbolToList(string symbol)
+{
+  list<string> result;
+  string current;
+  
+  string::iterator si;
+  for(si = symbol.begin(); si != symbol.end(); si++)
+    {
+      if(*si != ':')
+	{
+	  current += *si;
+	}
+      else
+	{
+	  if(current != "")
+	    result.push_back(current);
+	  
+	  current = "";
+	}
+    }
+  
+  result.push_back(current);
+  return result;
+}
+
+Symbol *matchSymbol (const list<string>& nlist, Namespace *ns)
+{
+  Symbol *symbol = ns;
+  for (list<string>::const_iterator i = nlist.begin(); i != nlist.end(); i++)
+    {
+      if (symbol)
+	symbol = symbol->find (*i);
+    }
+  return symbol;
+}
+
+void appendUnique (list<Symbol *>& symbols, Symbol *sym)
+{
+  for (list<Symbol *>::iterator si = symbols.begin(); si != symbols.end(); si++)
+    if (*si == sym)
+      return;
+  symbols.push_back (sym);
+}
+
+void qualifyHelper (const string& name, Namespace *ns,
+                    list<Symbol *>& alternatives, set<Namespace *>& done)
+{
+  /* prevent searching the same namespace twice */
+  if (done.count (ns)) return;
+  done.insert (ns);
+
+  /* try to find the symbol in the current namespace */
+  list<string> nlist = symbolToList (name);
+  Symbol *symbol = matchSymbol (nlist, ns);
+  if (symbol)
+    appendUnique (alternatives, symbol);
+
+  /* try to find the symbol in the parent namespace */
+  Namespace *parent_ns = dynamic_cast<Namespace *> (ns->parent);
+  if (parent_ns)
+    qualifyHelper (name, parent_ns, alternatives, done);
+
+  /* try to find the symbol in one of the namespaces used via "using namespace" */
+  for (vector<Namespace *>::iterator ni = ns->used.begin(); ni != ns->used.end(); ni++)
+    qualifyHelper (name, *ni, alternatives, done);
+}
+
+Symbol *Parser::qualifyHelper (const string& name)
+{
+  set<Namespace *> done;
+  list<Symbol *> alternatives;
+
+  ::qualifyHelper (name, currentNamespace, alternatives, done);
+
+  /* no match? */
+  if (alternatives.empty())
+    return 0;
+
+  /* good match? */
+  if (alternatives.front()->parent == currentNamespace || alternatives.size() == 1)
+    return alternatives.front();
+
+  /* multiple equally valid candidates? */
+  printError ("there are multiple valid interpretations of %s in this context", name.c_str());
+  for (list<Symbol *>::iterator ai = alternatives.begin(); ai != alternatives.end(); ai++)
+    printError (" - it could be %s", (*ai)->fullName().c_str());
+
+  return 0;
+}
+
+string Parser::qualifySymbol (const string& name)
+{
+  Symbol *sym = qualifyHelper (name);
+  if (sym)
+    return sym->fullName();
+  else
+    return "";
+}
+
+bool Parser::enterNamespace (const string& name)
+{
+  Symbol *symbol = currentNamespace->find (name);
+  if (symbol)
+    {
+      currentNamespace = dynamic_cast <Namespace *> (symbol);
+      if (!currentNamespace)
+	{
+	  printError ("%s is not a namespace", name.c_str());
+	  return false;
+	}
+    }
+  else
+    {
+      symbol = new Namespace;
+      symbol->name = name;
+      currentNamespace->insert (symbol);
+      currentNamespace = dynamic_cast<Namespace*>(symbol);
+    }
+  return true;
+}
+
+void Parser::leaveNamespace ()
+{
+  currentNamespace = dynamic_cast<Namespace *>(currentNamespace->parent);
+  if (!currentNamespace)
+    g_error ("fatal: leaveNamespace called without corresponding enterNamespace");
+}
+
+bool Parser::usingNamespace (const string& name)
+{
+  Symbol *sym = qualifyHelper (name);
+  if (!sym)
+    {
+      printError ("%s is an undeclared namespace (can't be used)", name.c_str());
+      return false;
+    }
+
+  Namespace *ns = dynamic_cast<Namespace *> (sym);
+  if (!ns)
+    {
+      printError ("%s is not a namespace (can't be used)", name.c_str());
+      return false;
+    }
+  currentNamespace->used.push_back (ns);
+  return true;
+}
+
+/*
+ * the beginnings of an alternate datastructure - currently only used for namespace
+ * lookups
+ */
+
+string Symbol::fullName ()
+{
+  if (parent && parent->fullName() != "")
+    return parent->fullName() + "::" + name;
+  else
+    return name;
+}
+
+Symbol *Symbol::find (const string& name)
+{
+  for (vector<Symbol *>::iterator ci = children.begin(); ci != children.end(); ci++)
+    {
+      if ((*ci)->name == name)
+	return (*ci);
+    }
+
+  return 0;
+}
+
+bool Symbol::insert (Symbol *symbol)
+{
+  if (find (symbol->name))
+    return false;
+
+  children.push_back (symbol);
+  symbol->parent = this;
+
+  return true;
+}
+
+Symbol::Symbol() : parent (0)
+{
+}
+
+Symbol::~Symbol()
+{
+  for (vector<Symbol *>::iterator ci = children.begin(); ci != children.end(); ci++)
+    delete *ci;
+}
+
 }; // anon namespace
 
 /* vim:set ts=8 sts=2 sw=2: */
