@@ -21,8 +21,9 @@
 #include "sfidl-options.h"
 #include "sfidl-parser.h"
 #include "sfidl-module.h"
+#include "sfidl-typelist.h"
+#include "sfidl-factory.h"
 #include "sfidl-cxx.h"
-#include "sfiparams.h" /* scatId (SFI_SCAT_*) */
 #include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -37,7 +38,9 @@ using namespace std;
 int main (int argc, char **argv)
 {
   Options options;
-  if (!options.parse (&argc, &argv))
+  Parser parser;
+
+  if (!options.parse (&argc, &argv, parser))
     {
       /* invalid options */
       return 1;
@@ -60,40 +63,22 @@ int main (int argc, char **argv)
       return 1;
     }
 
-  Parser parser;
   if (!parser.parse(argv[1]))
     {
       /* parse error */
       return 1;
     }
 
-  CodeGenerator *codeGenerator = 0;
-  switch (options.target)
+  if (!options.codeGenerator)
+    options.codeGenerator = new CodeGeneratorC (parser);
+
+  if (!options.codeGenerator->run ())
     {
-      case Options::TARGET_C:
-	codeGenerator = new CodeGeneratorC (parser);
-	break;
-      case Options::TARGET_QT:
-	codeGenerator = new CodeGeneratorQt (parser);
-	break;
-      case Options::TARGET_CXX:
-	codeGenerator = new CodeGeneratorCxx (parser);
-	break;
-      case Options::TARGET_MODULE:
-	codeGenerator = new CodeGeneratorModule (parser);
-	break;
-    }
-  if (!codeGenerator)
-    {
-      fprintf(stderr, "no target given\n");
+      delete options.codeGenerator;
       return 1;
     }
 
-  printf("\n/*-------- begin %s generated code --------*/\n\n\n",argv[0]);
-  codeGenerator->run ();
-  printf("\n\n/*-------- end %s generated code --------*/\n\n\n",argv[0]);
-
-  delete codeGenerator;
+  delete options.codeGenerator;
   return 0;
 }
 
