@@ -324,7 +324,6 @@ encoder_describe_proc (SfiGlueContext *context,
       SfiSeq *pseq;
       GParamSpec *pspec;
       proc = sfi_glue_proc_new (sfi_rec_get_string (rec, "name"));
-      proc->blurb = g_strdup (sfi_rec_get_string (rec, "blurb"));
       proc->help = g_strdup (sfi_rec_get_string (rec, "help"));
       proc->authors = g_strdup (sfi_rec_get_string (rec, "authors"));
       proc->license = g_strdup (sfi_rec_get_string (rec, "license"));
@@ -354,7 +353,6 @@ decoder_describe_proc (SfiGlueDecoder *decoder,
     {
       rec = sfi_rec_new ();
       sfi_rec_set_string (rec, "name", proc->name);
-      sfi_rec_set_string (rec, "blurb", proc->blurb);
       sfi_rec_set_string (rec, "help", proc->help);
       sfi_rec_set_string (rec, "authors", proc->authors);
       sfi_rec_set_string (rec, "license", proc->license);
@@ -1032,12 +1030,9 @@ sfi_glue_decoder_dispatch (SfiGlueDecoder *decoder)
     }
   
   /* send away queued signals */
+  sfi_com_port_send_bulk (decoder->port, decoder->outgoing);
   while (decoder->outgoing)
-    {
-      GValue *value = sfi_ring_pop_head (&decoder->outgoing);
-      sfi_com_port_send (decoder->port, value);
-      sfi_value_free (value);
-    }
+    sfi_value_free (sfi_ring_pop_head (&decoder->outgoing));
   
   /* FIXME: catch messages */
   
@@ -1083,12 +1078,9 @@ sfi_glue_decoder_dispatch (SfiGlueDecoder *decoder)
     }
   
   /* send away new signals and result */
+  sfi_com_port_send_bulk (decoder->port, decoder->outgoing);
   while (decoder->outgoing)
-    {
-      GValue *value = sfi_ring_pop_head (&decoder->outgoing);
-      sfi_com_port_send (decoder->port, value);
-      sfi_value_free (value);
-    }
+    sfi_value_free (sfi_ring_pop_head (&decoder->outgoing));
   sfi_com_port_process_io (decoder->port);
   
   sfi_glue_gc_run ();
