@@ -54,7 +54,7 @@ static gint	signals_compare	(gconstpointer	 bsearch_node1, /* key */
 static const GBSearchConfig signals_config = {
   sizeof (GlueSignal),
   signals_compare,
-  G_BSEARCH_ARRAY_FORCE_SHRINK,
+  G_BSEARCH_ARRAY_AUTO_SHRINK,
 };
 static GQuark quark_weak_refs = 0;
 
@@ -549,7 +549,7 @@ sfi_glue_proxy_disconnect (SfiProxy     proxy,
 	}
 
       if (!slist)
-	sfi_warn ("%s: signal handler %p(%p) is not connected", G_STRLOC, callback, data);
+	sfi_debug ("%s: signal handler %p(%p) is not connected", G_STRLOC, callback, data);
       signal = va_arg (var_args, gchar*);
     }
   va_end (var_args);
