@@ -185,11 +185,14 @@ eval_match (const gchar *str1,
   return *str1 == 0 && *str2 == 0;
 }
 
+#define isalnum(c)      ((c >= 'A' && c <= 'Z') || (c >= 'a' && c <= 'z') || (c >= '0' && c <= '9'))
+
 gboolean
 sfi_choice_match_detailed (const gchar *choice_val1,
 			   const gchar *choice_val2,
 			   gboolean     l1_ge_l2)
 {
+  const gchar *cv1, *cv2;
   guint l1, l2;
 
   g_return_val_if_fail (choice_val1 != NULL, FALSE);
@@ -199,7 +202,14 @@ sfi_choice_match_detailed (const gchar *choice_val1,
   l2 = strlen (choice_val2);
   if (l1_ge_l2 && l1 < l2)
     return FALSE;
-  return eval_match (choice_val1 + l1 - MIN (l1, l2), choice_val2 + l2 - MIN (l1, l2));
+  cv1 = choice_val1 + l1 - MIN (l1, l2);
+  cv2 = choice_val2 + l2 - MIN (l1, l2);
+  if (l1_ge_l2 && cv1 > choice_val1)    /* only allow partial matches on word boundary */
+    {
+      if (isalnum (cv1[-1]) && isalnum (cv1[0])) /* no word boundary */
+        return FALSE;
+    }
+  return cv2[0] && eval_match (cv1, cv2);
 }
 
 gboolean
