@@ -38,6 +38,7 @@ typedef gdouble			SfiReal;
 #define SFI_MINREAL		(2.2250738585072014e-308)	/* IEEE754 double */
 #define SFI_MAXREAL		(1.7976931348623157e+308)	/* IEEE754 double */
 typedef const gchar*		SfiChoice;
+typedef gchar*  		SfiString;                      /* convenience for code generators */
 typedef struct _SfiBBlock	SfiBBlock;
 typedef struct _SfiFBlock	SfiFBlock;
 typedef struct _SfiSeq		SfiSeq;
@@ -50,6 +51,7 @@ typedef struct {
 } SfiRecFields;
 typedef struct _SfiUStore	SfiUStore;
 typedef struct _SfiUPool	SfiUPool;
+typedef struct _SfiPPool	SfiPPool;
 
 
 /* --- global --- */
@@ -111,6 +113,15 @@ gint	     sfi_constants_rcmp		(const gchar	    *canon_identifier1,
 const gchar* sfi_info_string_find	(const gchar	   **infos,
 					 const gchar	    *key);
 
+
+/* --- idl macro magic --- */
+#define SFI_START_ARGS()     (
+#define SFI_END_ARGS()       )
+#define SFI_END_ARGS1(a)     a)
+#define SFI_END_ARGS2(a,b)   a , b)
+#define SFI_END_ARGS3(a,b,c) a , b , c)
+
+
 G_END_DECLS
 
 #endif /* __SFI_TYPES_H__ */
