@@ -25,7 +25,7 @@
 /* provide IDL type initializers */
 #define sfidl_pspec_Real(group, name, nick, blurb, dflt, min, max, step, hints)  \
   sfi_pspec_real (name, nick, blurb, dflt, min, max, step, hints)
-#define sfidl_pspec_BoxedRec(group, name, nick, blurb, hints, fields)            \
+#define sfidl_pspec_Record(group, name, nick, blurb, hints, fields)            \
   sfi_pspec_rec (name, nick, blurb, fields, hints)
 #define sfidl_pspec_Choice(group, name, nick, blurb, default_value, hints, choices) \
   sfi_pspec_choice (name, nick, blurb, default_value, choices, hints)
@@ -166,9 +166,16 @@ test_thread (gpointer data)
 static void
 test_threads (void)
 {
+  static SfiMutex test_mutex;
   guint thread_data = 0;
   SfiThread *thread;
+  gboolean locked;
   MSG ("Threading:");
+  sfi_mutex_init (&test_mutex);
+  locked = sfi_mutex_trylock (&test_mutex);
+  ASSERT (locked);
+  SFI_SPIN_UNLOCK (&test_mutex);
+  sfi_mutex_destroy (&test_mutex);
   thread = sfi_thread_run (NULL, test_thread, &thread_data);
   ASSERT (thread != NULL);
   ASSERT (thread_data == 0);
@@ -318,7 +325,7 @@ serialize_cmp (GValue     *value,
 	    }
 	}
       ASSERT (cmp == 0);
-      if (0) /* FIXME: generate testoutput */
+      if (0) /* generate testoutput */
 	g_print ("OK=================(%s)=================:\n%s\n", pspec->name, gstring->str);
     }
   g_scanner_destroy (scanner);
@@ -755,7 +762,7 @@ test_sfidl_seq (void)
   value = sfi_rec_get (rec, "relevant");
 
   ASSERT (SFI_VALUE_HOLDS_CHOICE (value));
-  ASSERT (strcmp (sfi_value_get_choice (value), "TEST_NO") == 0);
+  ASSERT (strcmp (sfi_value_get_choice (value), "test-no") == 0);
 
   pos2 = test_position_from_rec (rec);
 
